(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    135493,       4700]*)
(*NotebookOutlinePosition[    330023,      10106]*)
(*  CellTagsIndexPosition[    326808,       9985]*)
(*WindowFrame->Normal*)



Notebook[{
Cell[TextData[{
  "Introduction to Programming with ",
  StyleBox["Mathematica",
    FontSlant->"Italic"]
}], "TitleBar",
  CellTags->{
  "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
    "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
    "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
    "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
    "IPM3.8.5.3", "IPM3.8.5.4"}],

Cell[CellGroupData[{

Cell[TextData[{
  
  CounterBox["Chapter"],
  " ",
  "Numerics"
}], "Chapter",
  CounterAssignments->{{"Chapter", 7}},
  CellTags->{"IPM3.8.0", "c:1"}],

Cell[TextData[{
  "Of the many data types that are available in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \[Dash] numbers, strings, symbols, lists \[Dash] numbers are perhaps the \
most familiar. You can work with all kinds of numbers in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", but, most importantly, what distinguishes it from traditional \
programming languages and other computational systems is that with it you can \
operate on numbers of any size and to any degree of precision. In this \
chapter we will explore some of the issues related to working with numerical \
quantities and show how you can incorporate some of these ideas into any \
programs that involve numerical computations."
}], "ChapterAbstract",
  CellTags->"IPM3.8.0"],

Cell[CellGroupData[{

Cell["Introduction", "Section",
  CounterAssignments->{{"Chapter", 8}, {"Section", 0}},
  CellTags->{"b:34", "IPM3.8.1", "c:2"}],

Cell[TextData[{
  "One of the first things that users of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notice when they begin to use it is how different is its treatment of \
numbers from other systems including calculators, traditional programming \
languages, and other technical computing systems. In most traditional \
programming languages, you must declare the type of number your functions can \
take as an argument. Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " automatically handles such details for you, an understanding of the \
different number types and how they invoke different algorithms will be \
helpful for taking full advantage of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]s capabilities and writing efficient programs."
}], "TextFirst",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[TextData[{
  "Although you can work with both exact and approximate numbers, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " operates differently depending upon the type of input you give it."
}], "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[\[Pi]\/4]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    \(1\/\@2\)], "Output",
  CellLabel->"Out[1]=",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sin[\[Pi]\/4.0]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    \(0.7071067811865475`\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],

Cell[TextData[{
  "It is important to understand that not only are different kinds of output \
returned in such cases, but ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses entirely different algorithms for these two computations. In the \
first case, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " looks up identities involving the sin function and multiples of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/4\)]],
  " and applies the appropriate transformation rule to give an algebraic \
result. In the second example, because a floating point number is involved in \
the input, a numerical routine (a series expansion for sin) is used and the \
computation is carried out to insure a result with the same precision as the \
input."
}], "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[TextData[{
  "Another feature that is important to understand involves computations with \
high-precision numbers. By default, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " operates on approximate numbers using a fixed precision that is \
determined by the machine on which you are working."
}], "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\[Pi]] // Precision\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    \(MachinePrecision\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],

Cell[TextData[{
  "The number of decimal digits of precision for machine numbers is \
approximately 16 (we will discuss precision in detail in Section ",
  
  CounterBox["Chapter"],
  ".",
  
  CounterBox["Section", "Sec.WorkingWithNumbers"],
  ")."
}], "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \($MachinePrecision\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    \(15.954589770191003`\)], "Output",
  CellLabel->"Out[4]=",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],

Cell["\<\
When you need to, you can raise the number of digits of precision of the \
numbers you are working with. For example, this computes \[Pi] to 200 digit \
precision.\
\>", "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\[Pi], 200]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    \(3.1415926535897932384626433832795028841971693993751058209749445923078164\
062862089986280348253421170679821480865132823066470938446095505822317253594081\
284811174502841027019385211055596446229489549303819644288109757`200. \)], \
"Output",
  CellLabel->"Out[5]=",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],

Cell[TextData[{
  "You can extend such arbitrary-precision computations to ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]s built-in functions. As a simple, but illuminating \
example, consider the numerical solution of the van der Pol equation ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\^\[Prime]\[Prime]\)(
            t) - \(1\/5\) \((1 - \(x\^2\)(t))\) \(\(x\^\[Prime]\)(t)\) + 
          x(t) = 0\)]],
  " with the given initial conditions."
}], "Text",
  ZeroWidthTimes->True,
  CellTags->{"i:1", "b:34", "IPM3.8.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(soln = 
      NDSolve[{\(\(x\^\[Prime]\)\^\[Prime]\)[t] - 
              1\/5\ \((1 - x[t]\^2)\)\ \(x\^\[Prime]\)[t] + x[t] == 0, 
          x[0] == 1, \(x\^\[Prime]\)[0] == 0}, x, {t, 0, 30}]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0.`, 30.`}}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[6]=",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],

Cell[TextData[{
  "The solution is represented as an interpolating function, one that passes \
through the solution over the range for ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " from 0 to 30. Here is a plot of the original function evaluated at this \
numerical solution, essentially giving a visual picture of the error in the \
numerical solution."
}], "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    \(\(Plot[
        Evaluate[\(\(x\^\[Prime]\)\^\[Prime]\)[t] - 
              1\/5\ \((1 - x[t]\^2)\)\ \(x\^\[Prime]\)[t] + 
              x[t] /. \[InvisibleSpace]soln], {t, 0, 30}, 
        PlotRange \[Rule] {\(-10\^\(-5\)\), 10\^\(-5\)}];\)\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell["\<\
By increasing the precision of the internal algorithms used to solve this \
differential equation, we can get a more precise solution.\
\>", "Text",
  CellTags->{"i:2", "b:34", "IPM3.8.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(soln24 = 
      NDSolve[{\(\((x\^\[Prime])\)\^\[Prime]\)[t] - 
              1\/5\ \((1 - x[t]\^2)\)\ \(x\^\[Prime]\)[t] + x[t] == 0, 
          x[0] == 1, \(x\^\[Prime]\)[0] == 0}, x, {t, 0, 30}, 
        WorkingPrecision \[Rule] 27, PrecisionGoal \[Rule] 24]\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{"{", 
        RowBox[{"x", "\[Rule]", 
          TagBox[\(InterpolatingFunction[{{0, 30.`27. }}, "<>"]\),
            False,
            Editable->False]}], "}"}], "}"}]], "Output",
  CellLabel->"Out[8]=",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],

Cell[TextData[{
  "The plot of the original function evaluated at this higher precision \
solution clearly shows the higher degree of precision obtained with ",
  StyleBox["soln24", "MR"],
  "."
}], "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    \(\(Plot[
        Evaluate[\(\(x\^\[Prime]\)\^\[Prime]\)[
                t] - \(1\/5\) \((1 - x[t]\^2)\)\ \(x\^\[Prime]\)[t] + 
              x[t] /. \[InvisibleSpace]soln24], {t, 0, 30}, 
        PlotRange \[Rule] {\(-10\^\(-7\)\), 10\^\(-7\)}];\)\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell["\<\
Working with numbers and understanding issues of precision and accuracy and \
the interplay between your machine\[CloseCurlyQuote]s hardware and the \
software are essential to working with any computational system or \
programming language. In this chapter we will discuss all these issues and \
look at how to make your numeric computations as efficient as possible.\
\>", "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[BoxData[
    \(\($Line = 0;\)\)], "NonPrintInput",
  CellLabel->"In[10]:="],

Cell["", "SectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Numbers", "Section",
  CounterAssignments->{{"Chapter", 8}, {"Section", 1}},
  CellTags->{"IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", "IPM3.8.2.4", "c:3"}],

Cell[CellGroupData[{

Cell["Types of numbers", "Subsection",
  CellTags->{"b:35.0", "IPM3.8.2.1", "c:4"}],

Cell[TextData[{
  "There are four kinds of numbers represented in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " \[Dash] integer, rational, real, and complex. In addition, mathematical \
constants like \[Pi] and \[ExponentialE] are treated as a special type of \
number. Integers are considered to be exact and are represented without a \
decimal point; rational numbers are quotients of integers and are also \
considered to be exact."
}], "TextFirst",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[TextData[{
  "As mentioned in Chapter 2, numbers are atomic expressions, meaning they \
cannot be broken down into smaller parts. Use the ",
  StyleBox["Head", "MR"],
  " function to identify the type of number you are working with."
}], "Text",
  CellTags->{"i:3", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Head, {3, 3\/9, 0.33333, 4 + 3.1  I, \[Pi]}]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \({Integer, Rational, Real, Complex, Symbol}\)], "Output",
  CellLabel->"Out[1]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[TextData[{
  "Using ",
  StyleBox["FullForm", "MR"],
  " we can see how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " represents these objects internally."
}], "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[FullForm, {3, 3\/9, 0.33333, 4 + 3.1  I, \[Pi]}]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          StyleBox["3",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox[\(Rational[1, 3]\),
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["0.33333`",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox[\(Complex[4, 3.1`]\),
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm], ",", 
        TagBox[
          StyleBox["Pi",
            ShowSpecialCharacters->False,
            ShowStringCharacters->True,
            NumberMarks->True],
          FullForm]}], "}"}]], "Output",
  CellLabel->"Out[2]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[TextData[{
  "As can be seen in the above example, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " simplifies rational numbers to lowest terms and leaves them as exact \
numbers. (We will have more to say about the seemingly strange internal form \
of real numbers when we discuss their representation in Section ",
  
  CounterBox["Chapter"],
  ".",
  
  CounterBox["Section", "Sec.WorkingWithNumbers"],
  ".)"
}], "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[TextData[{
  "This representation of rational (and complex) numbers as a pair of \
integers has one more consequence. If you need to pattern match with rational \
numbers, you should be aware of their internal representation. For example, \
trying to pattern match with ",
  StyleBox["x_/y_", "MR"],
  " will not work."
}], "Text",
  CellTags->{"i:4", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(3\/4 /. \[InvisibleSpace]x_\/y_ \[Rule] {x, y}\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(3\/4\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[TextData[{
  "But pattern matching instead with ",
  StyleBox["Rational", "MR"],
  " works fine."
}], "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(3\/4 /. \[InvisibleSpace]Rational[x_, y_] \[Rule] {x, y}\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \({3, 4}\)], "Output",
  CellLabel->"Out[4]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[TextData[{
  "Any number containing a decimal point is classified as a real number in ",
  StyleBox["Mathematica.",
    FontSlant->"Italic"],
  " These numbers are not considered exact and are hence often referred to as \
",
  StyleBox["approximate numbers", "TermDefinition"],
  ". This often leads to confusion for new users of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". You may know that the number 6.0 is identical to the number 6, ",
  StyleBox["from a mathematical perspective",
    FontSlant->"Italic"],
  ", but from the perspective of the floating point unit (FPU) of your \
computer and as we saw in the example above, they are quite different both in \
terms of their representation and in terms of the algorithms that are used to \
do arithmetic with them. We will have much more to say about this in Section \
",
  
  CounterBox["Chapter"],
  ".",
  
  CounterBox["Section", "Sec.WorkingWithNumbers"],
  "."
}], "Text",
  PageBreakAbove->True,
  CellTags->{"i:5", "b:35.0", "IPM3.8.2.1"}],

Cell[TextData[{
  "Complex numbers are of the form ",
  Cell[BoxData[
      \(TraditionalForm\`a + b\[VeryThinSpace]i\)],
    FormatType->StandardForm],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)],
    FormatType->StandardForm],
  " are any numbers \[Dash] integer, rational, or real. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " represents ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(-1\)\)],
    FormatType->StandardForm],
  " by the symbol ",
  StyleBox["I", "MR"],
  " or \[ImaginaryI]."
}], "Text",
  CellTags->{"i:6", "b:35.0", "IPM3.8.2.1"}],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " views complex numbers as a distinct data type, different from integers or \
real numbers."
}], "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(z = 3 + 4\ \[ImaginaryI]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(3 + 4\ \[ImaginaryI]\)], "Output",
  CellLabel->"Out[5]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Head[z]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(Complex\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell["You can add and subtract complex numbers.", "TextFirst",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(z + \((2 - \[ImaginaryI])\)\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(5 + 3\ \[ImaginaryI]\)], "Output",
  CellLabel->"Out[7]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell["\<\
You can find the real and imaginary parts of any complex number.\
\>", "TextFirst",
  CellTags->{"i:7", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Re[z], Im[z]}\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \({3, 4}\)], "Output",
  CellLabel->"Out[8]=",
  CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell["\<\
The conjugate and absolute value can also be computed. The absolute value of \
any number is its distance to the origin in the complex plane. The conjugate \
can be thought of as the reflection of the complex number in the real axis of \
the complex plane.\
\>", "Text",
  CellTags->{"i:9", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Conjugate[z], Abs[z]}\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \({3 - 4\ \[ImaginaryI], 5}\)], "Output",
  CellLabel->"Out[9]=",
  CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell["The phase angle is given by the argument.", "TextFirst",
  CellTags->{"i:11", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Arg[4\ \[ImaginaryI]]\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(\[Pi]\/2\)], "Output",
  CellLabel->"Out[10]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell["\<\
Each of these properties of complex numbers can be visualized geometrically, \
as shown in Figure 8.1.\
\>", "TextFirst",
  PageBreakAbove->True,
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell["Geometric representation of complex numbers in the plane", \
"NumberedFigure",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[TextData[{
  "For purposes of pattern matching, complex numbers are quite similar to \
rational numbers. ",
  StyleBox["x\[ThinSpace]+\[ThinSpace]I\[ThinSpace]y", "MR"],
  " will not match with complex numbers. A complex number ",
  Cell[BoxData[
      \(TraditionalForm\`z = a + b\ \[ImaginaryI]\)]],
  " is treated as a single object for many operations, and is stored as ",
  StyleBox["Complex[a,b]", "MR"],
  ". So to match a complex number ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", use ",
  StyleBox["Complex[x_,y_]", "MR"],
  " (or ",
  StyleBox["z_Complex", "MR"],
  " and ",
  StyleBox["Re[z]", "MR"],
  " and ",
  StyleBox["Im[z]", "MR"],
  ") on the right-hand side of any rule you define."
}], "Text",
  CellTags->{"i:12", "b:35.0", "IPM3.8.2.1"}],

Cell[TextData[{
  "Built-in constants such as \[Pi], \[ExponentialE], \[ImaginaryI], and ",
  StyleBox["Degree", "MR"],
  " are not treated as real numbers by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Head[\[Pi]], NumberQ[\[Pi]]}\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \({Symbol, False}\)], "Output",
  CellLabel->"Out[11]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[TextData[{
  "Although ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not consider constants like \[Pi] and \[ExponentialE] like real \
numbers, it does recognize that they are numerical in nature and thus you can \
use them more like ordinary numbers."
}], "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Random[Real, {\[ExponentialE], \[Pi]}]\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(2.770328825316414`\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rationalize[\[Pi],  .0001]\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(333\/106\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[TextData[{
  "Mathematical constants have an attribute, ",
  StyleBox["NumericQ", "MR"],
  ", that essentially alerts ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to the fact that they are numeric in nature."
}], "Text",
  CellTags->{"i:13", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[
      NumericQ, {\[Pi], \[ExponentialE], 
        EulerGamma, \[Infinity], \[ImaginaryI]}]\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \({True, True, True, False, True}\)], "Output",
  CellLabel->"Out[14]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[TextData[{
  "All mathematical constants and any expressions which are explicit numbers \
are considered numeric and will return a value of ",
  StyleBox["True", "MR"],
  " when ",
  StyleBox["NumericQ", "MR"],
  " is applied to them (note in particular that the symbol \[Infinity] is not \
numeric). When ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " recognizes that a quantity has this attribute, it converts the symbol to \
a real number, using what it perceives to be necessary precision."
}], "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[ExponentialE]\^\[Pi] > \[Pi]\^\[ExponentialE]\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[15]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(NumericQ[\[Pi]\^\[ExponentialE]]\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[16]=",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[TextData[{
  "If you have to distinguish between explicit numbers and symbols that \
represent numbers, then use ",
  StyleBox["NumberQ", "MR"],
  "."
}], "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[NumberQ, {3.14, \[Pi]}]\)], "Input",
  CellLabel->"In[17]:=",
  CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}],

Cell[BoxData[
    \({True, False}\)], "Output",
  CellLabel->"Out[17]=",
  CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Digits and number bases", "Subsection",
  CellTags->{"b:35.1", "IPM3.8.2.2", "c:5"}],

Cell[TextData[{
  "A list of the digits of a number can be obtained with the functions ",
  StyleBox["IntegerDigits", "MR"],
  " or ",
  StyleBox["RealDigits", "MR"],
  "."
}], "TextFirst",
  CellTags->{"i:15", "b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{

Cell["IntegerDigits[1293]", "Input",
  CellLabel->"In[18]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    \({1, 2, 9, 3}\)], "Output",
  CellLabel->"Out[18]=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RealDigits[N[EulerGamma]]\)], "Input",
  CellLabel->"In[19]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    \({{5, 7, 7, 2, 1, 5, 6, 6, 4, 9, 0, 1, 5, 3, 2, 9}, 0}\)], "Output",
  CellLabel->"Out[19]=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell[TextData[{
  "Numbers in base 10 can be displayed in other bases by means of the ",
  StyleBox["BaseForm", "MR"],
  " function. For example, the following displays 18 in base 2."
}], "Text",
  CellTags->{"i:16", "b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{

Cell["BaseForm[18, 2]", "Input",
  CellLabel->"In[20]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    TagBox[
      InterpretationBox[\("10010"\_"2"\),
        18,
        Editable->False],
      (BaseForm[ #, 2]&)]], "Output",
  CellLabel->"Out[20]//BaseForm=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell[TextData[{
  "The operator ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  StyleBox["^^", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " takes the number ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " in base ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " and converts it to base 10."
}], "Text",
  CellTags->{"i:17", "b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(2^^10010\)], "Input",
  CellLabel->"In[21]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    \(18\)], "Output",
  CellLabel->"Out[21]=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell["\<\
The letters of the alphabet are used for numbers in bases larger than 10. For \
example, here are the numbers 1 through 20 in base 16.\
\>", "Text",
  PageBreakAbove->True,
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[BaseForm[j, 16], {j, 1, 20}]\)], "Input",
  CellLabel->"In[22]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        TagBox[
          InterpretationBox[\("1"\_"16"\),
            1,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("2"\_"16"\),
            2,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("3"\_"16"\),
            3,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("4"\_"16"\),
            4,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("5"\_"16"\),
            5,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("6"\_"16"\),
            6,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("7"\_"16"\),
            7,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("8"\_"16"\),
            8,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("9"\_"16"\),
            9,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("a"\_"16"\),
            10,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("b"\_"16"\),
            11,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("c"\_"16"\),
            12,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("d"\_"16"\),
            13,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("e"\_"16"\),
            14,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("f"\_"16"\),
            15,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("10"\_"16"\),
            16,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("11"\_"16"\),
            17,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("12"\_"16"\),
            18,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("13"\_"16"\),
            19,
            Editable->False],
          (BaseForm[ #, 16]&)], ",", 
        TagBox[
          InterpretationBox[\("14"\_"16"\),
            20,
            Editable->False],
          (BaseForm[ #, 16]&)]}], "}"}]], "Output",
  CellLabel->"Out[22]=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell["\<\
Numbers other than integers can be represented in bases different from 10. \
Here are the first few digits of \[Pi] in base 2.\
\>", "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(BaseForm[N[\[Pi], 5], 2]\)], "Input",
  CellLabel->"In[23]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    TagBox[
      InterpretationBox[\(11.00100100010000\_2\),
        3.1415926535897932385`5.,
        AutoDelete->True],
      (BaseForm[ #, 2]&)]], "Output",
  CellLabel->"Out[23]//BaseForm=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell[TextData[{
  "Recall that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is only displaying six significant ",
  StyleBox["decimal",
    FontSlant->"Italic"],
  " digits while storing quite a few more. In the exercises you are asked to \
convert the base 2 representation back to base 10. You will need the digits \
from the base 2 representation, which are obtained with the ",
  StyleBox["RealDigits", "MR"],
  " function."
}], "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(RealDigits[N[\[Pi]], 2]\)], "Input",
  CellLabel->"In[24]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    \({{1, 1, 0, 0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 1, 1, 1, 1, 1, 0, 1, 1, 0, 1, 
        0, 1, 0, 1, 0, 0, 0, 1, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 1, 1, 0, 1, 0, 
        0, 0, 1, 1, 0, 0, 0}, 2}\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell[TextData[{
  "The 2 in this last result indicates where the binary point is placed and \
can be stripped off this list by wrapping the ",
  StyleBox["First", "MR"],
  " function around the expression ",
  StyleBox["RealDigits[N[\[Pi]],2]", "MR"],
  "."
}], "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell["\<\
Here are the first 16 decimal digits of \[Pi] given in base 2.\
\>", "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(BaseForm[N[\[Pi]], 2]\)], "Input",
  CellLabel->"In[25]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    TagBox[
      InterpretationBox[\("11.00100100001111111"\_2\),
        3.1415926535897931,
        AutoDelete->True],
      (BaseForm[ #, 2]&)]], "Output",
  CellLabel->"Out[25]//BaseForm=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell["\<\
You are not restricted to integral bases such as in the previous examples. \
The base can be any real number greater than 1. For example:\
\>", "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(RealDigits[N[\[Pi]], N[GoldenRatio]]\)], "Input",
  CellLabel->"In[26]:=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[BoxData[
    \({{1, 0, 0, 0, 1, 0, 0, 1, 0, 1, 0, 1, 0, 0, 1, 0, 0, 0, 1, 0, 1, 0, 1, 
        0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 1, 0, 1, 
        0, 0, 0, 1, 0, 0, 0, 0, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 0, 0, 
        0, 0, 0, 1, 0, 0, 0}, 3}\)], "Output",
  CellLabel->"Out[26]=",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Random numbers", "Subsection",
  CellTags->{"b:35.2", "IPM3.8.2.3", "c:6"}],

Cell[TextData[{
  "Statistical work and numerical experimentation often require random \
numbers to test hypotheses. You use the ",
  StyleBox["Random", "MR"],
  " function to generate random numbers in various ranges, domains, and \
distributions."
}], "TextFirst",
  CellTags->{"i:18", "b:35.2", "IPM3.8.2.3"}],

Cell[TextData[{
  "Using ",
  StyleBox["Random", "MR"],
  " without any arguments will generate a uniformly distributed random real \
number between 0 and 1."
}], "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Random[]\)], "Input",
  CellLabel->"In[27]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \(0.06919886304962797`\)], "Output",
  CellLabel->"Out[27]=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell[TextData[{
  StyleBox["Random", "MR"],
  " takes two optional arguments. The first indicates the type of number to \
generate and the second argument specifies the range. For example, this \
generates a random integer in the range 0 to 100."
}], "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Random[Integer, {0, 100}]\)], "Input",
  CellLabel->"In[28]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \(69\)], "Output",
  CellLabel->"Out[28]=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell["\<\
A good random number generator will distribute random numbers evenly over \
many trials. For example, this generates a list of 1,000 integers between 0 \
and 9.\
\>", "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \(\(numbers = Table[Random[Integer, {0, 9}], {1000}];\)\)], "Input",
  CellLabel->"In[29]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[TextData[{
  "Here is a plot of the frequency with which each of the digits 0 through 9 \
occur. We first load the packages containing the definitions for ",
  StyleBox["Frequencies", "MR"],
  " and ",
  StyleBox["BarChart", "MR"],
  "."
}], "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell["Needs[\"Statistics`DataManipulation`\"]", "Input",
  CellLabel->"In[30]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell["Needs[\"Graphics`Graphics`\"]", "Input",
  CellLabel->"In[31]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \(\(BarChart[Frequencies[numbers]];\)\)], "Input",
  CellLabel->"In[32]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[TextData[{
  "We see each of the numbers 0 through 9 occur ",
  StyleBox["roughly",
    FontSlant->"Italic"],
  " 1/10 of the time. You would not want these numbers to occur ",
  StyleBox["exactly",
    FontSlant->"Italic"],
  " 1/10 of the time, as there would be no randomness in this. In fact, for a \
uniform distribution of the numbers 0 through 9, any sequence of 1,000 digits \
is equally as likely to occur as any other sequence of 1,000 digits. A \
sequence of 1,000 numbers that contains exactly 100 occurrences of the digit \
0 followed by 100 occurrences of the digit 1, followed by 100 occurrences of \
the digit 2, etc., is no more likely than the sequence that contains 1000 7s, \
for example."
}], "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[TextData[{
  "In addition to working with uniformly distributed random numbers (the \
default for ",
  StyleBox["Random", "MR"],
  "), you can also work with any of the built-in distributions that are \
defined in the Add-ons packages, or even your own user-defined distribution. \
For example, suppose you wished to work with the chi-square distribution \
(normal random variable with unit variance and mean about 0)."
}], "Text",
  CellTags->{"i:19", "b:35.2", "IPM3.8.2.3"}],

Cell["\<\
First we load the package in which this distribution is defined.\
\>", "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell["<<Statistics`ContinuousDistributions`", "Input",
  CellLabel->"In[33]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell["\<\
Here is a chi-square distribution with four degrees of freedom.\
\>", "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChiSquareDistribution[4]\)], "Input",
  CellLabel->"In[34]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \(ChiSquareDistribution[4]\)], "Output",
  CellLabel->"Out[34]=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell["\<\
This generates an array of ten random numbers distributed according to this \
distribution.\
\>", "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(RandomArray[ChiSquareDistribution[4], 10]\)], "Input",
  CellLabel->"In[35]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \({9.12669148294697`, 3.9723140131656405`, 3.5923123760652924`, 
      8.407313112391128`, 0.9018042045979305`, 7.79066838503577`, 
      9.378185545485799`, 8.146685712244137`, 4.44091128646348`, 
      3.0197507337136895`}\)], "Output",
  CellLabel->"Out[35]=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell["\<\
Suppose instead of using one of the built-in distributions, you wish to \
generate random numbers for a continuous distribution based on a small sample \
of that distribution.\
\>", "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell["\<\
For example, suppose this is the sample from a distribution from which you \
would like to generate a quantile function.\
\>", "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \(\(sample = {192, 155, 154, 152, 107, 149, 128, 111, 139, 108, 127, 130, 
          189, 119, 200, 178, 116, 180, 108, 129};\)\)], "Input",
  CellLabel->"In[36]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell["\<\
To construct a quantile function consistent with this sample, we need to \
generate some probability points, one for each sample point and then pair \
them up with the sample data points.\
\>", "TextFirst",
  CellTags->{"i:20", "b:35.2", "IPM3.8.2.3"}],

Cell["\<\
To generate a discrete quantile function that is consistent with the above \
sample, we will first generate some probability values interpolated between \
the sample points, and then pair them up with the sample points.\
\>", "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(probvals = N[Range[0, 1, 1\/\(Length[sample] - 1\)]]\)], "Input",
  CellLabel->"In[37]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \({0.`, 0.05263157894736842`, 0.10526315789473684`, 0.15789473684210525`, 
      0.21052631578947367`, 0.2631578947368421`, 0.3157894736842105`, 
      0.3684210526315789`, 0.42105263157894735`, 0.47368421052631576`, 
      0.5263157894736842`, 0.5789473684210527`, 0.631578947368421`, 
      0.6842105263157895`, 0.7368421052631579`, 0.7894736842105263`, 
      0.8421052631578947`, 0.8947368421052632`, 0.9473684210526315`, 
      1.`}\)], "Output",
  CellLabel->"Out[37]=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(quantilepts = Transpose[{probvals, Sort[sample]}]\)], "Input",
  CellLabel->"In[38]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \({{0.`, 107}, {0.05263157894736842`, 108}, {0.10526315789473684`, 
        108}, {0.15789473684210525`, 111}, {0.21052631578947367`, 
        116}, {0.2631578947368421`, 119}, {0.3157894736842105`, 
        127}, {0.3684210526315789`, 128}, {0.42105263157894735`, 
        129}, {0.47368421052631576`, 130}, {0.5263157894736842`, 
        139}, {0.5789473684210527`, 149}, {0.631578947368421`, 
        152}, {0.6842105263157895`, 154}, {0.7368421052631579`, 
        155}, {0.7894736842105263`, 178}, {0.8421052631578947`, 
        180}, {0.8947368421052632`, 189}, {0.9473684210526315`, 192}, {1.`, 
        200}}\)], "Output",
  CellLabel->"Out[38]=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell["\<\
To generate a continuous quantile function, we need to interpolate through \
these points.\
\>", "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(continuousQuantile = Interpolation[quantilepts]\)], "Input",
  CellLabel->"In[39]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    TagBox[\(InterpolatingFunction[{{0.`, 1.`}}, "<>"]\),
      False,
      Editable->False]], "Output",
  CellLabel->"Out[39]=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell["Here is a plot of this continuous quantile function.", "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \(\(Plot[continuousQuantile[x], {x, 0, 1}];\)\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell["\<\
Finally, we generate 20 random numbers that are consistent with the sample.\
\>", "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[continuousQuantile[Random[]], {20}]\)], "Input",
  CellLabel->"In[41]:=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[BoxData[
    \({117.55588415050889`, 118.49075035387082`, 112.166416088307`, 
      127.48101713588682`, 120.25606518371437`, 107.9590230110132`, 
      138.4366232049446`, 107.92592721681653`, 120.2799489203137`, 
      117.0185336146234`, 137.7628217096307`, 118.46708473040222`, 
      109.17601854437264`, 152.13108459383517`, 198.15126574765304`, 
      199.1122675101912`, 178.000461179091`, 133.0116699298463`, 
      149.83891702709894`, 179.57727916641042`}\)], "Output",
  CellLabel->"Out[41]=",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell[BoxData[{
    \(\(convert[digits_List, base_ : 2] := 
        Fold[\((base\ #1 + #2)\) &, 0, digits];\)\), "\[IndentingNewLine]", 
    \(\($Line = 0;\)\)}], "NonPrintInput",
  CellLabel->"In[42]:="],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSubsection",
  CellTags->{"b:35.2", "IPM3.8.2.4", "c:7"}],

Cell[TextData[{
  "Define a function ",
  StyleBox["complexToPolar", "MR"],
  " that converts complex numbers to their polar representations. Then, \
convert the numbers ",
  Cell[BoxData[
      \(TraditionalForm\`3 + 3  \[ImaginaryI]\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[Pi]\[ImaginaryI]\/3\)\)],
    FormatType->StandardForm],
  " to polar form."
}], "ExerciseItem",
  ZeroWidthTimes->True,
  CellTags->{"i:21", "b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell[TextData[{
  "Using the built-in ",
  StyleBox["Fold", "MR"],
  " function, write a function ",
  StyleBox["convert[", "MR"],
  Cell[BoxData[
      FormBox[
        StyleBox["lis",
          FontSlant->"Italic"], TraditionalForm]],
    FormatType->StandardForm],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`b\)],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  " that accepts a list of digits in any base ",
  Cell[BoxData[
      \(TraditionalForm\`b\)],
    FormatType->StandardForm],
  " (less than 20) and converts it to a base 10 number. For example, ",
  Cell[BoxData[
      \(TraditionalForm\`1101\_2\)],
    FormatType->StandardForm],
  " is 13 in base 10, so your function should handle this as follows:"
}], "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(convert[{1, 1, 0, 1}, 2]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[BoxData[
    \(13\)], "Output",
  CellLabel->"Out[1]=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell[" ", "Text",
  PageBreakAbove->True]
}, Closed]],

Cell[TextData[{
  "Write a function ",
  StyleBox["sumsOfCubes[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  " that takes a positive integer argument ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  " and computes the sums of cubes of the digits of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  ". This exercise and the next three exercises are excerpted from an article \
in ",
  StyleBox["The Mathematica Journal",
    FontSlant->"Italic"],
  ", ",
  "Sums of cubes of digits, driven to abstraction",
  " (Hayes 1992)."
}], "ExerciseItem",
  CellTags->{"i:22", "b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "Use ",
  StyleBox["NestList", "MR"],
  " to iterate this process of summing cubes of digits; that is, generate a \
list starting with an initial integer, say 4, of the successive sums of cubes \
of digits. For example, starting with 4, the list should look like: ",
  StyleBox["{4,64,280,520,133,\[Ellipsis]}", "MR"],
  ". Note, ",
  Cell[BoxData[
      \(TraditionalForm\`64 = 4\^3\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`280 = 6\^3 + 4\^3\)],
    FormatType->StandardForm],
  ", etc. Extend the list for at least 15 values and make an observation \
about any patterns you notice. Experiment with other starting values."
}], "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell["Prove the following statements:", "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  " has more than four digits, then ",
  StyleBox["sumsOfCubes[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  " has fewer digits than ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  "."
}], "ExerciseSubItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  " has four digits or less, then ",
  StyleBox["sumsOfCubes[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  " has four digits or less."
}], "ExerciseSubItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  " has four digits or less, then ",
  StyleBox["sumsOfCubes[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  StyleBox["]\[LessEqual]", "MR"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`4\[CenterDot]9\^3\)],
    FormatType->StandardForm],
  "."
}], "ExerciseSubItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "If ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  " is less than 2,916, then ",
  StyleBox["sumsOfCubes[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  " is less than 2,916."
}], "ExerciseSubItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "Write a function ",
  StyleBox["sumsOfPowers[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`p\)],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  " that computes the sums of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)],
    FormatType->StandardForm],
  "th powers of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  "."
}], "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell["\<\
Binary shifts arise in the study of computer algorithms because they often \
allow you to speed up calculations by operating in base 2 or in bases that \
are powers of 2. Try to discover what a binary shift does by performing the \
following shift on 24 (base 10). First get the integer digits of 24 in base \
2.\
\>", "ExerciseItem",
  CellTags->{"i:23", "b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(IntegerDigits[24, 2]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[BoxData[
    \({1, 1, 0, 0, 0}\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell["Then, do a binary shift, one place to the right.", "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(RotateRight[%]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[BoxData[
    \({0, 1, 1, 0, 0}\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell["Finally, convert back to base 10.", "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell["2^^01100", "Input",
  CellLabel->"In[4]:=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[BoxData[
    \(12\)], "Output",
  CellLabel->"Out[4]=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell["\<\
Experiment with other numbers (including both odd and even integers) and make \
some conjectures.\
\>", "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[" ", "Text",
  PageBreakAbove->True]
}, Closed]],

Cell[TextData[{
  "The ",
  StyleBox["survivor[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  " function from Chapter 4 can be programmed using binary shifts. This can \
be done by rotating the base 2 digits of the number ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  " by one unit to the left and then converting this rotated list back to \
base 10. For example, if ",
  Cell[BoxData[
      \(TraditionalForm\`n = 10\)],
    FormatType->StandardForm],
  ", the base 2 representation is ",
  Cell[BoxData[
      \(TraditionalForm\`1010\_2\)],
    FormatType->StandardForm],
  "; the binary shift gives ",
  Cell[BoxData[
      \(TraditionalForm\`0101\_2\)],
    FormatType->StandardForm],
  "; converting this number back to base 10 gives 5, which is the output to \
",
  StyleBox["survivor[5]", "MR"],
  ". Program a new ",
  StyleBox["survivor", "MR"],
  " function using the binary shift."
}], "ExerciseItem",
  CellTags->{"i:24", "b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "Simulate the throwing of two dice by defining a function ",
  StyleBox["rollEm", "MR"],
  " that, when evaluated, displays two integers between 1 and 6."
}], "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "Experiment with creating random two-dimensional images using ",
  StyleBox["ListDensityPlot", "MR"],
  "."
}], "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell[TextData[{
  "A surprisingly simple pseudorandom number algorithm is the ",
  StyleBox["linear congruential method", "TermDefinition"],
  ". It is quite easy to implement and has been studied extensively. \
Sequences of random numbers are generated by a formula such as the \
following:"
}], "ExerciseItem",
  CellTags->{"i:25", "b:35.2", "IPM3.8.2.4"}],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`x\_\(n + 1\) = \(x\_n\) b + 
        1\ \ \ \((mod\ m)\)\)]]], "DisplayFormula",
  ZeroWidthTimes->True,
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "The starting value ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)],
    FormatType->StandardForm],
  " is the ",
  StyleBox["seed", "TermDefinition"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\)],
    FormatType->StandardForm],
  " is the ",
  StyleBox["multiplier", "TermDefinition"],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)],
    FormatType->StandardForm],
  " is the ",
  StyleBox["modulus", "TermDefinition"],
  ". Recall that ",
  Cell[BoxData[
      \(TraditionalForm\`7\ mod\ 5\)],
    FormatType->StandardForm],
  " is the remainder upon dividing 7 by 5. This is represented in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " as"
}], "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mod[7, 5]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[BoxData[
    \(2\)], "Output",
  CellLabel->"Out[5]=",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell[TextData[{
  "Implement the linear congruential method and test it with a variety of \
numbers ",
  Cell[BoxData[
      \(TraditionalForm\`m\)],
    FormatType->StandardForm],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\)],
    FormatType->StandardForm],
  ". If you find that the generator gets in a loop easily, try a large value \
for the modulus ",
  Cell[BoxData[
      \(TraditionalForm\`m\)],
    FormatType->StandardForm],
  ". (See Knuth 1997 for a full treatment of random number generating \
algorithms.)"
}], "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Write a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["quadCong",
            "MR"], 
          StyleBox["[",
            "MR"], \(a, b, c, m, x\_0\), 
          StyleBox["]",
            "MR"]}], TraditionalForm]],
    FormatType->StandardForm],
  " that implements a ",
  StyleBox["quadratic congruential method", "TermDefinition"],
  StyleBox[",", "TermDefinition",
    FontSlant->"Plain"],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`a\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b\)],
    FormatType->StandardForm],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)],
    FormatType->StandardForm],
  " are the parameters, ",
  Cell[BoxData[
      \(TraditionalForm\`m\)],
    FormatType->StandardForm],
  " is the modulus, and ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0\)],
    FormatType->StandardForm],
  " is the starting value. The iteration is given by:"
}], "ExerciseItem",
  CellTags->{"i:26", "b:35.2", "IPM3.8.2.4"}],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`x\_\(n + 1\) = \((a\ x\_n\%2 + b\ x\_n + 
            c)\)\ \ \ mod\ \ m\)]]], "DisplayFormula",
  ZeroWidthTimes->True,
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Numerous tests are available for determining the effective \
\[OpenCurlyDoubleQuote]randomness\[CloseCurlyDoubleQuote] of a sequence. One \
of the more fundamental tests is known as the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)],
    FormatType->StandardForm],
  " (chi-square) test. It tests to see how evenly spread out the numbers \
appear in the sequence and uses their frequency of occurrence. If ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  " is the upper bound of a sequence of ",
  Cell[BoxData[
      \(TraditionalForm\`m\)],
    FormatType->StandardForm],
  " positive numbers, then, in a well-distributed random sequence, we would \
expect about ",
  Cell[BoxData[
      \(TraditionalForm\`m/n\)],
    FormatType->StandardForm],
  " copies of each number. To take into account the actual frequency with \
which each number occurs, the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)],
    FormatType->StandardForm],
  " test is implemented by the formula below where the function ",
  Cell[BoxData[
      \(TraditionalForm\`f\_i\)],
    FormatType->StandardForm],
  " is the number of copies of ",
  Cell[BoxData[
      \(TraditionalForm\`i\)],
    FormatType->StandardForm],
  " in the sequence.  ",
  "If the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)],
    FormatType->StandardForm],
  " statistic is close to ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  ", then the numbers are reasonably random. In particular, we will consider \
the sequence sufficiently random if the statistic is within ",
  Cell[BoxData[
      \(TraditionalForm\`2 \@ n\)],
    FormatType->StandardForm],
  " of ",
  Cell[BoxData[
      \(TraditionalForm\`n\)],
    FormatType->StandardForm],
  "."
}], "ExerciseItem",
  ZeroWidthTimes->True,
  CellTags->{"i:27", "b:35.2", "IPM3.8.2.4"}],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Chi]\^2 = \(\[Sum]\_\(1 \[LessEqual] i \[LessEqual] \
n\)\((f\_i - m/n)\)\^2\)\/\(m/n\)\)]]], "DisplayFormula",
  ScriptSizeMultipliers->0.8,
  ScriptMinSize->7,
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[TextData[{
  "Write a function ",
  StyleBox["chiSquare[", "MR"],
  Cell[BoxData[
      FormBox[
        StyleBox["lis",
          FontSlant->"Italic"], TraditionalForm]],
    FormatType->StandardForm],
  StyleBox["]", "MR"],
  " that takes a list of numbers and returns the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)],
    FormatType->StandardForm],
  " statistic. You will find the built-in ",
  StyleBox["Count", "MR"],
  " function helpful for calculating the frequencies."
}], "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell[TextData[{
  "Determine the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)],
    FormatType->StandardForm],
  " statistic for a sequence of 1000 integers generated with the linear \
congruential method with ",
  Cell[BoxData[
      \(TraditionalForm\`m = 381\)],
    FormatType->StandardForm],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`b = 15\)],
    FormatType->StandardForm],
  ", and a starting value of 0."
}], "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{

Cell[TextData[{
  "John von Neumann, considered by many to be the \
\[OpenCurlyDoubleQuote]father of computer science,\[CloseCurlyDoubleQuote] \
suggested a random number generator known as the ",
  StyleBox["middle-square", "TermDefinition"],
  " method. Starting with a ten-digit integer, square the initial integer and \
then extract its middle ten digits to get the next number in the sequence. \
For example, starting with 1234567890, squaring it produces \
1524157875019052100. The middle digits are 1578750190, so the sequence starts \
out 1234567890, 1578750190, 4521624250, \[Ellipsis]. Implement a middle \
square random number generator and then test it on a 1,000-number sequence \
using the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\^2\)],
    FormatType->StandardForm],
  " test. Was the \[OpenCurlyDoubleQuote]father of computer science\
\[CloseCurlyDoubleQuote] a good random number generator?"
}], "ExerciseItem",
  CellTags->{"i:28", "b:35.2", "IPM3.8.2.4"}],

Cell[BoxData[
    \(\($Line = 0;\)\)], "NonPrintInput",
  CellLabel->"In[6]:="],

Cell["", "SectionSpacer"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Working with numbers", "Section",
  CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
  CellTags->{
  "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
    "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],

Cell[CellGroupData[{

Cell["Precision and accuracy", "Subsection",
  CellTags->{"b:36.0", "IPM3.8.3.1", "c:9"}],

Cell[TextData[{
  "When you work with real numbers in any programming language, you are \
working with inexact, or approximate quantities. In ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", any number which contains a decimal point is considered to be an \
approximate number. You can specify an approximate number explicitly, such as \
1.57, or you can get approximations to exact quantities using ",
  StyleBox["N", "MR"],
  "."
}], "TextFirst",
  CellTags->{"i:29", "b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(e = N[\[ExponentialE]]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    \(2.718281828459045`\)], "Output",
  CellLabel->"Out[1]=",
  CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell[TextData[{
  StyleBox["Precision", "TermDefinition"],
  " of an approximate number is defined as the number of significant decimal \
digits in that number. You should think of precision as giving a measure of \
the relative size of the uncertainty in the value of a number. ",
  StyleBox["Accuracy", "TermDefinition"],
  " is defined as the number of these digits to the right of the decimal \
point. Accuracy can be thought of as a measure of the absolute size of the \
uncertainty in the value of a number."
}], "Text",
  CellTags->{"i:31", "b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Precision[e], Accuracy[e]}\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    \({MachinePrecision, 15.520295288287752`}\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell[TextData[{
  "The symbol ",
  StyleBox["MachinePrecision", "MR"],
  " (new in Version 5) is used to indicate a machine-precision number. To see \
the effective precision of any machine number on your computer, evaluate ",
  StyleBox["$MachinePrecision", "MR"],
  ". "
}], "Text",
  CellTags->{"i:32", "b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \($MachinePrecision\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    \(15.954589770191003`\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell[TextData[{
  "The numbers that can be operated with on the hardware (on the floating \
point unit, or FPU) of your computer are called ",
  StyleBox["machine numbers",
    FontSlant->"Italic"],
  ". Typically, 64 binary digits (IEEE double floats) are needed to specify a \
machine number: 1 for the sign, 11 for the exponent, and 52 for the mantissa \
(actually 53, since the leading one is implicitly taken as 0). A typical \
value of ",
  StyleBox["$MachinePrecision", "MR"],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\((64 - 11)\) \(log\_10\) 2\)], "InlineFormula"],
  ", giving machine numbers about 16 ",
  StyleBox["decimal",
    FontSlant->"Italic"],
  " digits."
}], "Text",
  CellTags->{"i:33", "b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(53\ Log[10, 2] // N\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    \(15.954589770191001`\)], "Output",
  CellLabel->"Out[4]=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell[TextData[{
  "To say that a real number ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " has some uncertainty associated with its value, can be formalized by \
saying that the value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " lies somewhere inside of an interval ",
  Cell[BoxData[
      \(TraditionalForm\`x - \[Delta]\/2\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x + \[Delta]\/2\)]],
  " for some uncertainty \[Delta]. A number with precision ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " is then defined to have uncertainty ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(x\)\(|\)\(10\^\(-p\)\)\)\)]],
  "."
}], "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(p /. Solve[\[Delta] == Abs[x] 10\^\(-p\), p]\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    RowBox[{\(Solve::"ifun"\), \(\(:\)\(\ \)\), "\<\"Inverse functions are \
being used by \\!\\(Solve\\), so some solutions may not be found; use Reduce \
for complete solution information. \
\\!\\(\\*ButtonBox[\\\"More\[Ellipsis]\\\", ButtonStyle->\\\"RefGuideLinkText\
\\\", ButtonFrame->None, ButtonData:>\\\"Solve::ifun\\\"]\\)\"\>"}]], \
"Message",
  CellLabel->"From In[5]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    \({\(-\(Log[\[Delta]\/Abs[x]]\/Log[10]\)\)}\)], "Output",
  CellLabel->"Out[5]=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell[TextData[{
  "In other words, the precision of a real number ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\(log\_10\)(\[Delta]\/\(\(|\)\(x\)\(|\)\))\)\)\)\
]],
  " for some uncertainty \[Delta]. So we could manually compute the precision \
of ",
  StyleBox["e", "MR"],
  " above using an uncertainty of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-15\)\)]],
  ", which is approximately what ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " assumes for machine-precision numbers."
}], "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(-Log[10, 10\^\(-15\)\/Abs[e]]\)\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    \(15.43429448190325`\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell[TextData[{
  "On the other hand, a number with accuracy ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " will have uncertainty ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta] = 10\^\(-a\)\)]],
  " and hence accuracy can be expressed as ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\(\(log\_10\)(\[Delta])\)\)\)]],
  "."
}], "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell["\<\
Before discussing accuracy and precision of non-machine numbers, let us first \
look at a few examples.\
\>", "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[TextData[{
  StyleBox["InputForm", "MR"],
  " can be used to see how you would have to input the full number as it is \
represented internally in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ". The ",
  StyleBox["Accuracy", "MR"],
  " indicates there are approximately 16 decimal digits to the right of the \
decimal point. The ",
  StyleBox["Precision", "MR"],
  " indicates that this is a machine-precision number."
}], "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x = N[EulerGamma];\)\), "\[IndentingNewLine]", 
    \({InputForm[x], Accuracy[x], Precision[x]}\)}], "Input",
  CellLabel->"In[7]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          StyleBox["0.5772156649015329",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ .57721566490153287],
          Editable->True,
          AutoDelete->True], ",", "16.193251661407835`", ",", 
        "MachinePrecision"}], "}"}]], "Output",
  CellLabel->"Out[8]=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell["\<\
The number 123.456 is a machine-precision number, but its accuracy is reduced \
because it has three digits to the left of the decimal point. \
\>", "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(x = 123.456;\)\), "\[IndentingNewLine]", 
    \({InputForm[x], Accuracy[x], Precision[x]}\)}], "Input",
  CellLabel->"In[9]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        InterpretationBox[
          StyleBox["123.456",
            ShowStringCharacters->True,
            NumberMarks->True],
          InputForm[ 123.456],
          Editable->True,
          AutoDelete->True], ",", "13.863077568563233`", ",", 
        "MachinePrecision"}], "}"}]], "Output",
  CellLabel->"Out[10]=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell[TextData[{
  "You can see more clearly how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " computes ",
  StyleBox["Accuracy", "MR"],
  " by looking at the following example."
}], "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Accuracy[1.23], Accuracy[12.3], Accuracy[123. ]}\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[BoxData[
    \({15.864684658751605`, 14.864684658751605`, 
      13.864684658751605`}\)], "Output",
  CellLabel->"Out[11]=",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],

Cell["\<\
Each addition of a digit to the left of the decimal point has the effect of \
reducing the number of significant digits to the right of the decimal point \
by 1.\
\>", "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Representation of approximate numbers", "Subsection",
  CellTags->{"b:36.1", "IPM3.8.3.2", "c:10"}],

Cell[TextData[{
  "Usually, when ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " displays numbers, it does so in a form that is as close to traditional \
mathematics as possible, printing six digits for example."
}], "TextFirst",
  CellTags->{"i:34", "b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(pi = N[\[Pi]]\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[BoxData[
    \(3.141592653589793`\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],

Cell["\<\
Do not assume that typing in what is displayed will result in the same value.\
\
\>", "Text",
  PageBreakAbove->True,
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(pi\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[BoxData[
    \(3.141592653589793`\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(pi - 3.14159\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[BoxData[
    \(2.6535897932333796`*^-6\)], "Output",
  CellLabel->"Out[14]=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],

Cell[TextData[{
  "This seemingly strange behavior \[Dash] the fact that ",
  StyleBox["pi", "MR"],
  " does not appear to be equal to 3.14159 \[Dash] can be explained by \
looking at the internal representation of ",
  StyleBox["pi", "MR"],
  "."
}], "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[pi]\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[BoxData[
    TagBox[
      StyleBox["3.141592653589793`",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[15]//FullForm=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],

Cell[TextData[{
  "The command ",
  StyleBox["N[\[Pi]]", "MR"],
  " causes ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to first convert \[Pi] to a machine-precision number, and then to display \
only six digits. Any computations with this number occur using the machine \
precision."
}], "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[TextData[{
  "Note that a number mark ",
  StyleBox["`", "MR"],
  " was printed at the end of the above number. This is a machine-independent \
mark used to indicate that this is a machine-precision number. When you work \
with numbers that are not at machine precision, this will be indicated by a \
number following the number mark. For example, here is a high-precision \
number."
}], "Text",
  CellTags->{"i:35", "b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\[Pi], 35]\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[BoxData[
    \(3.141592653589793238462643383279502884197169399375`35. \)], "Output",
  CellLabel->"Out[16]=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],

Cell["\<\
The following shows the full internal representation of this number with the \
precision indicated by the 35 following the number mark.\
\>", "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullForm[%]\)], "Input",
  CellLabel->"In[17]:=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[BoxData[
    TagBox[
      StyleBox["3.141592653589793238462643383279502884197169399375`35.",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[17]//FullForm=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],

Cell[TextData[{
  "Finally, note that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", in a sense, treats all machine real numbers as having the same \
precision."
}], "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[1.23]\)], "Input",
  CellLabel->"In[18]:=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[BoxData[
    \(MachinePrecision\)], "Output",
  CellLabel->"Out[18]=",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],

Cell[TextData[{
  "Although this last result may seem odd at first, it is a consequence of \
how ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " represents real numbers internally. A ",
  StyleBox["Precision", "MR"],
  " of 16 (on a computer with ",
  StyleBox["$MachinePrecision", "MR"],
  " of 16) indicates that the number 1.23 is viewed as a machine-precision \
real number which will allow ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to perform arithmetic with it using the efficient machine-precision \
arithmetic routines. ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " views the number 1.23 as a machine-precision real by effectively padding \
with 0s out to 16 significant digits. If you are uncertain about the \
precision of the numbers you are working with, it is best to check with ",
  StyleBox["Precision", "MR"],
  "."
}], "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exact vs. approximate numbers", "Subsection",
  CellTags->{"b:36.2", "IPM3.8.3.3", "c:11"}],

Cell[TextData[{
  "As stated earlier, all integers and rational numbers are considered ",
  StyleBox["exact",
    FontSlant->"Italic"],
  ". You can see this by examining the ",
  StyleBox["Precision", "MR"],
  " of any integer or rational number."
}], "TextFirst",
  CellTags->{"i:36", "b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Precision[7], Precision[1\/9]}\)], "Input",
  CellLabel->"In[19]:=",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[BoxData[
    \({\[Infinity], \[Infinity]}\)], "Output",
  CellLabel->"Out[19]=",
  CellTags->{"b:36.2", "IPM3.8.3.3"}]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " represents complex numbers similarly to rational numbers. If both the \
real and imaginary parts are exact, then the complex number is treated as \
exact."
}], "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[3 + 4  I]\)], "Input",
  CellLabel->"In[20]:=",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[BoxData[
    \(\[Infinity]\)], "Output",
  CellLabel->"Out[20]=",
  CellTags->{"b:36.2", "IPM3.8.3.3"}]
}, Closed]],

Cell["\<\
Exact numbers have more precision than any approximate number. Representing a \
number with infinite precision is another way of saying that it is exact. \
\>", "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Precision, {4, 1\/9, 3 + 4  I}]\)], "Input",
  CellLabel->"In[21]:=",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[BoxData[
    \({\[Infinity], \[Infinity], \[Infinity]}\)], "Output",
  CellLabel->"Out[21]=",
  CellTags->{"b:36.2", "IPM3.8.3.3"}]
}, Closed]],

Cell[TextData[{
  "As we saw in the example at the beginning of this chapter, this allows ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " to operate on such a number differently than if the number were only \
approximate."
}], "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Cos[\[Pi]\/4], Cos[\[Pi]\/4.0]}\)], "Input",
  CellLabel->"In[22]:="],

Cell[BoxData[
    \({1\/\@2, 0.7071067811865476`}\)], "Output",
  CellLabel->"Out[22]="]
}, Closed]],

Cell[TextData[{
  "But, in fact, more is true. As far as ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is concerned, all integers are not created equal."
}], "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[TextData[{
  "In stark contrast to programming languages, such as C or Pascal that \
typically restrict computations with integers to 16 or 32 bits (this \
restricts integers to a magnitude of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^16\)],
    FormatType->StandardForm],
  " in the case of 16-bit integers, or to a magnitude of ",
  Cell[BoxData[
      \(TraditionalForm\`2\^32\)],
    FormatType->StandardForm],
  " in the case of 32-bit integers), ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " allows you to compute with integers and rational numbers of arbitrary \
size. "
}], "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[TextData[{
  "If two numbers are to be added, ",
  Cell[BoxData[
      \(TraditionalForm\`3 + 6\)],
    FormatType->StandardForm],
  " for example, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " checks to see if the numbers can be added as ",
  StyleBox["machine integers", "TermDefinition"],
  ". A machine integer is an integer whose magnitude is small enough to fit \
into your machine\[CloseCurlyQuote]s natural word size, and to be operated on \
by the machine\[CloseCurlyQuote]s instructions, generally on its floating \
point processor. ",
  StyleBox["Word size", "TermDefinition"],
  " means the number of bits used to represent integers. On many computer \
systems, the most common word size is 64 bits."
}], "Text",
  CellTags->{"i:37", "b:36.2", "IPM3.8.3.3"}],

Cell["\<\
Arithmetic operations on integers within this range can be performed using \
the machine\[CloseCurlyQuote]s own instructions (that is, on the machine\
\[CloseCurlyQuote]s floating point unit), whereas operations on integers out \
of that range must be done by programs, which can be less efficient.\
\>", "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[TextData[{
  "If the two numbers to be added are machine integers and ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can determine that their sum is a machine integer, then the addition is \
performed at this low level."
}], "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[TextData[{
  "If, on the other hand, the two integers to be added are large and either \
the integers themselves or their sum is larger than the size of a machine \
integer, then ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " performs the arithmetic using special algorithms. Integers in this range \
are referred to as ",
  StyleBox["extended-precision integers", "TermDefinition"],
  ". For example, the following computation, although impossible to execute \
on most machine floating point units, is handled by ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "\[CloseCurlyQuote]s arithmetic algorithms for operating on \
extended-precision integers."
}], "Text",
  CellTags->{"i:38", "b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(2\^256 + 2\^1024\)], "Input",
  CellLabel->"In[23]:=",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[BoxData[
    \(179769313486231590772930519078902473361797697894230657273430081157732675\
805500963132708477322407536021120113879871393357658789768814416622492847430639\
474124377767893424865485276302219601246094119453082952085005768838150682342462\
881589705199778143432586921495693274206093217230604120280344292940337537353777\
152\)], "Output",
  CellLabel->"Out[23]=",
  CellTags->{"b:36.2", "IPM3.8.3.3"}]
}, Closed]],

Cell[TextData[{
  "Rational numbers are treated somewhat similarly to integers in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " since the rational number ",
  Cell[BoxData[
      \(TraditionalForm\`a/b\)]],
  " can be thought of as a pair of integers, and, in fact, as we saw earlier, \
it is represented as ",
  StyleBox["Rational[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  StyleBox[",", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  StyleBox["]", "MR"],
  ". In this way, algorithms for exact rational arithmetic will use integer \
arithmetic (either machine or extended) to perform many of the necessary \
computations."
}], "Text",
  CellTags->{"i:39", "b:36.2", "IPM3.8.3.3"}],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["High precision vs. machine precision", "Subsection",
  CellTags->{"b:36.3", "IPM3.8.3.4", "c:12"}],

Cell["\<\
Real numbers (often referred to as \[OpenCurlyDoubleQuote]floating point \
numbers\[CloseCurlyDoubleQuote]) contain decimal points, and, as mentioned \
above, although they can contain any number of digits, they are not \
considered exact. \
\>", "TextFirst",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Head[1.61803], Precision[1.61803]}\)], "Input",
  CellLabel->"In[24]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \({Real, MachinePrecision}\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Head[1.4987349873487454511], 
      Precision[1.4987349873487454511]}\)], "Input",
  CellLabel->"In[25]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \({Real, 19.17572484585219`}\)], "Output",
  CellLabel->"Out[25]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[TextData[{
  "In a manner similar to how integers are treated ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses different internal algorithms to do arithmetic on real numbers, \
depending upon whether you are using very high precision reals or not. \
Whenever possible arithmetic operations on real numbers are performed using \
machine-precision (fixed) reals. Real numbers that can be computed at the \
hardware level of the machine are referred to as ",
  StyleBox["fixed precision reals", "TermDefinition"],
  ", and, as stated above, the number of digits that each machine uses for \
fixed-precision real numbers is given by the system variable ",
  StyleBox["$MachinePrecision", "MR"],
  "."
}], "Text",
  CellTags->{"i:40", "b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \($MachinePrecision\)], "Input",
  CellLabel->"In[26]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(15.954589770191003`\)], "Output",
  CellLabel->"Out[26]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell["\<\
One fact to keep in mind when working with machine-precision numbers is that \
any computations of expressions containing machine-precision numbers will be \
done at the machine precision level.\
\>", "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(2.0\^100\)], "Input",
  CellLabel->"In[27]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(1.2676506002282294`*^30\)], "Output",
  CellLabel->"Out[27]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[%]\)], "Input",
  CellLabel->"In[28]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(MachinePrecision\)], "Output",
  CellLabel->"Out[28]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[TextData[{
  "So, if a machine-precision number is added to a high-precision number, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will perform the computation at the lower, machine precision."
}], "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[2.1 + 3.1111111111111111111111]\)], "Input",
  CellLabel->"In[29]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(MachinePrecision\)], "Output",
  CellLabel->"Out[29]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell["\<\
Here are the limits on the size of machine numbers that you can work with.\
\>", "Text",
  CellTags->{"i:41", "b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({$MaxMachineNumber, $MinMachineNumber}\)], "Input",
  CellLabel->"In[30]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \({1.7976931348623157`*^308, 2.2250738585072014`*^-308}\)], "Output",
  CellLabel->"Out[30]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[TextData[{
  "To get a sense of the limit given by ",
  StyleBox["$MaxMachineNumber", "MR"],
  ", note that this limit is essentially given by ",
  Cell[BoxData[
      \(TraditionalForm\`2\^1023*1.1111  \[Ellipsis]11\)]],
  " (53 total binary digits), a number just smaller than ",
  Cell[BoxData[
      \(TraditionalForm\`2\^1024\)]],
  ". The number 53 comes from the number of binary digits that are used to \
specify the mantissa for any floating point number."
}], "Text",
  CellTags->{"i:42", "b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[2\^1024]\)], "Input",
  CellLabel->"In[31]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(1.7976931348623159077293051908`15.954589770191005*^308\)], "Output",
  CellLabel->"Out[31]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(1.1111111111111111111111111111111111111111111111111111*2^1023\)], \
"Input",
  CellLabel->"In[32]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(9.987184082568421709607251059939026297877649883012814193096497016412`52.\
045757490560675*^307\)], "Output",
  CellLabel->"Out[32]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \($MaxMachineNumber\)], "Input",
  CellLabel->"In[33]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(1.7976931348623157`*^308\)], "Output",
  CellLabel->"Out[33]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[TextData[{
  "Although there is a limit to the magnitude of the machine-precision \
numbers on any given computer, you can still compute with numbers outside of \
this range. Real numbers larger than machine-precision reals are referred to \
as ",
  StyleBox["multiple precision reals", "TermDefinition"],
  " and arithmetic on such numbers is called ",
  StyleBox["multiple precision arithmetic", "TermDefinition"],
  " or ",
  StyleBox["variable precision floating point arithmetic", "TermDefinition"],
  ". So, for example, on a machine whose ",
  StyleBox["$MachinePrecision", "MR"],
  " is 16 decimal digits, computations involving real numbers with greater \
than 16 significant digits will be performed using multiple-precision \
algorithms."
}], "Text",
  CellTags->{"i:43", "b:36.3", "IPM3.8.3.4"}],

Cell[TextData[{
  "When doing exact arithmetic \[Dash] multiplying two integers, for example \
\[Dash]",
  StyleBox[" Mathematica",
    FontSlant->"Italic"],
  " first checks that both numbers are in fact integers (actually, ",
  StyleBox["machine integers", "TermDefinition"],
  "). If they are small and do not overflow the machine\[CloseCurlyQuote]s \
arithmetic registers, then it goes ahead and multiplies them at the hardware \
level. If they are large (on most machines, integers are 32 bits long), then \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " goes to its extended-precision algorithms and multiplies the integers \
there. In either case, all work done is ",
  StyleBox["exact",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[TextData[{
  "When doing computations on inexact numbers, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses two different types of arithmetic, depending upon the precision of \
the numbers involved. ",
  StyleBox["Fixed precision", "TermDefinition"],
  " floating point arithmetic is used whenever the numbers can be handled in \
the machine\[CloseCurlyQuote]s hardware routines. Sometimes, this arithmetic \
is referred to as ",
  StyleBox["machine precision", "TermDefinition"],
  " arithmetic. In the previous section, we gave the following example."
}], "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Precision[1.23], Accuracy[1.23]}\)], "Input",
  CellLabel->"In[34]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \({MachinePrecision, 15.864684658751605`}\)], "Output",
  CellLabel->"Out[34]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " has converted 1.23 to a machine floating point number and will use \
machine arithmetic on it whenever possible. The ",
  StyleBox["Accuracy", "MR"],
  " of 16 in this example indicates that there are implicit trailing 0s in \
this number. In the following example, ",
  StyleBox["n", "MR"],
  " has smaller accuracy due to the fact that there are an explicit number of \
numbers to the right of the decimal point and roughly speaking, for \
machine-precision numbers, the number of digits to the right of the decimal \
plus the number of digits to the left of the decimal should add up to the \
number of decimal digits given by ",
  StyleBox["$MachinePrecision", "MR"],
  "."
}], "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(n = 12345.6789101112\)], "Input",
  CellLabel->"In[35]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(12345.6789101112`\)], "Output",
  CellLabel->"Out[35]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \({Precision[n], Accuracy[n]}\)], "Input",
  CellLabel->"In[36]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \({MachinePrecision, 11.863074792666042`}\)], "Output",
  CellLabel->"Out[36]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[TextData[{
  "You can adjust the precision of numbers with ",
  StyleBox["SetPrecision", "MR"],
  ", although you should note that this function will not make an inexact \
number more exact."
}], "Text",
  CellTags->{"i:44", "b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(a = SetPrecision[1\/3, 30]\)], "Input",
  CellLabel->"In[37]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(0.333333333333333333333333333333333333333333333333`30. \)], "Output",
  CellLabel->"Out[37]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[TextData[{
  "When ",
  StyleBox["SetPrecision", "MR"],
  " is used with exact numbers, such as integers and rational numbers, it \
creates a few more bits than were asked for, 30 in this case. You can see \
this by trying to increase the precision."
}], "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(b = SetPrecision[a, 50]\)], "Input",
  CellLabel->"In[38]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(0.3333333333333333333333333333333333333333333333331052574114054659715`\
50. \)], "Output",
  CellLabel->"Out[38]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[TextData[{
  "When the number ",
  StyleBox["a", "MR"],
  " was first created, the extended-precision number was represented as a \
finite number of binary bits, followed by infinitely many (implicit) trailing \
0s. Increasing the precision of this number uncovered the decimal digits \
which are not 0s. We can see this by converting 1/3 to a binary \
representation and then taking a finite number of the binary digits to \
convert back to base 10."
}], "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(RealDigits[N[1\/3], 2]\)], "Input",
  CellLabel->"In[39]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \({{1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 
        0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 1, 0, 
        1, 0, 1, 0, 1, 0, 1}, \(-1\)}\)], "Output",
  CellLabel->"Out[39]=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(2^^.01010101 // FullForm\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    TagBox[
      StyleBox["0.33203125`",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[40]//FullForm=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell["Let us clear unneeded symbols.", "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[BoxData[
    \(Clear[a, b, n, x]\)], "Input",
  CellLabel->"In[41]:=",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Roundoff errors", "Subsection",
  CellTags->{"b:36.4", "IPM3.8.3.5", "c:13"}],

Cell["\<\
Precision and accuracy are affected by performing computations with inexact \
numbers in ways that can be quite surprising. One such situation concerns a \
magnification of error due to roundoff. This can be seen with a simple \
example.\
\>", "TextFirst",
  CellTags->{"i:45", "b:36.4", "IPM3.8.3.5"}],

Cell[TextData[{
  "Here is a machine-precision approximation to ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  " raised to a large power."
}], "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\@2]\^200\)], "Input",
  CellLabel->"In[42]:=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[BoxData[
    \(1.2676506002282469`*^30\)], "Output",
  CellLabel->"Out[42]=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell["\<\
Working with approximations necessarily introduces some error. Comparing the \
machine-precision result with the exact result gives a measure of how the \
error is magnified.\
\>", "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(% - \(\@2\)\^200\)], "Input",
  CellLabel->"In[43]:=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[BoxData[
    \(1.7451448556060672`*^16\)], "Output",
  CellLabel->"Out[43]=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell[TextData[{
  "That is an error of over 17 thousand trillion! This loss of accuracy is \
typically referred to as ",
  StyleBox["roundoff error", "TermDefinition"],
  ". You can see how this loss gets progressively worse by repeating the \
above example for larger and larger exponents."
}], "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[N[\@2]\^j - \(\@2\)\^j, {j, 100, 1000, 100}]\)], "Input",
  CellLabel->"In[44]:=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[BoxData[
    \({7.75`, 1.7451448556060672`*^16, 2.9155963805249276`*^31, 
      4.3887866550708266`*^46, 6.186711470397113`*^61, 
      8.367787698790428`*^76, 1.0999994272206225`*^92, 
      1.410501648833894`*^107, 1.7882080405751842`*^122, 
      2.2386632708304692`*^137}\)], "Output",
  CellLabel->"Out[44]=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Accuracy, %]\)], "Input",
  CellLabel->"In[45]:=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[BoxData[
    \({15.065288067684692`, \(-0.2872417111783479`\), \
\(-15.51013763222471`\), \(-30.687754699517615`\), \(-45.83687009211374`\), \
\(-60.96802088287935`\), \(-76.08680268882632`\), \(-91.19478382797784`\), \
\(-106.29782827313795`\), \(-121.39539900377302`\)}\)], "Output",
  CellLabel->"Out[45]=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell[TextData[{
  "Recall that ",
  StyleBox["Accuracy[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  StyleBox["]", "MR"],
  " gives the number of significant digits to the right of the decimal point \
in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". The negative values indicate that the significant digits are to the ",
  StyleBox["left",
    FontSlant->"Italic"],
  " of the decimal point."
}], "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[TextData[{
  "Of course, if you need to work with such numbers, you can increase the \
precision with either ",
  StyleBox["N", "MR"],
  " or ",
  StyleBox["SetPrecision", "MR"],
  ". Since almost all of the digits in this particular number are to the \
right of the decimal point, this effectively increases its accuracy."
}], "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[\@2, 100]\^200\)], "Input",
  CellLabel->"In[46]:=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[BoxData[
    \(1.2676506002282294014967032053759999999999999999999999999999999999999999\
9999999999999999999999999999999999999990828288`97.69897000433603*^30\)], \
"Output",
  CellLabel->"Out[46]=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell["Now the result has much greater accuracy.", "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((\@2)\)\^200 - %\)], "Input",
  CellLabel->"In[47]:=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[BoxData[
    \(0``67.59597043793791\)], "Output",
  CellLabel->"Out[47]=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Accuracy[%]\)], "Input",
  CellLabel->"In[48]:=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[BoxData[
    \(67.59597043793791`\)], "Output",
  CellLabel->"Out[48]=",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Computing with different number types", "Subsection",
  CellTags->{"b:36.5", "IPM3.8.3.6", "c:14"}],

Cell[TextData[{
  "When doing computations with numbers, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " tries to work with the most general type of number in the expression at \
hand.",
  " ",
  "For example, when adding two rational numbers, the sum is a rational \
number, unless of course it can be reduced to an integer."
}], "TextFirst",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(34\/21 + 2\/11\)], "Input",
  CellLabel->"In[49]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(416\/231\)], "Output",
  CellLabel->"Out[49]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(3\/4 + 9\/4\)], "Input",
  CellLabel->"In[50]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[50]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[TextData[{
  "But, if one of the terms is a real number, then all computations are done \
using real-number arithmetic \[Dash]",
  StyleBox[" Mathematica",
    FontSlant->"Italic"],
  " works at the lowest precision of the numbers in the expression."
}], "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[10\^100 + 1.3]\)], "Input",
  CellLabel->"In[51]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(MachinePrecision\)], "Output",
  CellLabel->"Out[51]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[TextData[{
  "One point to keep in mind is that when a symbol is present in the \
expression to be computed, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " does not convert the symbol to a machine number. This ability to perform \
",
  StyleBox["symbolic", "TermDefinition"],
  " computations is an extremely important feature that separates ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " from most other computer languages."
}], "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Sin[n\ \[Pi]], n \[Element] Integers]\)], "Input",
  CellLabel->"In[52]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[52]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[Sin[n\ N[\[Pi]]], n \[Element] Integers]\)], "Input",
  CellLabel->"In[53]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(Sin[3.141592653589793`\ n]\)], "Output",
  CellLabel->"Out[53]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell["\<\
When two extended-precision approximate numbers are multiplied, the precision \
of the result will be the minimum of the precision of the two factors.\
\>", "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[N[\@2, 50] N[\@3, 80]]\)], "Input",
  CellLabel->"In[54]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(49.99999999999999`\)], "Output",
  CellLabel->"Out[54]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell["\<\
In fact, whenever two numbers are multiplied, the precision of the product \
will be the minimum of the precision of the factors, even if one factor is a \
machine precision real number and the other factor is a high precision real \
number.\
\>", "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(\(a = N[2];\)\)], "Input",
  CellLabel->"In[55]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(\(b = N[2\^99, 30];\)\)], "Input",
  CellLabel->"In[56]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Precision[a], Precision[b], Precision[a\ b]}\)], "Input",
  CellLabel->"In[57]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \({MachinePrecision, 30.`, MachinePrecision}\)], "Output",
  CellLabel->"Out[57]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[TextData[{
  "For addition of real numbers, it is their ",
  StyleBox["accuracy", "TermDefinition"],
  " that counts most. Recall, ",
  StyleBox["Accuracy", "MR"],
  " gives the number of significant digits to the right of the decimal point. \
In essence, ",
  StyleBox["Accuracy[", "MR"],
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  StyleBox["]", "MR"],
  " measures the absolute error in the number ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \({Accuracy[1.23], Accuracy[12.5]}\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \({15.864684658751605`, 14.857679757182947`}\)], "Output",
  CellLabel->"Out[58]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell["\<\
For machine-precision numbers, adding a digit to the left of the decimal \
point essentially removes one digit from the right of the decimal point. \
These numbers have a fixed number of digits. This is not the case though for \
extended-precision numbers, where all the digits to the right of the decimal \
can be considered significant.\
\>", "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Accuracy[123.4444444444444444444444444444]\)], "Input",
  CellLabel->"In[59]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(28.`\)], "Output",
  CellLabel->"Out[59]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Accuracy[12321.4444444444444444444444444444]\)], "Input",
  CellLabel->"In[60]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(28.000000000000004`\)], "Output",
  CellLabel->"Out[60]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[TextData[{
  "In an analogous manner to the use of ",
  StyleBox["Precision", "MR"],
  " with multiplication, the ",
  StyleBox["Accuracy", "MR"],
  " of an addition will be the minimum of the accuracies of the summands."
}], "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Accuracy[1.23 + 12.3]\)], "Input",
  CellLabel->"In[61]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(14.823291973593381`\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Accuracy[12.3]\)], "Input",
  CellLabel->"In[62]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(14.864684658751605`\)], "Output",
  CellLabel->"Out[62]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell["\<\
This last point can lead to some unexpected results if you are not careful.\
\>", "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(1.0 + 10\^\(-25\)\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(1.`\)], "Output",
  CellLabel->"Out[63]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Accuracy[%]\)], "Input",
  CellLabel->"In[64]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(15.954589770191003`\)], "Output",
  CellLabel->"Out[64]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[TextData[{
  "The number 1.0 is a machine number, so this computation was performed \
using machine accuracy, hence the 1 in the 25th decimal place to the right in \
the number ",
  Cell[BoxData[
      \(TraditionalForm\`10\^\(-25\)\)]],
  " was lost when this computation was performed in machine arithmetic. You \
can avoid machine arithmetic and get the intended result by extending the \
precision of 1.0 to 25 digits."
}], "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(1.0`25 + 10\^\(-25\) // FullForm\)], "Input",
  CellLabel->"In[65]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    TagBox[
      StyleBox["1.0000000000000000000000001`25.",
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[65]//FullForm=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Accuracy[%]\)], "Input",
  CellLabel->"In[66]:=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[BoxData[
    \(24.999999999999996`\)], "Output",
  CellLabel->"Out[66]=",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[BoxData[
    \(\($Line = 0;\)\)], "NonPrintInput",
  CellLabel->"In[67]:=",
  CellTags->"b:36.36"],

Cell["", "SubsectionSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSubsection",
  CellTags->{"b:36.5", "IPM3.8.3.7", "c:15"}],

Cell[CellGroupData[{

Cell[TextData[{
  "Explain why ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " is unable to produce a number with 100 digits of precision in the \
following example."
}], "ExerciseItem",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[1.23, 100]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[BoxData[
    \(1.23`\)], "Output",
  CellLabel->"Out[1]=",
  CellTags->{"b:36.5", "IPM3.8.3.7"}]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Precision[%]\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[BoxData[
    \(MachinePrecision\)], "Output",
  CellLabel->"Out[2]=",
  CellTags->{"b:36.5", "IPM3.8.3.7"}]
}, Open  ]]
}, Open  ]],

Cell[TextData[{
  "Determine what level of precision is necessary when computing ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          RowBox[{
            StyleBox["N",
              "MR",
              FontSlant->"Plain"], 
            StyleBox["[",
              "MR"], 
            RowBox[{
              StyleBox[\(\@2\),
                "MR"], 
              StyleBox[",",
                "MR"], 
              StyleBox["prec",
                "IT"]}], 
            StyleBox["]",
              "MR"]}], "200"], TraditionalForm]]],
  " to produce accuracy in the output of at least 100 digits."
}], "ExerciseItem",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[CellGroupData[{

Cell["\<\
Explain why the following computation produces an unexpected result (that is, \
why the value 0.000000000001 is not returned). \
\>", "ExerciseItem",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(1.0 - 0.999999999999\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[BoxData[
    \(9.999778782798785`*^-13\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"b:36.5", "IPM3.8.3.7"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "How close is the number ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[Pi] \@ 163\)\)],
    FormatType->StandardForm],
  " to an integer? Use ",
  StyleBox["N", "MR"],
  ", but be careful about the precision of your computations."
}], "ExerciseItem",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[BoxData[
    \(\($Line = 0;\)\)], "NonPrintInput",
  CellLabel->"In[4]:="]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Working with arrays of numbers", "Section",
  CounterAssignments->{{"Chapter", 8}, {"Section", 3}},
  CellTags->{"IPM3.8.4.0", "IPM3.8.4.1", "IPM3.8.4.2", "IPM3.8.4.3", "c:16"}],

Cell[TextData[{
  "Scientists, engineers, and anyone who works with numbers typically do so \
in the context of arrays of data. In many applications these arrays can \
become quite large and hence pose special problems when computing with them. \
",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses two special data types to make computations with arrays faster and \
more efficient \[Dash] sparse arrays and packed arrays. In this section we \
will introduce each of these data types and see how a working knowledge of \
them can help you work with very large sets of data."
}], "TextFirst",
  CellTags->{"i:46", "IPM3.8.4.0"}],

Cell["", "SubsectionSpacer"],

Cell[CellGroupData[{

Cell["Sparse arrays", "Subsection",
  CellTags->{"b:37.0", "IPM3.8.4.1", "c:17"}],

Cell[TextData[{
  "In many applications, particularly solving ordinary and partial \
differential equations, optimization problems, and solving large systems of \
equations, it is not uncommon to work with very large matrices that have \
mostly 0s as elements. Such matrices or arrays are referred to as ",
  StyleBox["sparse", "TermDefinition"],
  " and many optimized algorithms have been developed for working with such \
objects. These algorithms allow you to work with arrays that are often \
several orders of magnitude larger than dense arrays and generally at speeds \
that are several orders of magnitude faster."
}], "TextFirst",
  CellTags->{"i:47", "b:37.0", "IPM3.8.4.1"}],

Cell[TextData[{
  "Sparse arrays are created with the ",
  StyleBox["SparseArray", "MR"],
  " function. The first argument to ",
  StyleBox["SparseArray", "MR"],
  " specifies the rules to be used to create the non-0 elements and the \
second argument specifies the dimensions of the array."
}], "Text",
  CellTags->{"i:48", "b:37.0", "IPM3.8.4.1"}],

Cell[TextData[{
  "For example, this creates a ",
  Cell[BoxData[
      \(TraditionalForm\`5\[Cross]5\)]],
  " sparse array object with elements on the diagonal equal to 1."
}], "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(spmat = SparseArray[{i_, i_} \[Rule] 1, {5, 5}]\)], "Input",
  CellLabel->"In[1]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          InterpretationBox[\("<"\[InvisibleSpace]5\[InvisibleSpace]">"\),
            SequenceForm[ "<", 5, ">"],
            Editable->False], ",", \({5, 5}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[1]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[TextData[{
  "Wrapping ",
  StyleBox["Normal", "MR"],
  " around a sparse array object converts it into a list of lists, which can \
then be displayed in a traditional form with ",
  StyleBox["MatrixForm", "MR"],
  "."
}], "Text",
  CellTags->{"i:49", "b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[spmat] // MatrixForm\)], "Input",
  CellLabel->"In[2]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0", "0", "0"},
            {"0", "1", "0", "0", "0"},
            {"0", "0", "1", "0", "0"},
            {"0", "0", "0", "1", "0"},
            {"0", "0", "0", "0", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[2]//MatrixForm=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[TextData[{
  "Here are the rules associated with this sparse array object. Notice that \
in addition to the explicit rules we specified, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " uses the rule ",
  StyleBox["{_,_}\[Rule]0", "MR"],
  " for the default cases; that is, any element not explicitly specified by a \
rule should be set to 0."
}], "Text",
  CellTags->{"i:50", "b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(ArrayRules[spmat]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    \({{1, 1} \[Rule] 1, {2, 2} \[Rule] 1, {3, 3} \[Rule] 1, {4, 4} \[Rule] 
        1, {5, 5} \[Rule] 1, {_, _} \[Rule] 0}\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[TextData[{
  "Using a third argument to ",
  StyleBox["SparseArray", "MR"],
  ", you can specify that the implicit elements are other than 0."
}], "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(spmat2 = SparseArray[{i_, i_} \[Rule] 1, {5, 5}, 13]\)], "Input",
  CellLabel->"In[4]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          InterpretationBox[\("<"\[InvisibleSpace]5\[InvisibleSpace]">"\),
            SequenceForm[ "<", 5, ">"],
            Editable->False], ",", \({5, 5}\), ",", "13"}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[4]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Normal[spmat2] // MatrixForm\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "13", "13", "13", "13"},
            {"13", "1", "13", "13", "13"},
            {"13", "13", "1", "13", "13"},
            {"13", "13", "13", "1", "13"},
            {"13", "13", "13", "13", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[5]//MatrixForm=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell["\<\
Here is a slightly more complicated specification for the rules associated \
with a sparse array. In this example, the diagonal elements are 1, and the \
elements whose vertical and horizontal positions differ by 1 will be 2.\
\>", "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(spmat3 = 
      SparseArray[{{i_, \ i_} \[Rule] 
            1, \(({i_, \ j_}\  /; \ Abs[i - j]\  \[Equal] \ 1)\) \[Rule] 
            2}, {10, 10}]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          InterpretationBox[\("<"\[InvisibleSpace]28\[InvisibleSpace]">"\),
            SequenceForm[ "<", 28, ">"],
            Editable->False], ",", \({10, 10}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[6]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[Normal[spmat3]]\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "2", "0", "0", "0", "0", "0", "0", "0", "0"},
            {"2", "1", "2", "0", "0", "0", "0", "0", "0", "0"},
            {"0", "2", "1", "2", "0", "0", "0", "0", "0", "0"},
            {"0", "0", "2", "1", "2", "0", "0", "0", "0", "0"},
            {"0", "0", "0", "2", "1", "2", "0", "0", "0", "0"},
            {"0", "0", "0", "0", "2", "1", "2", "0", "0", "0"},
            {"0", "0", "0", "0", "0", "2", "1", "2", "0", "0"},
            {"0", "0", "0", "0", "0", "0", "2", "1", "2", "0"},
            {"0", "0", "0", "0", "0", "0", "0", "2", "1", "2"},
            {"0", "0", "0", "0", "0", "0", "0", "0", "2", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[7]//MatrixForm=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[TextData[{
  "Here is a simple pictorial representation of a sparse array using ",
  StyleBox["ArrayPlot", "MR"],
  ". "
}], "Text",
  PageBreakAbove->True,
  CellTags->{"i:51", "b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    \(\(ArrayPlot[spmat3];\)\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell["\<\
Using a larger array, you can clearly see the nature of the \
\[OpenCurlyDoubleQuote]sparseness\[CloseCurlyDoubleQuote] of values.\
\>", "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    \(\(ArrayPlot[
        SparseArray[{i_, j_} /; Abs[i - j] \[LessEqual] 2 \[Rule] 1, {100, 
            100}]];\)\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[TextData[{
  "Let us take a look at some computations with sparse arrays to see how \
speed and memory issues are affected. First we create a ",
  Cell[BoxData[
      \(TraditionalForm\`100000\[Cross]100000\)]],
  " sparse array with random numbers on and just off the diagonal, and 0s \
everywhere else."
}], "Text",
  CellTags->{"i:53", "b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat\  = \ 
      SparseArray[\ {{i_, \ j_}\  /; \ 
              Abs[i - j] \[LessEqual] 2\  \[RuleDelayed] \ 
            Random[]}, \ {10\^5, 10\^5}]\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    TagBox[
      RowBox[{"SparseArray", "[", 
        RowBox[{
          
          InterpretationBox[\("<"\[InvisibleSpace]499994\[InvisibleSpace]">"\)\
,
            SequenceForm[ "<", 499994, ">"],
            Editable->False], ",", \({100000, 100000}\)}], "]"}],
      False,
      Editable->False]], "Output",
  CellLabel->"Out[10]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell["Here is a vector consisting of 100,000 random numbers.", "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    \(\(b\  = \ Table[\ Random[], \ {10\^5}];\)\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell["\<\
First, note the difference in size of this sparse array compared with a dense \
array. The sparse array takes up approximately six megabytes.\
\>", "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(sparseMemory\  = \ N[ByteCount[\ mat]]\ Byte\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    \(6.400304`*^6\ Byte\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell["\<\
The corresponding dense array would require 160 gigabytes to store.\
\>", "TextFirst",
  PageBreakAbove->True,
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(N[10\^5\ 10\^5\ 16]\ Byte\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    \(1.6`*^11\ Byte\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell["\<\
Computations involving this sparse linear system are extremely fast.\
\>", "TextFirst",
  CellTags->{"i:54", "b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\ \(LinearSolve[\ mat, \ b\ ];\)\ ]\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    \({0.8020000000000209`\ Second, Null}\)], "Output",
  CellLabel->"Out[14]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\ \(mat . mat;\)\ ]\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[BoxData[
    \({0.08999999999997499`\ Second, Null}\)], "Output",
  CellLabel->"Out[15]=",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell["", "SubsectionSpacer"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Packed arrays", "Subsection",
  CellTags->{"b:37.1", "IPM3.8.4.2", "c:18"}],

Cell[TextData[{
  "One of the great advantages of the ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " programming language is that it seamlessly handles the administrative \
tasks of dealing with a wide variety of data types. So for example, when you \
perform computations with floating point numbers, ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " determines the type of numbers you are working with and then chooses to \
perform the computation either on your machine\[CloseCurlyQuote]s floating \
point processor (if working with numbers that fit there) or does the \
computation using extended-precision software routines. Similarly \
computations involving integers will be done in hardware or using special \
software routines depending upon the size of the integers relative to your \
machine\[CloseCurlyQuote]s hardware constraints."
}], "TextFirst",
  CellTags->{"i:55", "b:37.1", "IPM3.8.4.2"}],

Cell["\<\
But all this comes at a cost, and the cost involves the administrative \
overhead necessary to determine the appropriate routine and whether to \
perform the computation in hardware or software. For small computations, this \
overhead is not noticeable, but for large computations involving tens of \
thousands of rows and columns of a matrix, say, this overhead could start to \
slow things down.\
\>", "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[TextData[{
  "Fortunately, there is a way to bypass some of this overhead and get \
significant speed improvements together with a smaller memory footprint. The \
technology that does this is referred to as ",
  StyleBox["packed arrays", "TermDefinition"],
  " and they are fairly simple to understand. Whenever possible ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " will represent a list of a single type of machine numbers (integer, real, \
or complex) as an array, in fact, a packed array object. So a matrix \
consisting of all machine real numbers will be represented internally as a \
packed array. This internal representation is transparent to the user."
}], "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[TextData[{
  "Here is a ",
  Cell[BoxData[
      \(TraditionalForm\`1000\[Cross]1000\)]],
  " array consisting of random real numbers. "
}], "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(\(mat = Table[Random[], {1000}, {1000}];\)\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[TextData[{
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " recognizes that this array consists entirely of machine numbers and so it \
",
  StyleBox["packs",
    FontSlant->"Italic"],
  " the array automatically."
}], "Text",
  PageBreakAbove->True,
  CellTags->{"i:56", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Developer`PackedArrayQ[mat]\)], "Input",
  CellLabel->"In[17]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[17]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[TextData[{
  "Let us also create an array that is not packed. We can do this by \
replacing one of the elements in ",
  StyleBox["mat", "MR"],
  " with a number that is not a machine floating point number. Here we \
replace the element in the first row, second column of ",
  StyleBox["mat", "MR"],
  " with a 1."
}], "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(\(mat2 = ReplacePart[mat, 1, {1, 2}];\)\)], "Input",
  CellLabel->"In[18]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Developer`PackedArrayQ[mat2]\)], "Input",
  CellLabel->"In[19]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[19]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell["\<\
The first thing to notice is the memory savings obtained by using packed \
arrays. \
\>", "TextFirst",
  CellTags->{"i:57", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[ByteCount, {mat, mat2}]\)], "Input",
  CellLabel->"In[20]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \({8000060, 20036032}\)], "Output",
  CellLabel->"Out[20]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell["\<\
In this example, it takes 60% less memory to store the packed array over the \
similar unpacked array.\
\>", "TextFirst",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(20036032 - 8000060\)\/20036032 // N\)], "Input",
  CellLabel->"In[21]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(0.6007163494248762`\)], "Output",
  CellLabel->"Out[21]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell["\<\
The time to compute the minimum value is roughly an order of magnitude faster \
for the packed array.\
\>", "TextFirst",
  CellTags->{"i:58", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[Timing[\(Min[#];\)] &, {mat, mat2}]\)], "Input",
  CellLabel->"In[22]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \({{0.009999999999990905`\ Second, Null}, {0.14999999999997726`\ Second, 
        Null}}\)], "Output",
  CellLabel->"Out[22]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell["\<\
Simple arithmetic on such objects is also significantly sped up with packed \
arrays.\
\>", "TextFirst",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(Do[mat + mat, {100}];\)]\)], "Input",
  CellLabel->"In[23]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \({3.816000000000031`\ Second, Null}\)], "Output",
  CellLabel->"Out[23]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Timing[\(Do[mat2 + mat2, {100}];\)]\)], "Input",
  CellLabel->"In[24]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \({59.685`\ Second, Null}\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[TextData[{
  "When packed arrays are used in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", the compiler is invoked, thus generally improving the time it takes for \
the computation to take place. Many of the built-in functions are designed to \
take advantage of the packed array technology. But they do ",
  StyleBox["not",
    FontSlant->"Italic"],
  " invoke the compiler whenever the time it takes to compile is close to the \
running time of the computation itself. There are length limits on many \
common ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions that determine whether the compiler will be used or not. For \
example, the length limit for ",
  StyleBox["Table", "MR"],
  " is 250."
}], "Text",
  CellTags->{"i:59", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m1 = Table[Random[], {249}];\)\), "\[IndentingNewLine]", 
    \(Developer`PackedArrayQ[m1]\)}], "Input",
  CellLabel->"In[25]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[26]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m2 = Table[Random[], {250}];\)\), "\[IndentingNewLine]", 
    \(Developer`PackedArrayQ[m2]\)}], "Input",
  CellLabel->"In[27]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[28]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[TextData[{
  "For ",
  StyleBox["NestList", "MR"],
  ", it is 100 (remember that ",
  StyleBox["NestList[", "MR"],
  StyleBox["f", "IT"],
  StyleBox[",", "MR"],
  StyleBox["init", "IT"],
  StyleBox[",", "MR"],
  StyleBox["n", "IT"],
  StyleBox["]", "MR"],
  " produces a list of ",
  Cell[BoxData[
      \(TraditionalForm\`n + 1\)]],
  " elements because it prepends the initial value to the list of iterates)."
}], "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n1 = NestList[Sin,  .5, 98];\)\), "\[IndentingNewLine]", 
    \(Developer`PackedArrayQ[n1]\)}], "Input",
  CellLabel->"In[29]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(False\)], "Output",
  CellLabel->"Out[30]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(n2 = NestList[Sin,  .5, 99];\)\), "\[IndentingNewLine]", 
    \(Developer`PackedArrayQ[n2]\)}], "Input",
  CellLabel->"In[31]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[32]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[TextData[{
  "These length limits are all system parameters that can be set with ",
  StyleBox["SystemOptions", "MR"],
  "."
}], "TextFirst",
  CellTags->{"i:60", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Developer`SystemOptions["\<CompileOptions\>"]\)], "Input",
  CellLabel->"In[33]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \("CompileOptions" \[Rule] {"ApplyCompileLength" \[Rule] \[Infinity], 
        "ArrayCompileLength" \[Rule] 250, 
        "AutoCompileAllowCoercion" \[Rule] False, 
        "AutoCompileProtectValues" \[Rule] False, 
        "AutomaticCompile" \[Rule] False, 
        "CompileAllowCoercion" \[Rule] True, 
        "CompileConfirmInitializedVariables" \[Rule] True, 
        "CompiledFunctionArgumentCoercionTolerance" \[Rule] 
          2.1072099696478683`, "CompileEvaluateConstants" \[Rule] True, 
        "CompileReportCoercion" \[Rule] False, 
        "CompileReportExternal" \[Rule] False, 
        "CompileReportFailure" \[Rule] False, 
        "CompileValuesLast" \[Rule] True, "FoldCompileLength" \[Rule] 100, 
        "InternalCompileMessages" \[Rule] False, 
        "MapCompileLength" \[Rule] 100, "NestCompileLength" \[Rule] 100, 
        "NumericalAllowExternal" \[Rule] True, 
        "SystemCompileOptimizations" \[Rule] All, 
        "TableCompileLength" \[Rule] 250}\)], "Output",
  CellLabel->"Out[33]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[TextData[{
  "So how do you best take advantage of packed arrays when you write your \
code? First, it is important that you insure that your lists and arrays \
consist of machine numbers ",
  StyleBox["all of the same type",
    FontSlant->"Italic"],
  " \[Dash] integer, real, or complex. In addition, whenever possible, try to \
operate on lists and arrays all at once instead of looping through your \
arrays. Listable operations with packed array input will use the compiler and \
will produce packed array output. Fortunately, many of the commonly used \
functions have this attribute."
}], "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \(\(names = 
        Select[Names["\<System`*\>"], \ 
          MemberQ[Attributes[#], \ Listable] &];\)\)], "Input",
  CellLabel->"In[34]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell["\<\
Here we display a representative sample of the symbols that have this \
attribute.\
\>", "TextFirst",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{

Cell[BoxData[
    \(Take[names, {1, Length[names], 10}]\)], "Input",
  CellLabel->"In[35]:=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[BoxData[
    \({"Abs", "ArcCsc", "Attributes", "BitNot", "Conjugate", "Csch", 
      "EllipticPi", "ExpIntegralE", "Fibonacci", "Hypergeometric0F1", 
      "IntegerDigits", "LegendreQ", "MathieuCharacteristicExponent", 
      "NonNegative", "PolyLog", "Quotient", "Sign", "StringLength", 
      "ToUpperCase"}\)], "Output",
  CellLabel->"Out[35]=",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell["", "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises", "ExerciseSubsection",
  CellTags->{"b:37.1", "IPM3.8.4.3", "c:19"}],

Cell[TextData[{
  "Create a function ",
  StyleBox["RandomSparseArray[", "MR"],
  StyleBox["n", "IT"],
  StyleBox["]", "MR"],
  " that generates an ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]n\)]],
  " sparse array with random numbers along the diagonal."
}], "ExerciseItem",
  CellTags->{"i:61", "b:37.1", "IPM3.8.4.3"}],

Cell[TextData[{
  "Create a function ",
  StyleBox["tridiagonalMatrix[", "MR"],
  StyleBox["n", "IT"],
  StyleBox[",", "MR"],
  StyleBox["p", "IT"],
  StyleBox[",", "MR"],
  StyleBox["q", "IT"],
  StyleBox["]", "MR"],
  " that creates an ",
  Cell[BoxData[
      \(TraditionalForm\`n\[Cross]n\)]],
  " matrix with the integer ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " on the diagonal, the integer ",
  Cell[BoxData[
      \(TraditionalForm\`q\)]],
  " on the upper and lower subdiagonals, and 0s everywhere else."
}], "ExerciseItem",
  CellTags->{"i:62", "b:37.1", "IPM3.8.4.3"}],

Cell[CellGroupData[{

Cell[TextData[{
  "Create a vector ",
  StyleBox["vec", "MR"],
  " consisting of 100,000 random real numbers between 0 and 1. Check that it \
is indeed a packed array by using ",
  StyleBox["Developer`PackedArrayQ", "MR"],
  ". Then replace one element in ",
  StyleBox["vec", "MR"],
  " with an integer. Check that this new vector is not a packed array. \
Finally, perform some memory and timing tests on these two vectors."
}], "ExerciseItem",
  CellTags->{"b:37.1", "IPM3.8.4.3"}],

Cell[BoxData[
    \(\($Line = 0;\)\)], "NonPrintInput",
  CellLabel->"In[85]:="],

Cell["", "SectionSpacer"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Meta-Information", "NonPrintSection"],

Cell[BoxData[
    \(ClearAll["\<Global`*\>"]\)], "NonPrintInput",
  CellLabel->"In[12]:=",
  InitializationCell->True,
  AspectRatioFixed->True],

Cell[BoxData[
    \(\($DefaultFont = {"\<Helvetica\>", 9};\)\)], "NonPrintInput",
  CellLabel->"In[13]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\(Off[General::spell1];\)\)], "NonPrintInput",
  CellLabel->"In[14]:=",
  InitializationCell->True],

Cell[BoxData[
    \(\($Line = 0;\)\)], "NonPrintInput",
  CellLabel->"In[15]:=",
  InitializationCell->True,
  AspectRatioFixed->True]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
AutoGeneratedPackage->None,
ScreenStyleEnvironment->"Working",
PrintingStyleEnvironment->"Production",
WindowToolbars->{},
WindowSize->{568, 608},
WindowMargins->{{-2, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->221,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"An Introduction to Programming with ", 
          StyleBox[ "Mathematica", "IT"]}], "Header"]}, {Cell[ 
        TextData[ {"8 Numerics"}], "Header"], Inherited, Inherited}},
PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
"PrintCellBrackets"->False,
"PrintRegistrationMarks"->False,
"PrintMultipleHorizontalPages"->False,
"FirstPageHeader"->False,
"FacingPages"->True},
TaggingRules:>{"NextIndexingNumber" -> 85, "PaginationCache" -> {{2004, 10, \
8, 11, 32, 28.232776`9.203328495229671}, {221, 221, 221, 221, 221, 221, 221, \
221, 221, 221, 222, 222, 222, 222, 222, 222, 222, 222, 222, 222, 222, 222, \
222, 222, 223, 223, 223, 223, 223, 223, 223, 223, 223, 223, 223, 224, 224, \
224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 224, 225, \
225, 225, 225, 225, 225, 225, 225, 225, 225, 225, 225, 225, 225, 225, 225, \
225, 225, 225, 226, 226, 226, 226, 226, 226, 226, 226, 226, 226, 226, 226, \
226, 226, 226, 227, 227, 227, 227, 227, 227, 227, 227, 227, 227, 227, 227, \
227, 227, 227, 227, 227, 227, 227, 227, 227, 228, 228, 228, 228, 228, 228, \
228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 228, 229, 229, 229, 229, \
229, 229, 229, 229, 229, 229, 229, 229, 229, 229, 229, 230, 230, 230, 230, \
230, 230, 230, 230, 230, 230, 230, 230, 230, 230, 230, 230, 230, 231, 231, \
231, 231, 231, 231, 231, 231, 231, 231, 231, 231, 231, 231, 231, 231, 231, \
231, 232, 232, 232, 232, 232, 232, 232, 232, 232, 232, 232, 232, 232, 232, \
232, 232, 232, 232, 232, 233, 233, 233, 233, 233, 233, 233, 233, 233, 233, \
233, 233, 234, 234, 234, 234, 234, 234, 234, 234, 234, 234, 234, 234, 235, \
235, 235, 235, 235, 235, 235, 235, 235, 235, 235, 235, 235, 236, 236, 236, \
236, 236, 236, 236, 236, 236, 236, 236, 236, 236, 236, 236, 236, 236, 236, \
236, 236, 237, 237, 237, 237, 237, 237, 237, 237, 237, 237, 237, 237, 237, \
237, 237, 237, 237, 237, 238, 238, 238, 238, 238, 238, 238, 238, 238, 238, \
238, 238, 238, 238, 238, 238, 238, 239, 239, 239, 239, 239, 239, 239, 239, \
239, 239, 239, 239, 240, 240, 240, 240, 240, 240, 240, 240, 240, 240, 240, \
240, 240, 240, 240, 240, 240, 240, 240, 241, 241, 241, 241, 241, 241, 241, \
241, 241, 241, 241, 241, 242, 242, 242, 242, 242, 242, 242, 242, 242, 242, \
242, 242, 242, 242, 242, 242, 242, 242, 243, 243, 243, 243, 243, 243, 243, \
243, 243, 243, 243, 243, 243, 243, 243, 243, 243, 243, 244, 244, 244, 244, \
244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, 244, \
244, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, 245, \
245, 245, 245, 245, 245, 245, 245, 246, 246, 246, 246, 246, 246, 246, 246, \
246, 246, 246, 246, 246, 246, 246, 246, 246, 246, 246, 246, 246, 247, 247, \
247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 247, 248, 248, 248, 248, \
248, 248, 248, 248, 248, 248, 248, 248, 249, 249, 249, 249, 249, 249, 249, \
249, 249, 249, 249, 249, 249, 249, 250, 250, 250, 250, 250, 250, 250, 250, \
250, 250, 250, 250, 250, 250, 250, 251, 251, 251, 251, 251, 251, 251, 251, \
251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 251, 252, 252, \
252, 252, 252, 252, 252, 252, 252, 252, 252, 252, 252, 253, 253, 253, 253, \
253, 253, 253, 253, 253, 253, 253, 253, 253, 253, 254, 254, 254, 254, 254, \
254, 254, 254, 254, 254, 254, 254, 254, 254, 254, 254, 255, 255, 255, 255, \
255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 255, 256, 256, 256, \
256, 256, 256, 256, 256, 256, 256, 256, 256, 256, 256, 256, 256, 256, 256, \
256, 256, 257, 257, 257, 257, 257, 257, 257, 257, 257, 257, 258, 258, 258, \
258, 258, 258, 258, 258, 258, 258, 259, 259, 259, 259, 259, 259, 259, 259, \
259, 259, 259, 259, 259, 259, 259, 260, 260, 260, 260, 260, 260, 260, 260, \
260, 260, 260, 260, 260, 260, 260, 260, 260, 260, 261, 261, 261, 261, 261, \
261, 261, 261, 261, 261, 261, 261, 261, 261, 261, 261, 262, 262, 262, 262, \
262, 262, 262, 262, 262, 262, 262, 262, 263, 263, 263, 263, 263, 263, 263, \
263, 263, 263, 263, 263, 263, 264, 264, 264, 264, 264, 264, 264, 264, 264, \
264, 264, 264, 264, 264, 264, 264, 264, 264, 264, 265, 265, 265, 265, 265, \
265, 265, 265, 265, 266, 266, 266, 266, 266, 266, 266, 266, 266, 266, 266, \
266, 266, 266, 266, 267, 267, 267, 267, 268, 268, 268, 268, 268, 268}, \
Automatic}, "IndexEntries" -> {{"i:10", 
  StyleBox[ "Abs", "MR"]}, {"i:10", 
  StyleBox[ "Conjugate", "MR"]}, {"i:11", {"Argument in complex number, ", 
  StyleBox[ "Arg", "MR"]}}, {"i:13", 
  StyleBox[ "NumericQ", "MR"]}, {"i:14", 
  StyleBox[ "NumberQ", "MR"]}, {"i:15", "Digits of numbers"}, {"i:15", 
  StyleBox[ "IntegerDigits", "MR"]}, {"i:16", 
  StyleBox[ "BaseForm", "MR"]}, {"i:18", "Random numbers"}, {"i:18", 
  StyleBox[ "Random", "MR"]}, {"i:2", 
  StyleBox[ 
  "WorkingPrecision", 
    "MR"]}, {"i:20", "Quantile functions"}, {"i:23", "Binary shifts"}, \
{"i:24", "Josephus problem"}, {"i:25", "Linear congruential method"}, \
{"i:26", "Quadratic congruential method"}, {"i:27", "Chi-square test"}, \
{"i:28", "von Neumann, John"}, {"i:30", 
  StyleBox[ "N", "MR"]}, {"i:31", 
  StyleBox[ "Accuracy", "MR"]}, {"i:31", 
  StyleBox[ "Precision", "MR"]}, {"i:32", 
  StyleBox[ 
  "MachinePrecision", "MR"]}, {"i:33", "Machine numbers"}, {"i:33", 
  StyleBox[ 
  "$MachinePrecision", 
    "MR"]}, {"i:36", "Exact numbers"}, {"i:40", "Fixed precision numbers"}, \
{"i:42", 
  StyleBox[ "$MaxMachineNumber", "MR"]}, {"i:42", 
  StyleBox[ 
  "$MinMachineNumber", 
    "MR"]}, {"i:43", "Multiple precision numbers"}, {"i:43", "Variable \
precision numbers"}, {"i:44", 
  StyleBox[ 
  "SetPrecision", 
    "MR"]}, {"i:45", "Roundoff errors"}, {"i:47", "Sparse arrays"}, {"i:48", 
  StyleBox[ 
  "SparseArray", 
    "MR"]}, {"i:5", "Approximate numbers"}, {"i:5", "Floating point \
numbers"}, {"i:50", 
  StyleBox[ "ArrayRules", "MR"]}, {"i:55", "Packed arrays"}, {"i:56", 
  StyleBox[ "PackedArrayQ", "MR"]}, {"i:6", "Complex numbers"}, {"i:60", 
  StyleBox[ "SystemOptions", "MR"]}, {"i:63", 
  StyleBox[ "PrecisionGoal", "MR"]}, {"i:64", 
  StyleBox[ "WorkingPrecision", "MR"]}, {"i:65", 
  StyleBox[ 
  "MaxIterations", "MR"]}, {"i:66", "Monitoring evaluations"}, {"i:66", 
  StyleBox[ "EvaluationMonitor", "MR"]}, {"i:68", 
  StyleBox[ 
  "$RecursionLimit", 
    "MR"]}, {"i:72", "Gaussian elimination"}, {"i:72", "Ill-conditioned \
matrices"}, {"i:73", "Nonsingular matrices"}, {"i:73", "Pivoting"}, {"i:74", \
"Partial pivoting"}, {"i:75", "Ill-conditioned matrices"}, {"i:76", "Hilbert \
matrices"}, {"i:76", "Orthogonal polynomials"}, {"i:8", 
  StyleBox[ "Im", "MR"]}, {"i:8", 
  StyleBox[ 
  "Re", "MR"]}, {"i:80", "Max norm"}, {"i:82", "Condition number of a \
matrix"}, {"i:84", "Scaled pivoting"}, {"i:11", "Complex numbers", "phase \
angle"}, {"i:12", "Complex numbers", "internal representation"}, {"i:13", \
"Numbers", "attributes"}, {"i:15", "Numbers", "digits of"}, {"i:16", \
"Numbers", "bases of"}, {"i:18", "Numbers", "random"}, {"i:19", "Random \
numbers", "alternate distributions"}, {"i:21", "Programs", 
  StyleBox[ 
  "complexToPolar", "MR"]}, {"i:22", "Hayes", "Allan"}, {"i:22", "Programs", 
  StyleBox[ "sumsOfCubes", "MR"]}, {"i:24", "Programs", {
  StyleBox[ 
  "survivor", 
    "MR"], " (to Josephus problem)"}}, {"i:25", "Random number generators", \
"linear congruential"}, {"i:26", "Random number generators", "quadratic \
congruential"}, {"i:27", "Random number generators", "testing"}, {"i:28", \
"Random number generators", "middle-square"}, {"i:29", "Numbers", \
"approximate"}, {"i:3", "Numbers", "types"}, {"i:33", "Numbers", "machine"}, \
{"i:34", "Numbers", "representation of approximate"}, {"i:36", "Numbers", \
"exact vs. approximate"}, {"i:37", "Integers", "machine"}, {"i:37", \
"Integers", "word size"}, {"i:38", "Integers", "extended precision"}, \
{"i:39", "Rational numbers", "representation"}, {"i:4", "Rational numbers", \
"internal representation"}, {"i:40", "Numbers", "fixed precision"}, {"i:41", \
"Numbers", "size limits on machine"}, {"i:43", "Numbers", "multiple \
precision"}, {"i:43", "Numbers", "variable precision"}, {"i:44", "Numbers", \
"setting precision"}, {"i:45", "Numbers", "roundoff error"}, {"i:46", \
"Numbers", "arrays of"}, {"i:47", "Arrays", "sparse"}, {"i:49", "Sparse \
arrays", "representation"}, {"i:5", "Numbers", "approximate"}, {"i:5", \
"Numbers", "real"}, {"i:50", "Sparse arrays", "rules"}, {"i:51", "Sparse \
arrays", "visualizing"}, {"i:53", "Sparse arrays", "memory savings"}, \
{"i:54", "Sparse arrays", "speed improvements"}, {"i:55", "Arrays", \
"packed"}, {"i:56", "Packed arrays", "identifying"}, {"i:57", "Packed \
arrays", "memory savings"}, {"i:58", "Packed arrays", "speed improvements"}, \
{"i:59", "Packed arrays", "working with built-in functions"}, {"i:6", \
"Numbers", "complex"}, {"i:60", "System parameters", "setting"}, {"i:61", \
"Programs", 
  StyleBox[ "RandomSparseArray", "MR"]}, {"i:62", "Programs", 
  StyleBox[ 
  "tridiagonalMatrix", 
    "MR"]}, {"i:67", "Newton\[CloseCurlyQuote]s method", "controlling \
precision and accuracy"}, {"i:67", "Solving equations", "Newton\
\[CloseCurlyQuote]s method"}, {"i:69", "Programs", 
  StyleBox[ 
  "newton", 
    "MR"]}, {"i:7", "Complex numbers", "real and imaginary parts"}, {"i:70", \
"Solving equations", "and symbolic derivatives"}, {"i:71", "Solving \
equations", "secant method"}, {"i:72", "Matrices", "ill-conditioned"}, \
{"i:72", "Solving linear systems", "Gaussian elimination"}, {"i:73", \
"Matrices", "nonsingular"}, {"i:73", "Solving linear systems", "pivoting"}, \
{"i:74", "Programs", 
  StyleBox[ 
  "solvePP", 
    "MR"]}, {"i:75", "Matrices", "ill-conditioned"}, {"i:76", "Matrices", \
"Hilbert"}, {"i:76", "Polynomials", "orthogonal"}, {"i:77", "Programs", 
  StyleBox[ 
  "HilbertMatrix", 
    "MR"]}, {"i:78", "Newton\[CloseCurlyQuote]s method", "accelerating"}, \
{"i:79", "Matrices", "norms"}, {"i:79", "Norms", "definition"}, {"i:79", \
"Norms", "matrix"}, {"i:80", "Norms", "max"}, {"i:80", "Norms", "vector"}, \
{"i:81", "Norms", 
  Cell[ 
    BoxData[ 
      FormBox[ 
        SubscriptBox[ "l", "\[Infinity]"], 
        TraditionalForm]]]}, {"i:82", "Matrices", "condition number"}, \
{"i:83", "Programs", 
  StyleBox[ 
  "conditionNumber", 
    "MR"]}, {"i:84", "Pivoting", "scaled"}, {"i:9", "Complex numbers", \
"conjugate"}, {"i:9", "Complex numbers", "magnitude"}, {"i:1", "van der Pol \
equations", "", ""}, {"i:15", 
  StyleBox[ "RealDigits", "MR"], "", ""}, {"i:17", {
  StyleBox[ "^^", "MR"], " (number base)"}, "", ""}, {"i:35", {
  StyleBox[ 
  "`", "MR"], " (number mark)"}, "", ""}, {"i:35", {"Number mark (", 
  StyleBox[ "`", "MR"], ")"}, "", ""}, {"i:51", 
  StyleBox[ "ArrayPlot", "MR"], "", ""}}},
CellLabelAutoDelete->False,
Magnification->1,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell[TextData[{
    "Style Definitions\n\n",
    StyleBox["An Introduction to Programming with Mathematica, ",
      FontSlant->"Italic"],
    "Third edition"
  }], "Subtitle",
    CellMargins->{{0, 0}, {20, 0}},
    Background->RGBColor[1, 1, 0]],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{12, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    CellLabelMargins->{{24, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->12],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    CellLabelMargins->{{2, Inherited}, {Inherited, Inherited}},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}],
  
  Cell[StyleData[All, "Production"],
    PageWidth->PaperWidth,
    ShowCellBracket->False,
    CellLabelMargins->{{30, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 2},
    ScriptMinSize->5,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the Notebook level.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    StyleMenuListing->None],
  
  Cell[StyleData["Notebook", "Production"],
    PrintingOptions->{"PrintingMargins"->{{54, 54}, {72, 72}},
    "PaperSize"->{Automatic, Automatic},
    "PageSize"->{494, 701},
    "PageHeaderMargins"->{Automatic, Automatic},
    "PageFooterMargins"->{Automatic, Automatic},
    "PaperOrientation"->"Portrait",
    "PrintCellBrackets"->False,
    "PrintSelectionHighlighting"->False,
    "PrintRegistrationMarks"->True,
    "PrintMultipleHorizontalPages"->False,
    "FirstPageHeader"->False,
    "FirstPageFooter"->True,
    "RestPagesHeader"->True,
    "RestPagesFooter"->True,
    "FacingPages"->True,
    "FirstPageFace"->Right,
    "GraphicsPrintingFormat"->"Automatic",
    "PostScriptOutputFile":>"Automatic",
    "UsePostScriptOutputFile"->False,
    "UnixShellPrintingCommand"->Automatic,
    "UseUnixShellPrintingCommand"->False,
    "CellBackgroundHalftoneDensity"->Automatic,
    "CellBackgroundHalftoneAngle"->Automatic},
    CellFrameLabelMargins->6]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Chapter"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {24, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    ConversionRules:>{"TeX" -> {"\\chapter{", "}\n\n"}},
    CellFrameMargins->20,
    LineSpacing->{1, 6},
    CounterIncrements->"Chapter",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Bold",
    Background->RGBColor[0.890196, 0.878431, 0.717647]],
  
  Cell[StyleData["Chapter", "Presentation"],
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Chapter", "Printout"],
    FontSize->22,
    Background->None],
  
  Cell[StyleData["Chapter", "Production"],
    CellMargins->{{0, Inherited}, {36, 18}},
    FontFamily->"Janson Text",
    FontSize->26,
    FontWeight->"Plain",
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    StyleMenuListing->None,
    CounterStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->24],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->36],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18],
  
  Cell[StyleData["Subtitle", "Production"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->18]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    StyleMenuListing->None,
    CounterStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14],
  
  Cell[StyleData["Subsubtitle", "Production"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {0, 15}},
    CellGroupingRules->{"SectionGrouping", 30},
    ConversionRules:>{"TeX" -> {"\\section{", "}\n\n"}},
    PageBreakBelow->False,
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "Chapter"], ".", 
              CounterBox[ "Section"]}], "Section", CellBaseline -> Baseline], 
          None}, {None, None}},
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}, {
        "Exercise", 0}},
    CounterStyleMenuListing->None,
    FontFamily->"Times",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{Inherited, 0}, {7, 18}},
    FontSize->14],
  
  Cell[StyleData["Section", "Production"],
    CellMargins->{{0, 0}, {6, 6}},
    FontFamily->"Janson Text",
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellMargins->{{12, Inherited}, {5, 18}},
    CellGroupingRules->{"SectionGrouping", 40},
    ConversionRules:>{"TeX" -> {"\\subsection{", "}\n\n"}},
    PageBreakBelow->False,
    CounterAssignments->{{"Subsubsection", 0}},
    CounterStyleMenuListing->None,
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{24, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->22],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{40, 0}, {7, 22}},
    FontSize->12],
  
  Cell[StyleData["Subsection", "Production"],
    CellMargins->{{0, 0}, {6, 6}},
    FontFamily->"Janson Text",
    FontSize->11,
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                  BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
                0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
        "MMA"->"Mathematica"},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Subsubsection",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11],
  
  Cell[StyleData["Subsubsection", "Production"],
    CellDingbat->None,
    CellMargins->{{0, 0}, {0, 6}},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitleBar"],
    ShowCellBracket->False,
    CellMargins->{{0, 0}, {0, 0}},
    CellFrameMargins->{{18, 0}, {6, 6}},
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->GrayLevel[0.900008],
    Background->RGBColor[0.501961, 0.501961, 0.752941]],
  
  Cell[StyleData["TitleBar", "Presentation"],
    CellMargins->{{0, 0}, {0, 0}},
    LineSpacing->{1, 0},
    FontSize->14],
  
  Cell[StyleData["TitleBar", "Printout"],
    CellMargins->{{Inherited, Inherited}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["TitleBar", "Production"],
    CellMargins->{{Inherited, Inherited}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphIndent->24,
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{40, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["Text", "Production"],
    CellMargins->{{0, 0}, {0, 0}},
    TextJustification->1,
    LineSpacing->{1, 2},
    ParagraphIndent->24,
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextFirst"],
    CellMargins->{{12, 10}, {7, 7}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["TextFirst", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["TextFirst", "Printout"],
    CellMargins->{{40, 2}, {6, 6}},
    TextJustification->0.5,
    FontSize->10],
  
  Cell[StyleData["TextFirst", "Production"],
    CellMargins->{{0, 0}, {0, 0}},
    TextJustification->1,
    LineSpacing->{1, 2},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedList"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{48, 4}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    ParagraphIndent->0,
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["BulletedList", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["BulletedList", "Printout"],
    CellMargins->{{50, 4}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["BulletedList", "Production"],
    CellMargins->{{24, 4}, {6, 6}},
    LineSpacing->{1, 2},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{26, 4}, {0, 8}},
    CellGroupingRules->{"SectionGrouping", 45},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "ItemNumber"], "."}], "ExerciseItemNumber", 
            CellBaseline -> Baseline], None}, {None, None}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ItemNumber"],
  
  Cell[StyleData["ItemizedText", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["ItemizedText", "Printout"],
    CellMargins->{{20, 4}, {0, 8}},
    FontSize->11],
  
  Cell[StyleData["ItemizedText", "Production"],
    CellMargins->{{14, 0}, {0, 6}},
    LineSpacing->{1, 2},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["BulletedSubItem"],
    CellDingbat->"\[Bullet]",
    CellMargins->{{48, 4}, {6, 6}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    ParagraphIndent->0,
    CounterIncrements->"Text",
    FontFamily->"Times"],
  
  Cell[StyleData["BulletedSubItem", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["BulletedSubItem", "Printout"],
    CellMargins->{{50, 4}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["BulletedSubItem", "Production"],
    CellMargins->{{48, 4}, {0, 6}},
    LineSpacing->{1, 2},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Editorial"],
    CellMargins->{{12, 10}, {6, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->10,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Editorial", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["Editorial", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7,
    FontWeight->"Bold",
    FontColor->GrayLevel[0.500008]],
  
  Cell[StyleData["Editorial", "Production"],
    CellMargins->{{Inherited, Inherited}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapterHeading"],
    CellFrame->{{0, 0}, {1, 0}},
    CellGroupingRules->{"TitleGrouping", 0},
    ConversionRules:>{"TeX" -> {{"", CompoundExpression[ #, ""]&, ""}, {"", 
      CompoundExpression[ #, ""]&, ""}}},
    PageBreakAbove->True,
    CellFrameMargins->False,
    CounterIncrements->"ChapterHeading",
    StyleMenuListing->None,
    CounterStyleMenuListing->None,
    FontSize->30,
    FontWeight->"Bold",
    GridBoxOptions->{ColumnSpacings->0.2,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["ChapterHeading", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["ChapterHeading", "Production"],
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapterHead"],
    CounterIncrements->"ChapterHeading",
    StyleMenuListing->None,
    CounterStyleMenuListing->None,
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["ChapterHead", "Printout"]],
  
  Cell[StyleData["ChapterHead", "Production"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrefaceSection"],
    CellMargins->{{12, Inherited}, {5, 18}},
    CellGroupingRules->{"SectionGrouping", 30},
    StyleMenuListing->None,
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["PrefaceSection", "Presentation"],
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["PrefaceSection", "Printout"],
    CellMargins->{{12, 0}, {7, 22}},
    FontSize->14],
  
  Cell[StyleData["PrefaceSection", "Production"],
    CellMargins->{{0, 0}, {6, 6}},
    FontFamily->"Janson Text",
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapterAbstract"],
    CellMargins->{{40, 100}, {20, 0}},
    TextJustification->1,
    Hyphenation->True,
    LineSpacing->{1, 2},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->11],
  
  Cell[StyleData["ChapterAbstract", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ChapterAbstract", "Printout"],
    TextJustification->1,
    FontSize->10],
  
  Cell[StyleData["ChapterAbstract", "Production"],
    CellMargins->{{24, 30}, {36, 0}},
    TextJustification->1,
    LineSpacing->{1, 1},
    FontFamily->"Janson Text",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Quote"],
    CellMargins->{{36, 36}, {9, 18}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[StyleData["Quote", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["Quote", "Printout"],
    CellMargins->{{20, 4}, {0, 8}},
    ParagraphIndent->-14,
    FontSize->11],
  
  Cell[StyleData["Quote", "Production"],
    CellMargins->{{24, 26}, {7, 7}},
    FontFamily->"Janson Text",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["References"],
    CellMargins->{{20, 10}, {0, 6}},
    DefaultNewInlineCellStyle->"None",
    Hyphenation->True,
    LineSpacing->{1, 3},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12],
  
  Cell[StyleData["References", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->14],
  
  Cell[StyleData["References", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    TextJustification->0.5,
    FontSize->7],
  
  Cell[StyleData["References", "Production"],
    CellMargins->{{0, 2}, {0, 6}},
    TextJustification->0.5,
    FontFamily->"Janson Text",
    FontSize->8.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayTable"],
    CellMargins->{{30, Inherited}, {0, 18}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultTraditionalFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayTable", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayTable", "Printout"],
    FontSize->10],
  
  Cell[StyleData["DisplayTable", "Production"],
    CellMargins->{{24, Inherited}, {0, 12}},
    FontFamily->"Janson Text",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{24, 10}, {6, 6}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{70, 2}, {6, 6}},
    Magnification->0.5],
  
  Cell[StyleData["Picture", "Production"],
    CellMargins->{{36, 2}, {12, 12}},
    Magnification->0.7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["NonPrint Styles", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NonPrintSection"],
    CellMargins->{{25, 4}, {4, 8}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["NonPrintSection", "Presentation"],
    FontSize->20],
  
  Cell[StyleData["NonPrintSection", "Production"],
    CellMargins->{{Inherited, Inherited}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NonPrintInput"],
    CellMargins->{{60, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontSize->14,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["NonPrintInput", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["NonPrintInput", "Production"],
    CellMargins->{{Inherited, Inherited}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->0,
    "ClosedCellHeight"->0},
    CellOpen->False,
    PageBreakAbove->False]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Automatic Numbering", "Section"],
  
  Cell["\<\
The following styles are useful for numbered equations, figures, etc.  They \
automatically give the cell a FrameLabel containing a reference to a \
particular counter, and also increment that counter.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{55, 10}, {0, 10}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    CellMargins->{{55, 55}, {0, 10}},
    FontSize->10],
  
  Cell[StyleData["NumberedEquation", "Production"],
    CellMargins->{{42, 55}, {0, 10}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedFigure"],
    CellMargins->{{52, 4}, {0, 8}},
    PageBreakAbove->False,
    CellFrameLabels->{{Cell[ 
            TextData[ {"Figure ", 
              CounterBox[ "Chapter"], ".", 
              CounterBox[ "NumberedFigure"], ":"}], FontWeight -> "Bold", 
            CellBaseline -> Baseline], None}, {None, None}},
    CounterIncrements->"NumberedFigure",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["NumberedFigure", "Printout"],
    FontSize->8],
  
  Cell[StyleData["NumberedFigure", "Production"],
    CellMargins->{{24, Inherited}, {12, Inherited}},
    FontSize->7.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedTable"],
    CellMargins->{{42, 4}, {0, 8}},
    PageBreakAbove->False,
    CellFrameMargins->8,
    CellFrameLabels->{{Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "Chapter"], ".", 
              CounterBox[ "NumberedTable"], ":"}], FontWeight -> "Bold", 
            CellBaseline -> Baseline], None}, {None, None}},
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["NumberedTable", "Presentation"],
    CellMargins->{{42, 4}, {0, 8}},
    PageBreakAbove->False,
    CellFrameMargins->8,
    CellFrameLabels->{{Cell[ 
            TextData[ {"Table ", 
              CounterBox[ "Chapter"], ".", 
              CounterBox[ "NumberedTable"], ":"}], FontWeight -> "Bold", 
            CellBaseline -> Baseline], None}, {None, None}},
    CounterIncrements->"NumberedTable",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->11],
  
  Cell[StyleData["NumberedTable", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->8],
  
  Cell[StyleData["NumberedTable", "Production"],
    CellMargins->{{24, Inherited}, {12, Inherited}},
    FontSize->7.5]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ProgramListing"],
    CellMargins->{{42, 4}, {12, 6}},
    CellFrameMargins->8,
    CellFrameLabels->{{Cell[ 
            TextData[ {"Program Listing ", 
              CounterBox[ "Chapter"], ".", 
              CounterBox[ "NumberedProgram"], ":"}], FontWeight -> "Bold", 
            CellBaseline -> Baseline], None}, {None, None}},
    CounterIncrements->"NumberedProgram",
    FormatTypeAutoConvert->False,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["ProgramListing", "Printout"],
    CellMargins->{{18, Inherited}, {Inherited, Inherited}},
    FontSize->10],
  
  Cell[StyleData["ProgramListing", "Production"],
    CellMargins->{{24, Inherited}, {12, 0}},
    FontSize->7.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output to the \
kernel.  Be careful when modifying, renaming, or removing these styles, \
because the front end associates special meanings with these style names. \
Some attributes for these styles are actually set in FormatType Styles (in \
the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{60, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{48, 0}, {4, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9],
  
  Cell[StyleData["Input", "Production"],
    CellMargins->{{52, 0}, {3, 6}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{60, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{48, 0}, {6, 4}},
    FontSize->9],
  
  Cell[StyleData["Output", "Production"],
    CellMargins->{{52, 0}, {6, 3}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{60, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontSize->11,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->9,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["Message", "Production"],
    CellMargins->{{52, Inherited}, {6, 3}},
    FontSize->9,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8],
  
  Cell[StyleData["Print", "Production"],
    CellMargins->{{24, Inherited}, {6, 3}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{40, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    LanguageCategory->None,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->10],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    Magnification->0.8],
  
  Cell[StyleData["Graphics", "Production"],
    ImageMargins->{{18, Inherited}, {6, 0}},
    Magnification->0.62]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["CellLabel", "Production"],
    FontFamily->"Helvetica",
    FontSize->7,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Inline Formatting", "Section"],
  
  Cell["\<\
These styles are for modifying individual words or letters in a cell \
exclusive of the cell tag.\
\>", "Text"],
  
  Cell[StyleData["RM"],
    StyleMenuListing->None,
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["BF"],
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[StyleData["IT"],
    StyleMenuListing->None,
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TR"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["TR", "Production"],
    StyleMenuListing->None,
    FontFamily->"Janson Text",
    FontWeight->"Plain",
    FontSlant->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TI", "Production"],
    StyleMenuListing->None,
    FontFamily->"Janson Text",
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TB"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["TB", "Production"],
    StyleMenuListing->None,
    FontFamily->"Janson Text",
    FontWeight->"Bold",
    FontSlant->"Plain"]
  }, Closed]],
  
  Cell[StyleData["TBI"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["MR"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["MO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["MB"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["MBO"],
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SR"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Plain"],
  
  Cell[StyleData["SR", "Production"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9.5,
    FontWeight->"Plain",
    FontSlant->"Plain"]
  }, Closed]],
  
  Cell[StyleData["SO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SB"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Plain"],
  
  Cell[StyleData["SBO"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SO10"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Presentation"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["SO10", "Production"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TermDefinition"],
    FontFamily->"Times",
    FontWeight->"Plain",
    FontSlant->"Italic"],
  
  Cell[StyleData["TermDefinition", "Production"],
    FontFamily->"Janson Text",
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[StyleData["SmallCaps"],
    StyleMenuListing->None,
    FontSize->9],
  
  Cell[StyleData["InputComment"],
    StyleMenuListing->None,
    FontColor->GrayLevel[0.2]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10],
  
  Cell[StyleData["InlineFormula", "Production"],
    CellMargins->{{2, 0}, {6, 6}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{36, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultTraditionalFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    FontSize->10],
  
  Cell[StyleData["DisplayFormula", "Production"],
    CellMargins->{{24, Inherited}, {12, 12}},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellFrame->{{0, 0}, {0.5, 0.5}},
    CellMargins->{{42, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    Hyphenation->False,
    LanguageCategory->"Formula",
    ScriptLevel->1,
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5},
    FontSize->16],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{Inherited, 0}, {6, 6}},
    FontSize->9],
  
  Cell[StyleData["Program", "Production"],
    CellMargins->{{24, 0}, {12, 12}},
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext ButtonBoxes.  The \
\"Hyperlink\" style is for links within the same Notebook, or between \
Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["Hyperlink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line help \
system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MainBookLink", "Production"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["AddOnsLink", "Production"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["RefGuideLink", "Production"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["GettingStartedLink", "Production"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["OtherInformationLink", "Production"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MasterIndexLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MasterIndex", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MasterIndexLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["MasterIndexLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SolutionsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["SolutionsLink", "Presentation"],
    FontSize->16],
  
  Cell[StyleData["SolutionsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}],
  
  Cell[StyleData["SolutionsLink", "Production"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    DefaultNewInlineCellStyle->"None",
    LanguageCategory->"NaturalLanguage",
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->8],
  
  Cell[StyleData["Header", "Production"],
    FontFamily->"Janson Text",
    FontSize->9.5,
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageFooter"],
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->7.5,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageFooter", "Production"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->9.5,
    FontWeight->"Bold"],
  
  Cell[StyleData["PageNumber", "Production"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Janson Text",
    FontSize->9.5,
    FontWeight->"Bold"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard ButtonFunctions, for use \
in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder objects in \
palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Placeholder->True,
    StyleMenuListing->None,
    FontSlant->"Italic",
    FontColor->RGBColor[0.890623, 0.864698, 0.384756],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PrimaryPlaceholder"],
    StyleMenuListing->None,
    DrawHighlighted->True,
    FontSlant->"Italic",
    Background->RGBColor[0.912505, 0.891798, 0.507774],
    TagBoxOptions->{Editable->False,
    Selectable->False,
    StripWrapperBoxes->False}],
  
  Cell[StyleData["PrimaryPlaceholder", "Presentation"]],
  
  Cell[StyleData["PrimaryPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles of most \
cells.  If a cell's FormatType matches the name of one of the styles defined \
below, then that style is applied between the cell's style and its own \
options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    Hyphenation->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    InputAutoReplacements->{},
    AllowInlineCells->False,
    Hyphenation->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    InputAutoReplacements->{
      "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
        ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
        Inherited},
    "TwoByteSyntaxCharacterAutoReplacement"->True,
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an inline cell \
within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Automatic Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are used to affect the display of certain \
types of objects in typeset expressions.  For example, \"UnmatchedBracket\" \
style defines how unmatched bracket, curly bracket, and parenthesis \
characters are displayed (typically by coloring them to make them stand out).\
\
\>", "Text"],
  
  Cell[StyleData["UnmatchedBracket"],
    StyleMenuListing->None,
    FontColor->RGBColor[0.760006, 0.330007, 0.8]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Title Page, Contents, and Index", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsTitle"],
    CellMargins->{{21, 4}, {12, 24}},
    FontFamily->"Times",
    FontSize->24,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsTitle", "Presentation"],
    FontSize->36],
  
  Cell[StyleData["ContentsTitle", "Printout"],
    CellMargins->{{12, 0}, {102, 89}},
    PageBreakBelow->False,
    FontSize->30.5,
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["ContentsTitle", "Production"],
    CellMargins->{{24, 0}, {72, 18}},
    PageBreakBelow->False,
    FontFamily->"Janson Text",
    FontSize->24,
    FontWeight->"Plain"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChapterNum"],
    TextAlignment->Left,
    StyleMenuListing->None,
    CounterStyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["ChapterNum", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ChapterNum", "Printout"],
    FontSize->10],
  
  Cell[StyleData["ChapterNum", "Production"],
    CellSize->{18, Inherited},
    FontFamily->"Janson Text",
    FontSize->12,
    FontWeight->"Bold"]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsChapter"],
    CellMargins->{{36, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "ChapterNum"], " "}], "ChapterNum", CellBaseline -> 
            Baseline], None}, {None, None}},
    CounterIncrements->"ChapterNum",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsChapter", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ContentsChapter", "Printout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["ContentsChapter", "Production"],
    CellMargins->{{2, 0}, {0, 6}},
    PageBreakBelow->False,
    FontFamily->"Janson Text",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsChapterNoNum"],
    CellMargins->{{35, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 70},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["ContentsChapterNoNum", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ContentsChapterNoNum", "Printout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["ContentsChapterNoNum", "Production"],
    CellMargins->{{24, 0}, {0, 6}},
    PageBreakBelow->False,
    FontFamily->"Janson Text",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSection"],
    CellMargins->{{48, 4}, {0, 12}},
    CellGroupingRules->{"SectionGrouping", 80},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->14],
  
  Cell[StyleData["ContentsSection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ContentsSection", "Printout"],
    CellMargins->{{20, 0}, {3, 18}},
    PageBreakBelow->False,
    FontSize->11],
  
  Cell[StyleData["ContentsSection", "Production"],
    CellMargins->{{26, 0}, {0, 6}},
    PageBreakBelow->False,
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Bold"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ContentsSubsection"],
    ShowGroupOpenCloseIcon->False,
    CellMargins->{{50, 4}, {6, 0}},
    CellGroupingRules->{"SectionGrouping", 90},
    StyleMenuListing->None],
  
  Cell[StyleData["ContentsSubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["ContentsSubsection", "Printout"],
    CellMargins->{{40, 4}, {0, 5}},
    FontSize->11],
  
  Cell[StyleData["ContentsSubsection", "Production"],
    CellMargins->{{26, 5}, {0, 0}},
    FontSize->10,
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{20, 4}, {5, 20}},
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["IndexSection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["IndexSection", "Printout"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12],
  
  Cell[StyleData["IndexSection", "Production"],
    CellMargins->{{12, 0}, {5, 20}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index"],
    CellMargins->{{21, 4}, {0, 0}},
    ParagraphIndent->-48,
    StyleMenuListing->None],
  
  Cell[StyleData["Index", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["Index", "Printout"],
    CellMargins->{{13, 0}, {0, 0}},
    FontSize->9],
  
  Cell[StyleData["Index", "Production"],
    CellMargins->{{13, 0}, {0, 0}},
    FontFamily->"Janson Text",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndexSubentry"],
    CellMargins->{{36, 4}, {0, 0}},
    ParagraphIndent->-48],
  
  Cell[StyleData["IndexSubentry", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["IndexSubentry", "Printout"],
    CellMargins->{{24, 0}, {0, 0}},
    FontSize->9],
  
  Cell[StyleData["IndexSubentry", "Production"],
    CellMargins->{{24, 0}, {0, 0}},
    FontFamily->"Janson Text",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Index2Column"],
    CellMargins->{{21, 4}, {0, 8}},
    ParagraphIndent->-20,
    TabSpacings->1,
    StyleMenuListing->None,
    FontSize->10,
    GridBoxOptions->{ColumnWidths->0.5,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["Index2Column", "Presentation"],
    FontSize->15],
  
  Cell[StyleData["Index2Column", "Printout"],
    CellMargins->{{2, 2}, {6, 6}},
    FontSize->8],
  
  Cell[StyleData["Index2Column", "Production"],
    CellMargins->{{2, 2}, {6, 6}},
    FontFamily->"Janson Text",
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RuledPageBreak"],
    CellFrame->{{0, 0}, {0.25, 0}},
    CellMargins->{{27, 4}, {12, 0}},
    CellFrameMargins->{{0, 0}, {1, 0}},
    FontSize->8],
  
  Cell[StyleData["RuledPageBreak", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["RuledPageBreak", "Production"],
    CellFrame->False,
    CellMargins->{{2, 2}, {6, 6}},
    PageBreakBelow->True,
    FontSize->1]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Leader"],
    TabFilling->".",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["Leader", "Printout"],
    FontSize->10],
  
  Cell[StyleData["Leader", "Production"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["LeaderNoDots"],
    TabFilling->" ",
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["LeaderNoDots", "Printout"],
    FontSize->10],
  
  Cell[StyleData["LeaderNoDots", "Production"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["PageLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0.269993, 0.308507, 0.6],
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["PageLink", "Printout"],
    FontColor->GrayLevel[0]],
  
  Cell[StyleData["PageLink", "Production"],
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCPage"],
    CellSize->{22, Inherited},
    TextAlignment->Right,
    StyleMenuListing->None,
    FontSize->12,
    FontWeight->"Plain"],
  
  Cell[StyleData["TOCPage", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCPage", "Printout"],
    FontSize->10],
  
  Cell[StyleData["TOCPage", "Production"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitle"],
    CellMargins->{{20, 0}, {1, 8}},
    CellGroupingRules->{"SectionGrouping", 70},
    TabSpacings->46,
    CounterIncrements->"TOCTitle",
    CounterAssignments->{{"TOCSection", 0}},
    CounterStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12,
    FontWeight->"Bold"],
  
  Cell[StyleData["TOCTitle", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCTitle", "Printout"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    TabSpacings->47.4,
    FontSize->11],
  
  Cell[StyleData["TOCTitle", "Production"],
    CellMargins->{{12, 0}, {1, 8}},
    PageBreakBelow->False,
    TabSpacings->47.4,
    FontSize->11]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSection"],
    CellMargins->{{48, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 75},
    TabSpacings->42.9,
    CounterIncrements->"TOCSection",
    CounterAssignments->{{"TOCSubsection", 0}},
    CounterStyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->12],
  
  Cell[StyleData["TOCSection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCSection", "Printout"],
    CellMargins->{{30, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->12],
  
  Cell[StyleData["TOCSection", "Production"],
    CellMargins->{{30, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsection"],
    CellMargins->{{76, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 80},
    TabSpacings->39.8,
    CounterIncrements->"TOCSubsection",
    CounterAssignments->{{"TOCSubsubsection", 0}},
    CounterStyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["TOCSubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCSubsection", "Printout"],
    CellMargins->{{70, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->10],
  
  Cell[StyleData["TOCSubsection", "Production"],
    CellMargins->{{70, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsubsection"],
    CellMargins->{{104, 0}, {1, 1}},
    CellGroupingRules->{"SectionGrouping", 85},
    TabSpacings->36.7,
    CounterIncrements->"TOCSubsubsection",
    CounterStyleMenuListing->None,
    FontSize->12],
  
  Cell[StyleData["TOCSubsubsection", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TOCSubsubsection", "Printout"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->9],
  
  Cell[StyleData["TOCSubsubsection", "Production"],
    CellMargins->{{96, 0}, {1, 1}},
    PageBreakBelow->False,
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCTitleDingbat"],
    CellSize->{34, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCTitleDingbat", "Production"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSectionDingbat"],
    CellSize->{38, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCSectionDingbat", "Production"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TOCSubsectionDingbat"],
    CellSize->{54, Inherited},
    TextAlignment->Right],
  
  Cell[StyleData["TOCSubsectionDingbat", "Production"],
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitlePageGraphic"],
    CellMargins->{{0, 0}, {100, 20}},
    Evaluatable->False,
    PageBreakBelow->False,
    TextAlignment->Center],
  
  Cell[StyleData["TitlePageGraphic", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TitlePageGraphic", "Printout"],
    CellMargins->{{0, 0}, {230, 88}}],
  
  Cell[StyleData["TitlePageGraphic", "Production"],
    CellMargins->{{0, 0}, {230, 88}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TitlePageLogo"],
    CellMargins->{{0, 0}, {0, 0}}],
  
  Cell[StyleData["TitlePageLogo", "Presentation"],
    FontSize->18],
  
  Cell[StyleData["TitlePageLogo", "Printout"]],
  
  Cell[StyleData["TitlePageLogo", "Production"]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Exercises", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseSubsection"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{12, 0}, {8, 36}},
    CellGroupingRules->{"SectionGrouping", 40},
    LineSpacing->{1, 6},
    LanguageCategory->"NaturalLanguage",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}, {
        "ExerciseItem", 0}, {"ExerciseSubItem", 0}},
    FontFamily->"Times",
    FontSize->16,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  
  Cell[StyleData["ExerciseSubsection", "Presentation"],
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["ExerciseSubsection", "Printout"],
    FontSize->14],
  
  Cell[StyleData["ExerciseSubsection", "Production"],
    CellFrame->{{0, 0}, {0, 0.5}},
    CellMargins->{{4, 0}, {0, 6}},
    PageBreakBelow->False,
    FontFamily->"Janson Text",
    FontSize->12,
    FontWeight->"Bold",
    FontSlant->"Italic",
    FontColor->GrayLevel[0],
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseItem"],
    CellMargins->{{22, 4}, {0, 8}},
    CellGroupingRules->{"SectionGrouping", 45},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "ExerciseItem"], "."}], "ExerciseItemNumber", 
            CellBaseline -> Baseline], None}, {None, None}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExerciseItem"],
  
  Cell[StyleData["ExerciseItem", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->14],
  
  Cell[StyleData["ExerciseItem", "Printout"],
    FontSize->10],
  
  Cell[StyleData["ExerciseItem", "Production"],
    CellMargins->{{-4, 4}, {0, 6}},
    LineSpacing->{1, 2},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseSubItem"],
    CellMargins->{{40, 4}, {0, 8}},
    CellGroupingRules->{"SectionGrouping", 45},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "ExerciseSubItem", CounterFunction -> (Part[ 
                  CharacterRange[ "a", "z"], #]&)], "."}], 
            "ExerciseSubItemNumber", CellBaseline -> Baseline], None}, {
        None, None}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"ExerciseSubItem"],
  
  Cell[StyleData["ExerciseSubItem", "Presentation"],
    LineSpacing->{1, 5},
    FontSize->14],
  
  Cell[StyleData["ExerciseSubItem", "Printout"],
    FontSize->10],
  
  Cell[StyleData["ExerciseSubItem", "Production"],
    CellMargins->{{12, 4}, {2, 4}},
    LineSpacing->{1, 2},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExercisesNoLabel"],
    CellMargins->{{44, 4}, {0, 8}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterStyleMenuListing->None],
  
  Cell[StyleData["ExercisesNoLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["ExercisesNoLabel", "Printout"],
    CellMargins->{{38, 4}, {0, 8}},
    ParagraphIndent->-14,
    FontSize->11],
  
  Cell[StyleData["ExercisesNoLabel", "Production"],
    CellMargins->{{20, 4}, {0, 0}},
    FontFamily->"Janson Text",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseItemNumber"],
    CellSize->{20, Inherited},
    TextAlignment->Right,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExerciseItemNumber", "Printout"],
    FontSize->10],
  
  Cell[StyleData["ExerciseItemNumber", "Production"],
    CellSize->{18, Inherited},
    FontFamily->"Janson Text",
    FontSize->9.5,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ExerciseSubItemNumber"],
    CellSize->{18, Inherited},
    TextAlignment->Right,
    FontWeight->"Bold"],
  
  Cell[StyleData["ExerciseSubItemNumber", "Printout"],
    FontSize->10],
  
  Cell[StyleData["ExerciseSubItemNumber", "Production"],
    FontFamily->"Janson Text",
    FontSize->10,
    FontWeight->"Plain",
    FontSlant->"Italic"]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Solutions", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SolutionsSection"],
    CellDingbat->None,
    CellMargins->{{12, Inherited}, {5, 18}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    FontFamily->"Times",
    FontSize->20,
    FontWeight->"Bold"],
  
  Cell[StyleData["SolutionsSection", "Presentation"],
    CellMargins->{{24, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["SolutionsSection", "Printout"],
    CellMargins->{{Inherited, 0}, {7, 18}},
    FontSize->14],
  
  Cell[StyleData["SolutionsSection", "Production"],
    CellMargins->{{0, 0}, {6, 6}},
    FontFamily->"Janson Text",
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SolutionsSubsection"],
    CellMargins->{{24, 0}, {12, 6}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    DefaultNewInlineCellStyle->"None",
    LineSpacing->{1, 7},
    LanguageCategory->"NaturalLanguage",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}, {
        "SolutionItem", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["SolutionsSubsection", "Presentation"],
    LineSpacing->{1, 0},
    FontSize->16],
  
  Cell[StyleData["SolutionsSubsection", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14],
  
  Cell[StyleData["SolutionsSubsection", "Production"],
    CellMargins->{{0, 0}, {6, 6}},
    FontFamily->"Janson Text",
    FontSize->12]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SolutionItem"],
    CellMargins->{{18, 4}, {0, 8}},
    CellGroupingRules->{"SectionGrouping", 55},
    CellFrameLabels->{{Cell[ 
            TextData[ {
              CounterBox[ "SolutionItem"], "."}], "ExerciseItemNumber", 
            CellBaseline -> Baseline], None}, {None, None}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterIncrements->"SolutionItem"],
  
  Cell[StyleData["SolutionItem", "Presentation"],
    CellMargins->{{22, 4}, {0, 8}},
    FontSize->14],
  
  Cell[StyleData["SolutionItem", "Printout"],
    CellMargins->{{22, 4}, {0, 8}},
    FontSize->10],
  
  Cell[StyleData["SolutionItem", "Production"],
    CellMargins->{{4, 4}, {0, 6}},
    FontFamily->"Janson Text",
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SolutionNoLabel"],
    CellMargins->{{30, 4}, {0, 8}},
    Hyphenation->True,
    LineSpacing->{1, 3},
    ParagraphSpacing->{0, 8},
    CounterStyleMenuListing->None],
  
  Cell[StyleData["SolutionNoLabel", "Presentation"],
    FontSize->14],
  
  Cell[StyleData["SolutionNoLabel", "Printout"],
    CellMargins->{{38, 4}, {0, 8}},
    ParagraphIndent->-14,
    FontSize->11],
  
  Cell[StyleData["SolutionNoLabel", "Production"],
    CellMargins->{{0, 4}, {0, 8}},
    FontFamily->"Janson Text",
    FontSize->9]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Spacer Cells", "Section"],
  
  Cell[StyleData["SectionSpacer", "Working"],
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["SectionSpacer", "Production"],
    CellMargins->{{Inherited, Inherited}, {24, 0}},
    PageBreakAbove->False],
  
  Cell[StyleData["SubsectionSpacer", "Working"],
    CellElementSpacings->{"CellMinHeight"->1,
    "ClosedCellHeight"->0},
    CellOpen->False],
  
  Cell[StyleData["SubsectionSpacer", "Production"],
    CellMargins->{{Inherited, Inherited}, {0, 0}},
    CellElementSpacings->{"CellMinHeight"->0},
    PageBreakAbove->False]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "IPM3.8.0"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[2241, 65, 151, 7, 96, "Chapter",
      CounterAssignments->{{"Chapter", 7}},
      CellTags->{"IPM3.8.0", "c:1"}],
    Cell[2395, 74, 779, 15, 148, "ChapterAbstract",
      CellTags->"IPM3.8.0"]},
  "IPM3.8.1"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[3199, 93, 128, 2, 40, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 0}},
      CellTags->{"b:34", "IPM3.8.1", "c:2"}],
    Cell[3330, 97, 860, 18, 147, "TextFirst",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4193, 117, 254, 6, 52, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4472, 127, 104, 3, 40, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4579, 132, 98, 3, 46, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4714, 140, 106, 3, 40, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4823, 145, 111, 3, 29, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4949, 151, 811, 18, 128, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[5763, 171, 355, 8, 71, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6143, 183, 112, 3, 30, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6258, 188, 108, 3, 29, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6381, 194, 295, 10, 52, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6701, 208, 108, 3, 30, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6812, 213, 111, 3, 29, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6938, 219, 221, 5, 52, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[7184, 228, 104, 3, 30, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[7291, 233, 317, 6, 86, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[7623, 242, 557, 13, 74, "Text",
      CellTags->{"i:1", "b:34", "IPM3.8.1"}],
    Cell[8205, 259, 283, 6, 64, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[8491, 267, 283, 8, 29, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[8789, 278, 408, 9, 71, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[9200, 289, 331, 7, 64, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[9534, 298, 199, 4, 52, "Text",
      CellTags->{"i:2", "b:34", "IPM3.8.1"}],
    Cell[9758, 306, 351, 7, 106, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[10112, 315, 285, 8, 48, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[10412, 326, 240, 6, 52, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[10655, 334, 338, 7, 64, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[10996, 343, 426, 7, 90, "Text",
      CellTags->{"b:34", "IPM3.8.1"}]},
  "IPM3.8.2.1"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[11570, 361, 159, 2, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 1}},
      CellTags->{
      "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", "IPM3.8.2.4", "c:3"}],
    Cell[11754, 367, 83, 1, 44, "Subsection",
      CellTags->{"b:35.0", "IPM3.8.2.1", "c:4"}],
    Cell[11840, 370, 503, 10, 90, "TextFirst",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[12346, 382, 295, 6, 52, "Text",
      CellTags->{"i:3", "b:35.0", "IPM3.8.2.1"}],
    Cell[12666, 392, 143, 3, 42, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[12812, 397, 138, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[12965, 403, 223, 8, 33, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[13213, 415, 147, 3, 42, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[13363, 420, 1067, 34, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[14445, 457, 477, 14, 71, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[14925, 473, 381, 8, 71, "Text",
      CellTags->{"i:4", "b:35.0", "IPM3.8.2.1"}],
    Cell[15331, 485, 141, 3, 46, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[15475, 490, 100, 3, 42, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[15590, 496, 152, 5, 33, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[15767, 505, 151, 3, 42, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[15921, 510, 102, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[16038, 516, 1023, 26, 147, "Text",
      PageBreakAbove->True,
      CellTags->{"i:5", "b:35.0", "IPM3.8.2.1"}],
    Cell[17064, 544, 671, 24, 52, "Text",
      CellTags->{"i:6", "b:35.0", "IPM3.8.2.1"}],
    Cell[17738, 570, 212, 6, 52, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[17975, 580, 119, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18097, 585, 116, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18250, 593, 102, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18355, 598, 103, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18473, 604, 100, 1, 33, "TextFirst",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18598, 609, 122, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18723, 614, 116, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18854, 620, 138, 3, 33, "TextFirst",
      CellTags->{"i:7", "b:35.0", "IPM3.8.2.1"}],
    Cell[19017, 627, 116, 3, 30, "Input",
      CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}],
    Cell[19136, 632, 109, 3, 29, "Output",
      CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}],
    Cell[19260, 638, 325, 6, 71, "Text",
      CellTags->{"i:9", "b:35.0", "IPM3.8.2.1"}],
    Cell[19610, 648, 125, 3, 30, "Input",
      CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}],
    Cell[19738, 653, 129, 3, 29, "Output",
      CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}],
    Cell[19882, 659, 108, 1, 33, "TextFirst",
      CellTags->{"i:11", "b:35.0", "IPM3.8.2.1"}],
    Cell[20015, 664, 117, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[20135, 669, 105, 3, 40, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[20255, 675, 193, 5, 33, "TextFirst",
      PageBreakAbove->True,
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[20451, 682, 122, 2, 22, "NumberedFigure",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[20576, 686, 777, 22, 109, "Text",
      CellTags->{"i:12", "b:35.0", "IPM3.8.2.1"}],
    Cell[21356, 710, 269, 8, 33, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[21650, 722, 125, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[21778, 727, 112, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[21905, 733, 325, 8, 52, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22255, 745, 134, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22392, 750, 115, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22544, 758, 122, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22669, 763, 105, 3, 42, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22789, 769, 285, 8, 52, "Text",
      CellTags->{"i:13", "b:35.0", "IPM3.8.2.1"}],
    Cell[23099, 781, 191, 5, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[23293, 788, 128, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[23436, 794, 561, 13, 90, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24022, 811, 143, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24168, 816, 101, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24306, 824, 128, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24437, 829, 101, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24553, 835, 205, 6, 52, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24783, 845, 131, 3, 30, "Input",
      CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}],
    Cell[24917, 850, 118, 3, 29, "Output",
      CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}]},
  "IPM3.8.2.2"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[11570, 361, 159, 2, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 1}},
      CellTags->{
      "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", "IPM3.8.2.4", "c:3"}],
    Cell[25115, 861, 90, 1, 44, "Subsection",
      CellTags->{"b:35.1", "IPM3.8.2.2", "c:5"}],
    Cell[25208, 864, 235, 7, 52, "TextFirst",
      CellTags->{"i:15", "b:35.1", "IPM3.8.2.2"}],
    Cell[25468, 875, 99, 2, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[25570, 879, 109, 3, 29, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[25716, 887, 121, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[25840, 892, 150, 3, 29, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[26005, 898, 241, 5, 52, "Text",
      CellTags->{"i:16", "b:35.1", "IPM3.8.2.2"}],
    Cell[26271, 907, 95, 2, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[26369, 911, 216, 7, 43, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[26600, 921, 380, 15, 33, "Text",
      CellTags->{"i:17", "b:35.1", "IPM3.8.2.2"}],
    Cell[27005, 940, 104, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[27112, 945, 99, 3, 29, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[27226, 951, 220, 5, 52, "Text",
      PageBreakAbove->True,
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[27471, 960, 130, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[27604, 965, 2979, 104, 48, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[30598, 1072, 188, 4, 52, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[30811, 1080, 120, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[30934, 1085, 247, 7, 43, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[31196, 1095, 492, 13, 71, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[31713, 1112, 119, 3, 21, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[31835, 1117, 279, 5, 44, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32129, 1125, 307, 8, 43, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32439, 1135, 124, 3, 14, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32588, 1142, 117, 3, 21, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32708, 1147, 246, 7, 30, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32969, 1157, 199, 4, 28, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[33193, 1165, 132, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[33328, 1170, 357, 6, 86, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}]},
  "IPM3.8.2.3"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[11570, 361, 159, 2, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 1}},
      CellTags->{
      "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", "IPM3.8.2.4", "c:3"}],
    Cell[33765, 1184, 81, 1, 44, "Subsection",
      CellTags->{"b:35.2", "IPM3.8.2.3", "c:6"}],
    Cell[33849, 1187, 312, 7, 52, "TextFirst",
      CellTags->{"i:18", "b:35.2", "IPM3.8.2.3"}],
    Cell[34164, 1196, 208, 6, 52, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[34397, 1206, 104, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[34504, 1211, 117, 3, 29, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[34636, 1217, 296, 6, 52, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[34957, 1227, 121, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35081, 1232, 99, 3, 29, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35195, 1238, 222, 5, 52, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35420, 1245, 149, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35572, 1250, 292, 8, 52, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35867, 1260, 119, 2, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35989, 1264, 109, 2, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[36101, 1268, 131, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[36235, 1273, 764, 15, 101, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[37002, 1290, 482, 9, 72, "Text",
      CellTags->{"i:19", "b:35.2", "IPM3.8.2.3"}],
    Cell[37487, 1301, 126, 3, 14, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[37616, 1306, 117, 2, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[37736, 1310, 130, 3, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[37891, 1317, 120, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38014, 1322, 121, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38150, 1328, 158, 4, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38333, 1336, 137, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38473, 1341, 319, 6, 32, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38807, 1350, 237, 5, 28, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[39047, 1357, 182, 4, 28, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[39232, 1363, 221, 4, 33, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[39456, 1369, 262, 5, 43, "TextFirst",
      CellTags->{"i:20", "b:35.2", "IPM3.8.2.3"}],
    Cell[39721, 1376, 281, 5, 43, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[40027, 1385, 148, 3, 32, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[40178, 1390, 532, 9, 56, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[40747, 1404, 145, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[40895, 1409, 711, 12, 80, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[41621, 1424, 157, 4, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[41803, 1432, 143, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[41949, 1437, 182, 5, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42146, 1445, 111, 1, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42260, 1448, 139, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42402, 1453, 142, 3, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42569, 1460, 137, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42709, 1465, 548, 9, 67, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}]},
  "IPM3.8.2.4"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[11570, 361, 159, 2, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 1}},
      CellTags->{
      "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", "IPM3.8.2.4", "c:3"}],
    Cell[43543, 1488, 84, 1, 77, "ExerciseSubsection",
      CellTags->{"b:35.2", "IPM3.8.2.4", "c:7"}],
    Cell[43630, 1491, 509, 15, 51, "ExerciseItem",
      CellTags->{"i:21", "b:35.2", "IPM3.8.2.4"}],
    Cell[44164, 1510, 803, 25, 65, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[44992, 1539, 119, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[45114, 1544, 98, 3, 29, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[45283, 1554, 725, 23, 65, "ExerciseItem",
      CellTags->{"i:22", "b:35.2", "IPM3.8.2.4"}],
    Cell[46011, 1579, 742, 18, 103, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[46756, 1599, 93, 1, 27, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[46852, 1602, 450, 17, 27, "ExerciseSubItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[47305, 1621, 365, 13, 27, "ExerciseSubItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[47673, 1636, 454, 17, 20, "ExerciseSubItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[48130, 1655, 355, 13, 20, "ExerciseSubItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[48488, 1670, 547, 21, 20, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49060, 1695, 390, 7, 63, "ExerciseItem",
      CellTags->{"i:23", "b:35.2", "IPM3.8.2.4"}],
    Cell[49475, 1706, 115, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49593, 1711, 111, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49719, 1717, 114, 1, 15, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49858, 1722, 109, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49970, 1727, 111, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50096, 1733, 99, 1, 15, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50220, 1738, 87, 2, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50310, 1742, 98, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50423, 1748, 171, 4, 30, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50653, 1758, 1061, 32, 92, "ExerciseItem",
      CellTags->{"i:24", "b:35.2", "IPM3.8.2.4"}],
    Cell[51717, 1792, 230, 5, 34, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[51950, 1799, 183, 5, 34, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[52158, 1808, 358, 7, 49, "ExerciseItem",
      CellTags->{"i:25", "b:35.2", "IPM3.8.2.4"}],
    Cell[52519, 1817, 193, 4, 36, "DisplayFormula",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[52715, 1823, 759, 28, 31, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[53499, 1855, 104, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[53606, 1860, 97, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[53718, 1866, 593, 18, 61, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[54348, 1889, 1046, 38, 49, "ExerciseItem",
      CellTags->{"i:26", "b:35.2", "IPM3.8.2.4"}],
    Cell[55397, 1929, 209, 4, 36, "DisplayFormula",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[55643, 1938, 1905, 55, 150, "ExerciseItem",
      CellTags->{"i:27", "b:35.2", "IPM3.8.2.4"}],
    Cell[57551, 1995, 252, 5, 46, "DisplayFormula",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[57806, 2002, 557, 17, 46, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[58378, 2022, 489, 16, 46, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[58892, 2042, 985, 18, 160, "ExerciseItem",
      CellTags->{"i:28", "b:35.2", "IPM3.8.2.4"}]},
  "IPM3.8.3.1"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],
    Cell[60321, 2081, 89, 1, 44, "Subsection",
      CellTags->{"b:36.0", "IPM3.8.3.1", "c:9"}],
    Cell[60413, 2084, 505, 11, 90, "TextFirst",
      CellTags->{"i:29", "b:36.0", "IPM3.8.3.1"}],
    Cell[60943, 2099, 125, 3, 30, "Input",
      CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}],
    Cell[61071, 2104, 122, 3, 29, "Output",
      CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}],
    Cell[61208, 2110, 572, 10, 109, "Text",
      CellTags->{"i:31", "b:36.0", "IPM3.8.3.1"}],
    Cell[61805, 2124, 122, 3, 30, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[61930, 2129, 135, 3, 29, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[62080, 2135, 330, 8, 71, "Text",
      CellTags->{"i:32", "b:36.0", "IPM3.8.3.1"}],
    Cell[62435, 2147, 112, 3, 30, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[62550, 2152, 115, 3, 29, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[62680, 2158, 743, 18, 109, "Text",
      CellTags->{"i:33", "b:36.0", "IPM3.8.3.1"}],
    Cell[63448, 2180, 114, 3, 21, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[63565, 2185, 115, 3, 21, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[63695, 2191, 713, 22, 57, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[64433, 2217, 139, 3, 21, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[64575, 2222, 435, 8, 56, "Message",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[65013, 2232, 137, 3, 34, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[65165, 2238, 621, 19, 58, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[65811, 2261, 128, 3, 34, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[65942, 2266, 114, 3, 21, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[66071, 2272, 387, 12, 28, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[66461, 2286, 165, 4, 28, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[66629, 2292, 484, 13, 57, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[67138, 2309, 194, 4, 33, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[67335, 2315, 427, 12, 21, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[67777, 2330, 204, 4, 28, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[68006, 2338, 188, 4, 33, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[68197, 2344, 406, 12, 21, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[68618, 2359, 240, 8, 29, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[68883, 2371, 145, 3, 30, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[69031, 2376, 167, 4, 29, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[69213, 2383, 223, 5, 52, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}]},
  "IPM3.8.3.2"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],
    Cell[69504, 2395, 105, 1, 30, "Subsection",
      CellTags->{"b:36.1", "IPM3.8.3.2", "c:10"}],
    Cell[69612, 2398, 286, 7, 52, "TextFirst",
      CellTags->{"i:34", "b:36.1", "IPM3.8.3.2"}],
    Cell[69923, 2409, 109, 3, 30, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70035, 2414, 115, 3, 29, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70165, 2420, 165, 5, 33, "Text",
      PageBreakAbove->True,
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70355, 2429, 98, 3, 30, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70456, 2434, 115, 3, 29, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70608, 2442, 108, 3, 30, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70719, 2447, 120, 3, 29, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70854, 2453, 297, 8, 52, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[71176, 2465, 108, 3, 30, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[71287, 2470, 265, 8, 43, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[71567, 2481, 348, 10, 52, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[71918, 2493, 446, 9, 90, "Text",
      CellTags->{"i:35", "b:36.1", "IPM3.8.3.2"}],
    Cell[72389, 2506, 108, 3, 21, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[72500, 2511, 152, 3, 21, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[72667, 2517, 197, 4, 28, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[72889, 2525, 107, 3, 21, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[72999, 2530, 301, 8, 30, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[73315, 2541, 224, 7, 29, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[73564, 2552, 111, 3, 21, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[73678, 2557, 113, 3, 21, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[73806, 2563, 922, 23, 116, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}]},
  "IPM3.8.3.3"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],
    Cell[74796, 2593, 97, 1, 30, "Subsection",
      CellTags->{"b:36.2", "IPM3.8.3.3", "c:11"}],
    Cell[74896, 2596, 311, 8, 29, "TextFirst",
      CellTags->{"i:36", "b:36.2", "IPM3.8.3.3"}],
    Cell[75232, 2608, 127, 3, 30, "Input",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[75362, 2613, 123, 3, 21, "Output",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[75500, 2619, 277, 7, 29, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[75802, 2630, 115, 3, 21, "Input",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[75920, 2635, 108, 3, 21, "Output",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[76043, 2641, 216, 4, 28, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[76284, 2649, 131, 3, 30, "Input",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[76418, 2654, 136, 3, 21, "Output",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[76569, 2660, 283, 7, 29, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[77073, 2680, 216, 6, 29, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[77292, 2688, 650, 17, 57, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[77945, 2707, 788, 18, 87, "Text",
      CellTags->{"i:37", "b:36.2", "IPM3.8.3.3"}],
    Cell[78736, 2727, 360, 6, 43, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[79099, 2735, 287, 7, 29, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[79389, 2744, 737, 16, 87, "Text",
      CellTags->{"i:38", "b:36.2", "IPM3.8.3.3"}],
    Cell[80151, 2764, 112, 3, 21, "Input",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[80266, 2769, 414, 7, 124, "Output",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[80695, 2779, 722, 20, 90, "Text",
      CellTags->{"i:39", "b:36.2", "IPM3.8.3.3"}]},
  "IPM3.8.3.4"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],
    Cell[81485, 2806, 104, 1, 30, "Subsection",
      CellTags->{"b:36.3", "IPM3.8.3.4", "c:12"}],
    Cell[81592, 2809, 307, 6, 52, "TextFirst",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[81924, 2819, 131, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[82058, 2824, 121, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[82216, 2832, 166, 4, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[82385, 2838, 123, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[82523, 2844, 774, 15, 128, "Text",
      CellTags->{"i:40", "b:36.3", "IPM3.8.3.4"}],
    Cell[83322, 2863, 113, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[83438, 2868, 116, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[83569, 2874, 256, 5, 52, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[83850, 2883, 104, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[83957, 2888, 120, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84114, 2896, 108, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84225, 2901, 113, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84353, 2907, 261, 6, 52, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84639, 2917, 137, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84779, 2922, 113, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84907, 2928, 144, 3, 14, "Text",
      CellTags->{"i:41", "b:36.3", "IPM3.8.3.4"}],
    Cell[85076, 2935, 134, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[85213, 2940, 150, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[85378, 2946, 528, 12, 57, "Text",
      CellTags->{"i:42", "b:36.3", "IPM3.8.3.4"}],
    Cell[85931, 2962, 106, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86040, 2967, 151, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86228, 2975, 159, 4, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86390, 2981, 191, 4, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86618, 2990, 113, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86734, 2995, 121, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86870, 3001, 812, 16, 101, "Text",
      CellTags->{"i:43", "b:36.3", "IPM3.8.3.4"}],
    Cell[87685, 3019, 788, 19, 87, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[88476, 3040, 622, 13, 72, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[89123, 3057, 129, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[89255, 3062, 136, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[89406, 3068, 799, 17, 101, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90230, 3089, 116, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90349, 3094, 114, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90500, 3102, 123, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90626, 3107, 136, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90777, 3113, 254, 6, 28, "Text",
      CellTags->{"i:44", "b:36.3", "IPM3.8.3.4"}],
    Cell[91056, 3123, 122, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91181, 3128, 152, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91348, 3134, 305, 7, 43, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91678, 3145, 119, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91800, 3150, 173, 4, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91988, 3157, 506, 10, 90, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[92519, 3171, 118, 3, 42, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[92640, 3176, 284, 5, 67, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[92961, 3186, 120, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[93084, 3191, 258, 8, 43, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[93357, 3202, 84, 1, 33, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[93444, 3205, 113, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}]},
  "IPM3.8.3.5"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],
    Cell[93625, 3215, 83, 1, 30, "Subsection",
      CellTags->{"b:36.4", "IPM3.8.3.5", "c:13"}],
    Cell[93711, 3218, 312, 6, 71, "TextFirst",
      CellTags->{"i:45", "b:36.4", "IPM3.8.3.5"}],
    Cell[94026, 3226, 196, 6, 33, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94247, 3236, 107, 3, 34, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94357, 3241, 120, 3, 29, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94492, 3247, 236, 5, 52, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94753, 3256, 112, 3, 25, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94868, 3261, 120, 3, 21, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[95003, 3267, 341, 7, 43, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[95369, 3278, 146, 3, 26, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[95518, 3283, 357, 7, 46, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[95912, 3295, 112, 3, 21, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[96027, 3300, 353, 6, 32, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[96395, 3309, 466, 15, 43, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[96864, 3326, 378, 9, 43, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97267, 3339, 112, 3, 26, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97382, 3344, 241, 5, 33, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97638, 3352, 95, 1, 33, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97758, 3357, 114, 3, 34, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97875, 3362, 117, 3, 29, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[98029, 3370, 107, 3, 30, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[98139, 3375, 115, 3, 29, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}]},
  "IPM3.8.3.6"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],
    Cell[98334, 3386, 105, 1, 30, "Subsection",
      CellTags->{"b:36.5", "IPM3.8.3.6", "c:14"}],
    Cell[98442, 3389, 392, 10, 71, "TextFirst",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[98859, 3403, 110, 3, 42, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[98972, 3408, 105, 3, 42, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99114, 3416, 107, 3, 42, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99224, 3421, 98, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99337, 3427, 305, 7, 52, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99667, 3438, 120, 3, 31, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99790, 3443, 113, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99918, 3449, 504, 13, 90, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[100447, 3466, 142, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[100592, 3471, 98, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[100727, 3479, 145, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[100875, 3484, 123, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101013, 3490, 212, 4, 52, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101250, 3498, 128, 3, 33, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101381, 3503, 115, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101511, 3509, 303, 6, 71, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101817, 3517, 109, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101929, 3522, 117, 3, 31, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[102071, 3529, 141, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[102215, 3534, 139, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[102369, 3540, 518, 16, 71, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[102912, 3560, 128, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103043, 3565, 139, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103197, 3571, 400, 7, 90, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103622, 3582, 138, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103763, 3587, 101, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103901, 3595, 140, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104044, 3600, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104175, 3606, 276, 7, 52, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104476, 3617, 117, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104596, 3622, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104749, 3630, 110, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104862, 3635, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104993, 3641, 137, 3, 33, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105155, 3648, 113, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105271, 3653, 100, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105408, 3661, 107, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105518, 3666, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105649, 3672, 478, 10, 90, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[106152, 3686, 128, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[106283, 3691, 278, 8, 43, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[106598, 3704, 107, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[106708, 3709, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}]},
  "IPM3.8.3.7"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],
    Cell[107010, 3725, 85, 1, 77, "ExerciseSubsection",
      CellTags->{"b:36.5", "IPM3.8.3.7", "c:15"}],
    Cell[107120, 3730, 235, 7, 46, "ExerciseItem",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107380, 3741, 107, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107490, 3746, 101, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107628, 3754, 107, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107738, 3759, 112, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107877, 3766, 671, 22, 46, "ExerciseItem",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[108573, 3792, 197, 4, 46, "ExerciseItem",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[108795, 3800, 115, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[108913, 3805, 119, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[109081, 3814, 325, 9, 50, "ExerciseItem",
      CellTags->{"b:36.5", "IPM3.8.3.7"}]},
  "IPM3.8.4.0"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[109549, 3834, 183, 2, 40, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 3}},
      CellTags->{
      "IPM3.8.4.0", "IPM3.8.4.1", "IPM3.8.4.2", "IPM3.8.4.3", "c:16"}],
    Cell[109735, 3838, 640, 12, 128, "TextFirst",
      CellTags->{"i:46", "IPM3.8.4.0"}]},
  "IPM3.8.4.1"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[109549, 3834, 183, 2, 40, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 3}},
      CellTags->{
      "IPM3.8.4.0", "IPM3.8.4.1", "IPM3.8.4.2", "IPM3.8.4.3", "c:16"}],
    Cell[110431, 3856, 81, 1, 44, "Subsection",
      CellTags->{"b:37.0", "IPM3.8.4.1", "c:17"}],
    Cell[110515, 3859, 685, 11, 128, "TextFirst",
      CellTags->{"i:47", "b:37.0", "IPM3.8.4.1"}],
    Cell[111203, 3872, 349, 8, 71, "Text",
      CellTags->{"i:48", "b:37.0", "IPM3.8.4.1"}],
    Cell[111555, 3882, 223, 6, 33, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[111803, 3892, 142, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[111948, 3897, 358, 10, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[112321, 3910, 281, 8, 49, "Text",
      CellTags->{"i:49", "b:37.0", "IPM3.8.4.1"}],
    Cell[112627, 3922, 122, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[112752, 3927, 539, 15, 103, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[113306, 3945, 416, 10, 68, "Text",
      CellTags->{"i:50", "b:37.0", "IPM3.8.4.1"}],
    Cell[113747, 3959, 112, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[113862, 3964, 213, 4, 48, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114090, 3971, 197, 5, 49, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114312, 3980, 147, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114462, 3985, 369, 10, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114868, 4000, 123, 3, 27, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114994, 4005, 559, 15, 103, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[115568, 4023, 287, 5, 71, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[115880, 4032, 243, 6, 70, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[116126, 4040, 362, 10, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[116525, 4055, 121, 3, 27, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[116649, 4060, 984, 20, 183, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[117648, 4083, 207, 6, 30, "Text",
      PageBreakAbove->True,
      CellTags->{"i:51", "b:37.0", "IPM3.8.4.1"}],
    Cell[117858, 4091, 117, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[117978, 4096, 192, 4, 33, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[118173, 4102, 205, 5, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[118381, 4109, 368, 8, 71, "Text",
      CellTags->{"i:53", "b:37.0", "IPM3.8.4.1"}],
    Cell[118774, 4121, 247, 6, 52, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119024, 4129, 392, 12, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119431, 4144, 108, 1, 30, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119542, 4147, 137, 3, 31, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119682, 4152, 203, 4, 52, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119910, 4160, 140, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120053, 4165, 115, 3, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120183, 4171, 158, 4, 30, "TextFirst",
      PageBreakAbove->True,
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120366, 4179, 121, 3, 31, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120490, 4184, 111, 3, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120616, 4190, 143, 3, 30, "TextFirst",
      CellTags->{"i:54", "b:37.0", "IPM3.8.4.1"}],
    Cell[120784, 4197, 138, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120925, 4202, 132, 3, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[121094, 4210, 122, 3, 27, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[121219, 4215, 133, 3, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}]},
  "IPM3.8.4.2"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[109549, 3834, 183, 2, 40, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 3}},
      CellTags->{
      "IPM3.8.4.0", "IPM3.8.4.1", "IPM3.8.4.2", "IPM3.8.4.3", "c:16"}],
    Cell[121432, 4226, 81, 1, 44, "Subsection",
      CellTags->{"b:37.1", "IPM3.8.4.2", "c:18"}],
    Cell[121516, 4229, 928, 17, 166, "TextFirst",
      CellTags->{"i:55", "b:37.1", "IPM3.8.4.2"}],
    Cell[122447, 4248, 459, 8, 90, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[122909, 4258, 730, 13, 128, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[123642, 4273, 191, 6, 33, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[123836, 4281, 138, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[123977, 4286, 308, 10, 52, "Text",
      PageBreakAbove->True,
      CellTags->{"i:56", "b:37.1", "IPM3.8.4.2"}],
    Cell[124310, 4300, 123, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[124436, 4305, 101, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[124552, 4311, 368, 9, 71, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[124923, 4322, 135, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125083, 4329, 124, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125210, 4334, 102, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125327, 4340, 158, 4, 33, "TextFirst",
      CellTags->{"i:57", "b:37.1", "IPM3.8.4.2"}],
    Cell[125510, 4348, 123, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125636, 4353, 116, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125767, 4359, 169, 4, 33, "TextFirst",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125961, 4367, 133, 3, 42, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126097, 4372, 116, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126228, 4378, 176, 4, 33, "TextFirst",
      CellTags->{"i:58", "b:37.1", "IPM3.8.4.2"}],
    Cell[126429, 4386, 135, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126567, 4391, 183, 4, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126765, 4398, 152, 4, 33, "TextFirst",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126942, 4406, 129, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[127074, 4411, 131, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[127242, 4419, 131, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[127376, 4424, 120, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[127511, 4430, 793, 19, 128, "Text",
      CellTags->{"i:59", "b:37.1", "IPM3.8.4.2"}],
    Cell[128329, 4453, 190, 4, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[128522, 4459, 102, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[128661, 4467, 190, 4, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[128854, 4473, 101, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[128970, 4479, 466, 16, 52, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[129461, 4499, 190, 4, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[129654, 4505, 102, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[129793, 4513, 190, 4, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[129986, 4519, 101, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[130102, 4525, 192, 5, 33, "TextFirst",
      CellTags->{"i:60", "b:37.1", "IPM3.8.4.2"}],
    Cell[130319, 4534, 141, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[130463, 4539, 1077, 20, 257, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[131555, 4562, 647, 12, 128, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[132205, 4576, 198, 5, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[132406, 4583, 149, 4, 33, "TextFirst",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[132580, 4591, 131, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[132714, 4596, 391, 7, 86, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}]},
  "IPM3.8.4.3"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}],
    Cell[109549, 3834, 183, 2, 40, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 3}},
      CellTags->{
      "IPM3.8.4.0", "IPM3.8.4.1", "IPM3.8.4.2", "IPM3.8.4.3", "c:16"}],
    Cell[133185, 4611, 85, 1, 45, "ExerciseSubsection",
      CellTags->{"b:37.1", "IPM3.8.4.3", "c:19"}],
    Cell[133273, 4614, 331, 10, 46, "ExerciseItem",
      CellTags->{"i:61", "b:37.1", "IPM3.8.4.3"}],
    Cell[133607, 4626, 592, 20, 46, "ExerciseItem",
      CellTags->{"i:62", "b:37.1", "IPM3.8.4.3"}],
    Cell[134224, 4650, 483, 11, 84, "ExerciseItem",
      CellTags->{"b:37.1", "IPM3.8.4.3"}]},
  "IPM3.8.5.0"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}]},
  "IPM3.8.5.1"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}]},
  "IPM3.8.5.2"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}]},
  "IPM3.8.5.3"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}]},
  "IPM3.8.5.4"->{
    Cell[1754, 51, 462, 10, 0, "TitleBar",
      CellTags->{
      "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
        "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
        "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
        "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
        "IPM3.8.5.3", "IPM3.8.5.4"}]},
  "c:1"->{
    Cell[2241, 65, 151, 7, 96, "Chapter",
      CounterAssignments->{{"Chapter", 7}},
      CellTags->{"IPM3.8.0", "c:1"}]},
  "b:34"->{
    Cell[3199, 93, 128, 2, 40, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 0}},
      CellTags->{"b:34", "IPM3.8.1", "c:2"}],
    Cell[3330, 97, 860, 18, 147, "TextFirst",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4193, 117, 254, 6, 52, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4472, 127, 104, 3, 40, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4579, 132, 98, 3, 46, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4714, 140, 106, 3, 40, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4823, 145, 111, 3, 29, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[4949, 151, 811, 18, 128, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[5763, 171, 355, 8, 71, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6143, 183, 112, 3, 30, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6258, 188, 108, 3, 29, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6381, 194, 295, 10, 52, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6701, 208, 108, 3, 30, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6812, 213, 111, 3, 29, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[6938, 219, 221, 5, 52, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[7184, 228, 104, 3, 30, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[7291, 233, 317, 6, 86, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[7623, 242, 557, 13, 74, "Text",
      CellTags->{"i:1", "b:34", "IPM3.8.1"}],
    Cell[8205, 259, 283, 6, 64, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[8491, 267, 283, 8, 29, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[8789, 278, 408, 9, 71, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[9200, 289, 331, 7, 64, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[9534, 298, 199, 4, 52, "Text",
      CellTags->{"i:2", "b:34", "IPM3.8.1"}],
    Cell[9758, 306, 351, 7, 106, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[10112, 315, 285, 8, 48, "Output",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[10412, 326, 240, 6, 52, "Text",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[10655, 334, 338, 7, 64, "Input",
      CellTags->{"b:34", "IPM3.8.1"}],
    Cell[10996, 343, 426, 7, 90, "Text",
      CellTags->{"b:34", "IPM3.8.1"}]},
  "c:2"->{
    Cell[3199, 93, 128, 2, 40, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 0}},
      CellTags->{"b:34", "IPM3.8.1", "c:2"}]},
  "i:1"->{
    Cell[7623, 242, 557, 13, 74, "Text",
      CellTags->{"i:1", "b:34", "IPM3.8.1"}]},
  "i:2"->{
    Cell[9534, 298, 199, 4, 52, "Text",
      CellTags->{"i:2", "b:34", "IPM3.8.1"}]},
  "c:3"->{
    Cell[11570, 361, 159, 2, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 1}},
      CellTags->{
      "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", "IPM3.8.2.4", "c:3"}]},
  "b:35.0"->{
    Cell[11754, 367, 83, 1, 44, "Subsection",
      CellTags->{"b:35.0", "IPM3.8.2.1", "c:4"}],
    Cell[11840, 370, 503, 10, 90, "TextFirst",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[12346, 382, 295, 6, 52, "Text",
      CellTags->{"i:3", "b:35.0", "IPM3.8.2.1"}],
    Cell[12666, 392, 143, 3, 42, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[12812, 397, 138, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[12965, 403, 223, 8, 33, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[13213, 415, 147, 3, 42, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[13363, 420, 1067, 34, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[14445, 457, 477, 14, 71, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[14925, 473, 381, 8, 71, "Text",
      CellTags->{"i:4", "b:35.0", "IPM3.8.2.1"}],
    Cell[15331, 485, 141, 3, 46, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[15475, 490, 100, 3, 42, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[15590, 496, 152, 5, 33, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[15767, 505, 151, 3, 42, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[15921, 510, 102, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[16038, 516, 1023, 26, 147, "Text",
      PageBreakAbove->True,
      CellTags->{"i:5", "b:35.0", "IPM3.8.2.1"}],
    Cell[17064, 544, 671, 24, 52, "Text",
      CellTags->{"i:6", "b:35.0", "IPM3.8.2.1"}],
    Cell[17738, 570, 212, 6, 52, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[17975, 580, 119, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18097, 585, 116, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18250, 593, 102, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18355, 598, 103, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18473, 604, 100, 1, 33, "TextFirst",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18598, 609, 122, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18723, 614, 116, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[18854, 620, 138, 3, 33, "TextFirst",
      CellTags->{"i:7", "b:35.0", "IPM3.8.2.1"}],
    Cell[19017, 627, 116, 3, 30, "Input",
      CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}],
    Cell[19136, 632, 109, 3, 29, "Output",
      CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}],
    Cell[19260, 638, 325, 6, 71, "Text",
      CellTags->{"i:9", "b:35.0", "IPM3.8.2.1"}],
    Cell[19610, 648, 125, 3, 30, "Input",
      CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}],
    Cell[19738, 653, 129, 3, 29, "Output",
      CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}],
    Cell[19882, 659, 108, 1, 33, "TextFirst",
      CellTags->{"i:11", "b:35.0", "IPM3.8.2.1"}],
    Cell[20015, 664, 117, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[20135, 669, 105, 3, 40, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[20255, 675, 193, 5, 33, "TextFirst",
      PageBreakAbove->True,
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[20451, 682, 122, 2, 22, "NumberedFigure",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[20576, 686, 777, 22, 109, "Text",
      CellTags->{"i:12", "b:35.0", "IPM3.8.2.1"}],
    Cell[21356, 710, 269, 8, 33, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[21650, 722, 125, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[21778, 727, 112, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[21905, 733, 325, 8, 52, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22255, 745, 134, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22392, 750, 115, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22544, 758, 122, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22669, 763, 105, 3, 42, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[22789, 769, 285, 8, 52, "Text",
      CellTags->{"i:13", "b:35.0", "IPM3.8.2.1"}],
    Cell[23099, 781, 191, 5, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[23293, 788, 128, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[23436, 794, 561, 13, 90, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24022, 811, 143, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24168, 816, 101, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24306, 824, 128, 3, 30, "Input",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24437, 829, 101, 3, 29, "Output",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24553, 835, 205, 6, 52, "Text",
      CellTags->{"b:35.0", "IPM3.8.2.1"}],
    Cell[24783, 845, 131, 3, 30, "Input",
      CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}],
    Cell[24917, 850, 118, 3, 29, "Output",
      CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}]},
  "c:4"->{
    Cell[11754, 367, 83, 1, 44, "Subsection",
      CellTags->{"b:35.0", "IPM3.8.2.1", "c:4"}]},
  "i:3"->{
    Cell[12346, 382, 295, 6, 52, "Text",
      CellTags->{"i:3", "b:35.0", "IPM3.8.2.1"}]},
  "i:4"->{
    Cell[14925, 473, 381, 8, 71, "Text",
      CellTags->{"i:4", "b:35.0", "IPM3.8.2.1"}]},
  "i:5"->{
    Cell[16038, 516, 1023, 26, 147, "Text",
      PageBreakAbove->True,
      CellTags->{"i:5", "b:35.0", "IPM3.8.2.1"}]},
  "i:6"->{
    Cell[17064, 544, 671, 24, 52, "Text",
      CellTags->{"i:6", "b:35.0", "IPM3.8.2.1"}]},
  "i:7"->{
    Cell[18854, 620, 138, 3, 33, "TextFirst",
      CellTags->{"i:7", "b:35.0", "IPM3.8.2.1"}]},
  "i:8"->{
    Cell[19017, 627, 116, 3, 30, "Input",
      CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}],
    Cell[19136, 632, 109, 3, 29, "Output",
      CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}]},
  "i:9"->{
    Cell[19260, 638, 325, 6, 71, "Text",
      CellTags->{"i:9", "b:35.0", "IPM3.8.2.1"}]},
  "i:10"->{
    Cell[19610, 648, 125, 3, 30, "Input",
      CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}],
    Cell[19738, 653, 129, 3, 29, "Output",
      CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}]},
  "i:11"->{
    Cell[19882, 659, 108, 1, 33, "TextFirst",
      CellTags->{"i:11", "b:35.0", "IPM3.8.2.1"}]},
  "i:12"->{
    Cell[20576, 686, 777, 22, 109, "Text",
      CellTags->{"i:12", "b:35.0", "IPM3.8.2.1"}]},
  "i:13"->{
    Cell[22789, 769, 285, 8, 52, "Text",
      CellTags->{"i:13", "b:35.0", "IPM3.8.2.1"}]},
  "i:14"->{
    Cell[24783, 845, 131, 3, 30, "Input",
      CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}],
    Cell[24917, 850, 118, 3, 29, "Output",
      CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}]},
  "b:35.1"->{
    Cell[25115, 861, 90, 1, 44, "Subsection",
      CellTags->{"b:35.1", "IPM3.8.2.2", "c:5"}],
    Cell[25208, 864, 235, 7, 52, "TextFirst",
      CellTags->{"i:15", "b:35.1", "IPM3.8.2.2"}],
    Cell[25468, 875, 99, 2, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[25570, 879, 109, 3, 29, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[25716, 887, 121, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[25840, 892, 150, 3, 29, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[26005, 898, 241, 5, 52, "Text",
      CellTags->{"i:16", "b:35.1", "IPM3.8.2.2"}],
    Cell[26271, 907, 95, 2, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[26369, 911, 216, 7, 43, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[26600, 921, 380, 15, 33, "Text",
      CellTags->{"i:17", "b:35.1", "IPM3.8.2.2"}],
    Cell[27005, 940, 104, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[27112, 945, 99, 3, 29, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[27226, 951, 220, 5, 52, "Text",
      PageBreakAbove->True,
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[27471, 960, 130, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[27604, 965, 2979, 104, 48, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[30598, 1072, 188, 4, 52, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[30811, 1080, 120, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[30934, 1085, 247, 7, 43, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[31196, 1095, 492, 13, 71, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[31713, 1112, 119, 3, 21, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[31835, 1117, 279, 5, 44, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32129, 1125, 307, 8, 43, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32439, 1135, 124, 3, 14, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32588, 1142, 117, 3, 21, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32708, 1147, 246, 7, 30, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[32969, 1157, 199, 4, 28, "Text",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[33193, 1165, 132, 3, 30, "Input",
      CellTags->{"b:35.1", "IPM3.8.2.2"}],
    Cell[33328, 1170, 357, 6, 86, "Output",
      CellTags->{"b:35.1", "IPM3.8.2.2"}]},
  "c:5"->{
    Cell[25115, 861, 90, 1, 44, "Subsection",
      CellTags->{"b:35.1", "IPM3.8.2.2", "c:5"}]},
  "i:15"->{
    Cell[25208, 864, 235, 7, 52, "TextFirst",
      CellTags->{"i:15", "b:35.1", "IPM3.8.2.2"}]},
  "i:16"->{
    Cell[26005, 898, 241, 5, 52, "Text",
      CellTags->{"i:16", "b:35.1", "IPM3.8.2.2"}]},
  "i:17"->{
    Cell[26600, 921, 380, 15, 33, "Text",
      CellTags->{"i:17", "b:35.1", "IPM3.8.2.2"}]},
  "b:35.2"->{
    Cell[33765, 1184, 81, 1, 44, "Subsection",
      CellTags->{"b:35.2", "IPM3.8.2.3", "c:6"}],
    Cell[33849, 1187, 312, 7, 52, "TextFirst",
      CellTags->{"i:18", "b:35.2", "IPM3.8.2.3"}],
    Cell[34164, 1196, 208, 6, 52, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[34397, 1206, 104, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[34504, 1211, 117, 3, 29, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[34636, 1217, 296, 6, 52, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[34957, 1227, 121, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35081, 1232, 99, 3, 29, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35195, 1238, 222, 5, 52, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35420, 1245, 149, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35572, 1250, 292, 8, 52, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35867, 1260, 119, 2, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[35989, 1264, 109, 2, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[36101, 1268, 131, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[36235, 1273, 764, 15, 101, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[37002, 1290, 482, 9, 72, "Text",
      CellTags->{"i:19", "b:35.2", "IPM3.8.2.3"}],
    Cell[37487, 1301, 126, 3, 14, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[37616, 1306, 117, 2, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[37736, 1310, 130, 3, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[37891, 1317, 120, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38014, 1322, 121, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38150, 1328, 158, 4, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38333, 1336, 137, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38473, 1341, 319, 6, 32, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[38807, 1350, 237, 5, 28, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[39047, 1357, 182, 4, 28, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[39232, 1363, 221, 4, 33, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[39456, 1369, 262, 5, 43, "TextFirst",
      CellTags->{"i:20", "b:35.2", "IPM3.8.2.3"}],
    Cell[39721, 1376, 281, 5, 43, "Text",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[40027, 1385, 148, 3, 32, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[40178, 1390, 532, 9, 56, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[40747, 1404, 145, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[40895, 1409, 711, 12, 80, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[41621, 1424, 157, 4, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[41803, 1432, 143, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[41949, 1437, 182, 5, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42146, 1445, 111, 1, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42260, 1448, 139, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42402, 1453, 142, 3, 14, "TextFirst",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42569, 1460, 137, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[42709, 1465, 548, 9, 67, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.3"}],
    Cell[43543, 1488, 84, 1, 77, "ExerciseSubsection",
      CellTags->{"b:35.2", "IPM3.8.2.4", "c:7"}],
    Cell[43630, 1491, 509, 15, 51, "ExerciseItem",
      CellTags->{"i:21", "b:35.2", "IPM3.8.2.4"}],
    Cell[44164, 1510, 803, 25, 65, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[44992, 1539, 119, 3, 30, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[45114, 1544, 98, 3, 29, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[45283, 1554, 725, 23, 65, "ExerciseItem",
      CellTags->{"i:22", "b:35.2", "IPM3.8.2.4"}],
    Cell[46011, 1579, 742, 18, 103, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[46756, 1599, 93, 1, 27, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[46852, 1602, 450, 17, 27, "ExerciseSubItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[47305, 1621, 365, 13, 27, "ExerciseSubItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[47673, 1636, 454, 17, 20, "ExerciseSubItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[48130, 1655, 355, 13, 20, "ExerciseSubItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[48488, 1670, 547, 21, 20, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49060, 1695, 390, 7, 63, "ExerciseItem",
      CellTags->{"i:23", "b:35.2", "IPM3.8.2.4"}],
    Cell[49475, 1706, 115, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49593, 1711, 111, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49719, 1717, 114, 1, 15, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49858, 1722, 109, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[49970, 1727, 111, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50096, 1733, 99, 1, 15, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50220, 1738, 87, 2, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50310, 1742, 98, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50423, 1748, 171, 4, 30, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[50653, 1758, 1061, 32, 92, "ExerciseItem",
      CellTags->{"i:24", "b:35.2", "IPM3.8.2.4"}],
    Cell[51717, 1792, 230, 5, 34, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[51950, 1799, 183, 5, 34, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[52158, 1808, 358, 7, 49, "ExerciseItem",
      CellTags->{"i:25", "b:35.2", "IPM3.8.2.4"}],
    Cell[52519, 1817, 193, 4, 36, "DisplayFormula",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[52715, 1823, 759, 28, 31, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[53499, 1855, 104, 3, 21, "Input",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[53606, 1860, 97, 3, 21, "Output",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[53718, 1866, 593, 18, 61, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[54348, 1889, 1046, 38, 49, "ExerciseItem",
      CellTags->{"i:26", "b:35.2", "IPM3.8.2.4"}],
    Cell[55397, 1929, 209, 4, 36, "DisplayFormula",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[55643, 1938, 1905, 55, 150, "ExerciseItem",
      CellTags->{"i:27", "b:35.2", "IPM3.8.2.4"}],
    Cell[57551, 1995, 252, 5, 46, "DisplayFormula",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[57806, 2002, 557, 17, 46, "ExercisesNoLabel",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[58378, 2022, 489, 16, 46, "ExerciseItem",
      CellTags->{"b:35.2", "IPM3.8.2.4"}],
    Cell[58892, 2042, 985, 18, 160, "ExerciseItem",
      CellTags->{"i:28", "b:35.2", "IPM3.8.2.4"}]},
  "c:6"->{
    Cell[33765, 1184, 81, 1, 44, "Subsection",
      CellTags->{"b:35.2", "IPM3.8.2.3", "c:6"}]},
  "i:18"->{
    Cell[33849, 1187, 312, 7, 52, "TextFirst",
      CellTags->{"i:18", "b:35.2", "IPM3.8.2.3"}]},
  "i:19"->{
    Cell[37002, 1290, 482, 9, 72, "Text",
      CellTags->{"i:19", "b:35.2", "IPM3.8.2.3"}]},
  "i:20"->{
    Cell[39456, 1369, 262, 5, 43, "TextFirst",
      CellTags->{"i:20", "b:35.2", "IPM3.8.2.3"}]},
  "c:7"->{
    Cell[43543, 1488, 84, 1, 77, "ExerciseSubsection",
      CellTags->{"b:35.2", "IPM3.8.2.4", "c:7"}]},
  "i:21"->{
    Cell[43630, 1491, 509, 15, 51, "ExerciseItem",
      CellTags->{"i:21", "b:35.2", "IPM3.8.2.4"}]},
  "i:22"->{
    Cell[45283, 1554, 725, 23, 65, "ExerciseItem",
      CellTags->{"i:22", "b:35.2", "IPM3.8.2.4"}]},
  "i:23"->{
    Cell[49060, 1695, 390, 7, 63, "ExerciseItem",
      CellTags->{"i:23", "b:35.2", "IPM3.8.2.4"}]},
  "i:24"->{
    Cell[50653, 1758, 1061, 32, 92, "ExerciseItem",
      CellTags->{"i:24", "b:35.2", "IPM3.8.2.4"}]},
  "i:25"->{
    Cell[52158, 1808, 358, 7, 49, "ExerciseItem",
      CellTags->{"i:25", "b:35.2", "IPM3.8.2.4"}]},
  "i:26"->{
    Cell[54348, 1889, 1046, 38, 49, "ExerciseItem",
      CellTags->{"i:26", "b:35.2", "IPM3.8.2.4"}]},
  "i:27"->{
    Cell[55643, 1938, 1905, 55, 150, "ExerciseItem",
      CellTags->{"i:27", "b:35.2", "IPM3.8.2.4"}]},
  "i:28"->{
    Cell[58892, 2042, 985, 18, 160, "ExerciseItem",
      CellTags->{"i:28", "b:35.2", "IPM3.8.2.4"}]},
  "c:8"->{
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}]},
  "Sec.WorkingWithNumbers"->{
    Cell[60048, 2073, 248, 4, 29, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
      CellTags->{
      "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
        "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}]},
  "b:36.0"->{
    Cell[60321, 2081, 89, 1, 44, "Subsection",
      CellTags->{"b:36.0", "IPM3.8.3.1", "c:9"}],
    Cell[60413, 2084, 505, 11, 90, "TextFirst",
      CellTags->{"i:29", "b:36.0", "IPM3.8.3.1"}],
    Cell[60943, 2099, 125, 3, 30, "Input",
      CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}],
    Cell[61071, 2104, 122, 3, 29, "Output",
      CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}],
    Cell[61208, 2110, 572, 10, 109, "Text",
      CellTags->{"i:31", "b:36.0", "IPM3.8.3.1"}],
    Cell[61805, 2124, 122, 3, 30, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[61930, 2129, 135, 3, 29, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[62080, 2135, 330, 8, 71, "Text",
      CellTags->{"i:32", "b:36.0", "IPM3.8.3.1"}],
    Cell[62435, 2147, 112, 3, 30, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[62550, 2152, 115, 3, 29, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[62680, 2158, 743, 18, 109, "Text",
      CellTags->{"i:33", "b:36.0", "IPM3.8.3.1"}],
    Cell[63448, 2180, 114, 3, 21, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[63565, 2185, 115, 3, 21, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[63695, 2191, 713, 22, 57, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[64433, 2217, 139, 3, 21, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[64575, 2222, 435, 8, 56, "Message",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[65013, 2232, 137, 3, 34, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[65165, 2238, 621, 19, 58, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[65811, 2261, 128, 3, 34, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[65942, 2266, 114, 3, 21, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[66071, 2272, 387, 12, 28, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[66461, 2286, 165, 4, 28, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[66629, 2292, 484, 13, 57, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[67138, 2309, 194, 4, 33, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[67335, 2315, 427, 12, 21, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[67777, 2330, 204, 4, 28, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[68006, 2338, 188, 4, 33, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[68197, 2344, 406, 12, 21, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[68618, 2359, 240, 8, 29, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[68883, 2371, 145, 3, 30, "Input",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[69031, 2376, 167, 4, 29, "Output",
      CellTags->{"b:36.0", "IPM3.8.3.1"}],
    Cell[69213, 2383, 223, 5, 52, "Text",
      CellTags->{"b:36.0", "IPM3.8.3.1"}]},
  "c:9"->{
    Cell[60321, 2081, 89, 1, 44, "Subsection",
      CellTags->{"b:36.0", "IPM3.8.3.1", "c:9"}]},
  "i:29"->{
    Cell[60413, 2084, 505, 11, 90, "TextFirst",
      CellTags->{"i:29", "b:36.0", "IPM3.8.3.1"}]},
  "i:30"->{
    Cell[60943, 2099, 125, 3, 30, "Input",
      CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}],
    Cell[61071, 2104, 122, 3, 29, "Output",
      CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}]},
  "i:31"->{
    Cell[61208, 2110, 572, 10, 109, "Text",
      CellTags->{"i:31", "b:36.0", "IPM3.8.3.1"}]},
  "i:32"->{
    Cell[62080, 2135, 330, 8, 71, "Text",
      CellTags->{"i:32", "b:36.0", "IPM3.8.3.1"}]},
  "i:33"->{
    Cell[62680, 2158, 743, 18, 109, "Text",
      CellTags->{"i:33", "b:36.0", "IPM3.8.3.1"}]},
  "b:36.1"->{
    Cell[69504, 2395, 105, 1, 30, "Subsection",
      CellTags->{"b:36.1", "IPM3.8.3.2", "c:10"}],
    Cell[69612, 2398, 286, 7, 52, "TextFirst",
      CellTags->{"i:34", "b:36.1", "IPM3.8.3.2"}],
    Cell[69923, 2409, 109, 3, 30, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70035, 2414, 115, 3, 29, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70165, 2420, 165, 5, 33, "Text",
      PageBreakAbove->True,
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70355, 2429, 98, 3, 30, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70456, 2434, 115, 3, 29, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70608, 2442, 108, 3, 30, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70719, 2447, 120, 3, 29, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[70854, 2453, 297, 8, 52, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[71176, 2465, 108, 3, 30, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[71287, 2470, 265, 8, 43, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[71567, 2481, 348, 10, 52, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[71918, 2493, 446, 9, 90, "Text",
      CellTags->{"i:35", "b:36.1", "IPM3.8.3.2"}],
    Cell[72389, 2506, 108, 3, 21, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[72500, 2511, 152, 3, 21, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[72667, 2517, 197, 4, 28, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[72889, 2525, 107, 3, 21, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[72999, 2530, 301, 8, 30, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[73315, 2541, 224, 7, 29, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[73564, 2552, 111, 3, 21, "Input",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[73678, 2557, 113, 3, 21, "Output",
      CellTags->{"b:36.1", "IPM3.8.3.2"}],
    Cell[73806, 2563, 922, 23, 116, "Text",
      CellTags->{"b:36.1", "IPM3.8.3.2"}]},
  "c:10"->{
    Cell[69504, 2395, 105, 1, 30, "Subsection",
      CellTags->{"b:36.1", "IPM3.8.3.2", "c:10"}]},
  "i:34"->{
    Cell[69612, 2398, 286, 7, 52, "TextFirst",
      CellTags->{"i:34", "b:36.1", "IPM3.8.3.2"}]},
  "i:35"->{
    Cell[71918, 2493, 446, 9, 90, "Text",
      CellTags->{"i:35", "b:36.1", "IPM3.8.3.2"}]},
  "b:36.2"->{
    Cell[74796, 2593, 97, 1, 30, "Subsection",
      CellTags->{"b:36.2", "IPM3.8.3.3", "c:11"}],
    Cell[74896, 2596, 311, 8, 29, "TextFirst",
      CellTags->{"i:36", "b:36.2", "IPM3.8.3.3"}],
    Cell[75232, 2608, 127, 3, 30, "Input",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[75362, 2613, 123, 3, 21, "Output",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[75500, 2619, 277, 7, 29, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[75802, 2630, 115, 3, 21, "Input",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[75920, 2635, 108, 3, 21, "Output",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[76043, 2641, 216, 4, 28, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[76284, 2649, 131, 3, 30, "Input",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[76418, 2654, 136, 3, 21, "Output",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[76569, 2660, 283, 7, 29, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[77073, 2680, 216, 6, 29, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[77292, 2688, 650, 17, 57, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[77945, 2707, 788, 18, 87, "Text",
      CellTags->{"i:37", "b:36.2", "IPM3.8.3.3"}],
    Cell[78736, 2727, 360, 6, 43, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[79099, 2735, 287, 7, 29, "Text",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[79389, 2744, 737, 16, 87, "Text",
      CellTags->{"i:38", "b:36.2", "IPM3.8.3.3"}],
    Cell[80151, 2764, 112, 3, 21, "Input",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[80266, 2769, 414, 7, 124, "Output",
      CellTags->{"b:36.2", "IPM3.8.3.3"}],
    Cell[80695, 2779, 722, 20, 90, "Text",
      CellTags->{"i:39", "b:36.2", "IPM3.8.3.3"}]},
  "c:11"->{
    Cell[74796, 2593, 97, 1, 30, "Subsection",
      CellTags->{"b:36.2", "IPM3.8.3.3", "c:11"}]},
  "i:36"->{
    Cell[74896, 2596, 311, 8, 29, "TextFirst",
      CellTags->{"i:36", "b:36.2", "IPM3.8.3.3"}]},
  "i:37"->{
    Cell[77945, 2707, 788, 18, 87, "Text",
      CellTags->{"i:37", "b:36.2", "IPM3.8.3.3"}]},
  "i:38"->{
    Cell[79389, 2744, 737, 16, 87, "Text",
      CellTags->{"i:38", "b:36.2", "IPM3.8.3.3"}]},
  "i:39"->{
    Cell[80695, 2779, 722, 20, 90, "Text",
      CellTags->{"i:39", "b:36.2", "IPM3.8.3.3"}]},
  "b:36.3"->{
    Cell[81485, 2806, 104, 1, 30, "Subsection",
      CellTags->{"b:36.3", "IPM3.8.3.4", "c:12"}],
    Cell[81592, 2809, 307, 6, 52, "TextFirst",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[81924, 2819, 131, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[82058, 2824, 121, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[82216, 2832, 166, 4, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[82385, 2838, 123, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[82523, 2844, 774, 15, 128, "Text",
      CellTags->{"i:40", "b:36.3", "IPM3.8.3.4"}],
    Cell[83322, 2863, 113, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[83438, 2868, 116, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[83569, 2874, 256, 5, 52, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[83850, 2883, 104, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[83957, 2888, 120, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84114, 2896, 108, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84225, 2901, 113, 3, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84353, 2907, 261, 6, 52, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84639, 2917, 137, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84779, 2922, 113, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[84907, 2928, 144, 3, 14, "Text",
      CellTags->{"i:41", "b:36.3", "IPM3.8.3.4"}],
    Cell[85076, 2935, 134, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[85213, 2940, 150, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[85378, 2946, 528, 12, 57, "Text",
      CellTags->{"i:42", "b:36.3", "IPM3.8.3.4"}],
    Cell[85931, 2962, 106, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86040, 2967, 151, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86228, 2975, 159, 4, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86390, 2981, 191, 4, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86618, 2990, 113, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86734, 2995, 121, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[86870, 3001, 812, 16, 101, "Text",
      CellTags->{"i:43", "b:36.3", "IPM3.8.3.4"}],
    Cell[87685, 3019, 788, 19, 87, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[88476, 3040, 622, 13, 72, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[89123, 3057, 129, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[89255, 3062, 136, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[89406, 3068, 799, 17, 101, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90230, 3089, 116, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90349, 3094, 114, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90500, 3102, 123, 3, 21, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90626, 3107, 136, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[90777, 3113, 254, 6, 28, "Text",
      CellTags->{"i:44", "b:36.3", "IPM3.8.3.4"}],
    Cell[91056, 3123, 122, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91181, 3128, 152, 3, 21, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91348, 3134, 305, 7, 43, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91678, 3145, 119, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91800, 3150, 173, 4, 29, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[91988, 3157, 506, 10, 90, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[92519, 3171, 118, 3, 42, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[92640, 3176, 284, 5, 67, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[92961, 3186, 120, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[93084, 3191, 258, 8, 43, "Output",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[93357, 3202, 84, 1, 33, "Text",
      CellTags->{"b:36.3", "IPM3.8.3.4"}],
    Cell[93444, 3205, 113, 3, 30, "Input",
      CellTags->{"b:36.3", "IPM3.8.3.4"}]},
  "c:12"->{
    Cell[81485, 2806, 104, 1, 30, "Subsection",
      CellTags->{"b:36.3", "IPM3.8.3.4", "c:12"}]},
  "i:40"->{
    Cell[82523, 2844, 774, 15, 128, "Text",
      CellTags->{"i:40", "b:36.3", "IPM3.8.3.4"}]},
  "i:41"->{
    Cell[84907, 2928, 144, 3, 14, "Text",
      CellTags->{"i:41", "b:36.3", "IPM3.8.3.4"}]},
  "i:42"->{
    Cell[85378, 2946, 528, 12, 57, "Text",
      CellTags->{"i:42", "b:36.3", "IPM3.8.3.4"}]},
  "i:43"->{
    Cell[86870, 3001, 812, 16, 101, "Text",
      CellTags->{"i:43", "b:36.3", "IPM3.8.3.4"}]},
  "i:44"->{
    Cell[90777, 3113, 254, 6, 28, "Text",
      CellTags->{"i:44", "b:36.3", "IPM3.8.3.4"}]},
  "b:36.4"->{
    Cell[93625, 3215, 83, 1, 30, "Subsection",
      CellTags->{"b:36.4", "IPM3.8.3.5", "c:13"}],
    Cell[93711, 3218, 312, 6, 71, "TextFirst",
      CellTags->{"i:45", "b:36.4", "IPM3.8.3.5"}],
    Cell[94026, 3226, 196, 6, 33, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94247, 3236, 107, 3, 34, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94357, 3241, 120, 3, 29, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94492, 3247, 236, 5, 52, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94753, 3256, 112, 3, 25, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[94868, 3261, 120, 3, 21, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[95003, 3267, 341, 7, 43, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[95369, 3278, 146, 3, 26, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[95518, 3283, 357, 7, 46, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[95912, 3295, 112, 3, 21, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[96027, 3300, 353, 6, 32, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[96395, 3309, 466, 15, 43, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[96864, 3326, 378, 9, 43, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97267, 3339, 112, 3, 26, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97382, 3344, 241, 5, 33, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97638, 3352, 95, 1, 33, "Text",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97758, 3357, 114, 3, 34, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[97875, 3362, 117, 3, 29, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[98029, 3370, 107, 3, 30, "Input",
      CellTags->{"b:36.4", "IPM3.8.3.5"}],
    Cell[98139, 3375, 115, 3, 29, "Output",
      CellTags->{"b:36.4", "IPM3.8.3.5"}]},
  "c:13"->{
    Cell[93625, 3215, 83, 1, 30, "Subsection",
      CellTags->{"b:36.4", "IPM3.8.3.5", "c:13"}]},
  "i:45"->{
    Cell[93711, 3218, 312, 6, 71, "TextFirst",
      CellTags->{"i:45", "b:36.4", "IPM3.8.3.5"}]},
  "b:36.5"->{
    Cell[98334, 3386, 105, 1, 30, "Subsection",
      CellTags->{"b:36.5", "IPM3.8.3.6", "c:14"}],
    Cell[98442, 3389, 392, 10, 71, "TextFirst",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[98859, 3403, 110, 3, 42, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[98972, 3408, 105, 3, 42, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99114, 3416, 107, 3, 42, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99224, 3421, 98, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99337, 3427, 305, 7, 52, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99667, 3438, 120, 3, 31, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99790, 3443, 113, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[99918, 3449, 504, 13, 90, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[100447, 3466, 142, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[100592, 3471, 98, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[100727, 3479, 145, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[100875, 3484, 123, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101013, 3490, 212, 4, 52, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101250, 3498, 128, 3, 33, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101381, 3503, 115, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101511, 3509, 303, 6, 71, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101817, 3517, 109, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[101929, 3522, 117, 3, 31, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[102071, 3529, 141, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[102215, 3534, 139, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[102369, 3540, 518, 16, 71, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[102912, 3560, 128, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103043, 3565, 139, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103197, 3571, 400, 7, 90, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103622, 3582, 138, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103763, 3587, 101, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[103901, 3595, 140, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104044, 3600, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104175, 3606, 276, 7, 52, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104476, 3617, 117, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104596, 3622, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104749, 3630, 110, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104862, 3635, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[104993, 3641, 137, 3, 33, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105155, 3648, 113, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105271, 3653, 100, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105408, 3661, 107, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105518, 3666, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[105649, 3672, 478, 10, 90, "Text",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[106152, 3686, 128, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[106283, 3691, 278, 8, 43, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[106598, 3704, 107, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[106708, 3709, 116, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.6"}],
    Cell[107010, 3725, 85, 1, 77, "ExerciseSubsection",
      CellTags->{"b:36.5", "IPM3.8.3.7", "c:15"}],
    Cell[107120, 3730, 235, 7, 46, "ExerciseItem",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107380, 3741, 107, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107490, 3746, 101, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107628, 3754, 107, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107738, 3759, 112, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[107877, 3766, 671, 22, 46, "ExerciseItem",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[108573, 3792, 197, 4, 46, "ExerciseItem",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[108795, 3800, 115, 3, 30, "Input",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[108913, 3805, 119, 3, 29, "Output",
      CellTags->{"b:36.5", "IPM3.8.3.7"}],
    Cell[109081, 3814, 325, 9, 50, "ExerciseItem",
      CellTags->{"b:36.5", "IPM3.8.3.7"}]},
  "c:14"->{
    Cell[98334, 3386, 105, 1, 30, "Subsection",
      CellTags->{"b:36.5", "IPM3.8.3.6", "c:14"}]},
  "b:36.36"->{
    Cell[106839, 3715, 103, 3, 30, "NonPrintInput",
      CellTags->"b:36.36"]},
  "c:15"->{
    Cell[107010, 3725, 85, 1, 77, "ExerciseSubsection",
      CellTags->{"b:36.5", "IPM3.8.3.7", "c:15"}]},
  "c:16"->{
    Cell[109549, 3834, 183, 2, 40, "Section",
      CounterAssignments->{{"Chapter", 8}, {"Section", 3}},
      CellTags->{
      "IPM3.8.4.0", "IPM3.8.4.1", "IPM3.8.4.2", "IPM3.8.4.3", "c:16"}]},
  "i:46"->{
    Cell[109735, 3838, 640, 12, 128, "TextFirst",
      CellTags->{"i:46", "IPM3.8.4.0"}]},
  "b:37.0"->{
    Cell[110431, 3856, 81, 1, 44, "Subsection",
      CellTags->{"b:37.0", "IPM3.8.4.1", "c:17"}],
    Cell[110515, 3859, 685, 11, 128, "TextFirst",
      CellTags->{"i:47", "b:37.0", "IPM3.8.4.1"}],
    Cell[111203, 3872, 349, 8, 71, "Text",
      CellTags->{"i:48", "b:37.0", "IPM3.8.4.1"}],
    Cell[111555, 3882, 223, 6, 33, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[111803, 3892, 142, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[111948, 3897, 358, 10, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[112321, 3910, 281, 8, 49, "Text",
      CellTags->{"i:49", "b:37.0", "IPM3.8.4.1"}],
    Cell[112627, 3922, 122, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[112752, 3927, 539, 15, 103, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[113306, 3945, 416, 10, 68, "Text",
      CellTags->{"i:50", "b:37.0", "IPM3.8.4.1"}],
    Cell[113747, 3959, 112, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[113862, 3964, 213, 4, 48, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114090, 3971, 197, 5, 49, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114312, 3980, 147, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114462, 3985, 369, 10, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114868, 4000, 123, 3, 27, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[114994, 4005, 559, 15, 103, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[115568, 4023, 287, 5, 71, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[115880, 4032, 243, 6, 70, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[116126, 4040, 362, 10, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[116525, 4055, 121, 3, 27, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[116649, 4060, 984, 20, 183, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[117648, 4083, 207, 6, 30, "Text",
      PageBreakAbove->True,
      CellTags->{"i:51", "b:37.0", "IPM3.8.4.1"}],
    Cell[117858, 4091, 117, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[117978, 4096, 192, 4, 33, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[118173, 4102, 205, 5, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[118381, 4109, 368, 8, 71, "Text",
      CellTags->{"i:53", "b:37.0", "IPM3.8.4.1"}],
    Cell[118774, 4121, 247, 6, 52, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119024, 4129, 392, 12, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119431, 4144, 108, 1, 30, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119542, 4147, 137, 3, 31, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119682, 4152, 203, 4, 52, "Text",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[119910, 4160, 140, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120053, 4165, 115, 3, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120183, 4171, 158, 4, 30, "TextFirst",
      PageBreakAbove->True,
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120366, 4179, 121, 3, 31, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120490, 4184, 111, 3, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120616, 4190, 143, 3, 30, "TextFirst",
      CellTags->{"i:54", "b:37.0", "IPM3.8.4.1"}],
    Cell[120784, 4197, 138, 3, 30, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[120925, 4202, 132, 3, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[121094, 4210, 122, 3, 27, "Input",
      CellTags->{"b:37.0", "IPM3.8.4.1"}],
    Cell[121219, 4215, 133, 3, 29, "Output",
      CellTags->{"b:37.0", "IPM3.8.4.1"}]},
  "c:17"->{
    Cell[110431, 3856, 81, 1, 44, "Subsection",
      CellTags->{"b:37.0", "IPM3.8.4.1", "c:17"}]},
  "i:47"->{
    Cell[110515, 3859, 685, 11, 128, "TextFirst",
      CellTags->{"i:47", "b:37.0", "IPM3.8.4.1"}]},
  "i:48"->{
    Cell[111203, 3872, 349, 8, 71, "Text",
      CellTags->{"i:48", "b:37.0", "IPM3.8.4.1"}]},
  "i:49"->{
    Cell[112321, 3910, 281, 8, 49, "Text",
      CellTags->{"i:49", "b:37.0", "IPM3.8.4.1"}]},
  "i:50"->{
    Cell[113306, 3945, 416, 10, 68, "Text",
      CellTags->{"i:50", "b:37.0", "IPM3.8.4.1"}]},
  "i:51"->{
    Cell[117648, 4083, 207, 6, 30, "Text",
      PageBreakAbove->True,
      CellTags->{"i:51", "b:37.0", "IPM3.8.4.1"}]},
  "i:53"->{
    Cell[118381, 4109, 368, 8, 71, "Text",
      CellTags->{"i:53", "b:37.0", "IPM3.8.4.1"}]},
  "i:54"->{
    Cell[120616, 4190, 143, 3, 30, "TextFirst",
      CellTags->{"i:54", "b:37.0", "IPM3.8.4.1"}]},
  "b:37.1"->{
    Cell[121432, 4226, 81, 1, 44, "Subsection",
      CellTags->{"b:37.1", "IPM3.8.4.2", "c:18"}],
    Cell[121516, 4229, 928, 17, 166, "TextFirst",
      CellTags->{"i:55", "b:37.1", "IPM3.8.4.2"}],
    Cell[122447, 4248, 459, 8, 90, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[122909, 4258, 730, 13, 128, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[123642, 4273, 191, 6, 33, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[123836, 4281, 138, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[123977, 4286, 308, 10, 52, "Text",
      PageBreakAbove->True,
      CellTags->{"i:56", "b:37.1", "IPM3.8.4.2"}],
    Cell[124310, 4300, 123, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[124436, 4305, 101, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[124552, 4311, 368, 9, 71, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[124923, 4322, 135, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125083, 4329, 124, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125210, 4334, 102, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125327, 4340, 158, 4, 33, "TextFirst",
      CellTags->{"i:57", "b:37.1", "IPM3.8.4.2"}],
    Cell[125510, 4348, 123, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125636, 4353, 116, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125767, 4359, 169, 4, 33, "TextFirst",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[125961, 4367, 133, 3, 42, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126097, 4372, 116, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126228, 4378, 176, 4, 33, "TextFirst",
      CellTags->{"i:58", "b:37.1", "IPM3.8.4.2"}],
    Cell[126429, 4386, 135, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126567, 4391, 183, 4, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126765, 4398, 152, 4, 33, "TextFirst",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[126942, 4406, 129, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[127074, 4411, 131, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[127242, 4419, 131, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[127376, 4424, 120, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[127511, 4430, 793, 19, 128, "Text",
      CellTags->{"i:59", "b:37.1", "IPM3.8.4.2"}],
    Cell[128329, 4453, 190, 4, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[128522, 4459, 102, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[128661, 4467, 190, 4, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[128854, 4473, 101, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[128970, 4479, 466, 16, 52, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[129461, 4499, 190, 4, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[129654, 4505, 102, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[129793, 4513, 190, 4, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[129986, 4519, 101, 3, 29, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[130102, 4525, 192, 5, 33, "TextFirst",
      CellTags->{"i:60", "b:37.1", "IPM3.8.4.2"}],
    Cell[130319, 4534, 141, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[130463, 4539, 1077, 20, 257, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[131555, 4562, 647, 12, 128, "Text",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[132205, 4576, 198, 5, 50, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[132406, 4583, 149, 4, 33, "TextFirst",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[132580, 4591, 131, 3, 30, "Input",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[132714, 4596, 391, 7, 86, "Output",
      CellTags->{"b:37.1", "IPM3.8.4.2"}],
    Cell[133185, 4611, 85, 1, 45, "ExerciseSubsection",
      CellTags->{"b:37.1", "IPM3.8.4.3", "c:19"}],
    Cell[133273, 4614, 331, 10, 46, "ExerciseItem",
      CellTags->{"i:61", "b:37.1", "IPM3.8.4.3"}],
    Cell[133607, 4626, 592, 20, 46, "ExerciseItem",
      CellTags->{"i:62", "b:37.1", "IPM3.8.4.3"}],
    Cell[134224, 4650, 483, 11, 84, "ExerciseItem",
      CellTags->{"b:37.1", "IPM3.8.4.3"}]},
  "c:18"->{
    Cell[121432, 4226, 81, 1, 44, "Subsection",
      CellTags->{"b:37.1", "IPM3.8.4.2", "c:18"}]},
  "i:55"->{
    Cell[121516, 4229, 928, 17, 166, "TextFirst",
      CellTags->{"i:55", "b:37.1", "IPM3.8.4.2"}]},
  "i:56"->{
    Cell[123977, 4286, 308, 10, 52, "Text",
      PageBreakAbove->True,
      CellTags->{"i:56", "b:37.1", "IPM3.8.4.2"}]},
  "i:57"->{
    Cell[125327, 4340, 158, 4, 33, "TextFirst",
      CellTags->{"i:57", "b:37.1", "IPM3.8.4.2"}]},
  "i:58"->{
    Cell[126228, 4378, 176, 4, 33, "TextFirst",
      CellTags->{"i:58", "b:37.1", "IPM3.8.4.2"}]},
  "i:59"->{
    Cell[127511, 4430, 793, 19, 128, "Text",
      CellTags->{"i:59", "b:37.1", "IPM3.8.4.2"}]},
  "i:60"->{
    Cell[130102, 4525, 192, 5, 33, "TextFirst",
      CellTags->{"i:60", "b:37.1", "IPM3.8.4.2"}]},
  "c:19"->{
    Cell[133185, 4611, 85, 1, 45, "ExerciseSubsection",
      CellTags->{"b:37.1", "IPM3.8.4.3", "c:19"}]},
  "i:61"->{
    Cell[133273, 4614, 331, 10, 46, "ExerciseItem",
      CellTags->{"i:61", "b:37.1", "IPM3.8.4.3"}]},
  "i:62"->{
    Cell[133607, 4626, 592, 20, 46, "ExerciseItem",
      CellTags->{"i:62", "b:37.1", "IPM3.8.4.3"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"IPM3.8.0", 217033, 7490},
  {"IPM3.8.1", 217664, 7503},
  {"IPM3.8.2.1", 220424, 7568},
  {"IPM3.8.2.2", 226026, 7694},
  {"IPM3.8.2.3", 229110, 7763},
  {"IPM3.8.2.4", 233320, 7857},
  {"IPM3.8.3.1", 237638, 7947},
  {"IPM3.8.3.2", 241163, 8024},
  {"IPM3.8.3.3", 243903, 8084},
  {"IPM3.8.3.4", 246369, 8137},
  {"IPM3.8.3.5", 251438, 8250},
  {"IPM3.8.3.6", 254054, 8307},
  {"IPM3.8.3.7", 258684, 8410},
  {"IPM3.8.4.0", 260392, 8445},
  {"IPM3.8.4.1", 261107, 8459},
  {"IPM3.8.4.2", 265535, 8557},
  {"IPM3.8.4.3", 270208, 8660},
  {"IPM3.8.5.0", 271240, 8680},
  {"IPM3.8.5.1", 271668, 8688},
  {"IPM3.8.5.2", 272096, 8696},
  {"IPM3.8.5.3", 272524, 8704},
  {"IPM3.8.5.4", 272952, 8712},
  {"c:1", 273373, 8720},
  {"b:34", 273510, 8724},
  {"c:2", 275854, 8782},
  {"i:1", 276014, 8786},
  {"i:2", 276113, 8789},
  {"c:3", 276211, 8792},
  {"b:35.0", 276419, 8797},
  {"c:4", 281412, 8912},
  {"i:3", 281520, 8915},
  {"i:4", 281623, 8918},
  {"i:5", 281726, 8921},
  {"i:6", 281860, 8925},
  {"i:7", 281964, 8928},
  {"i:8", 282072, 8931},
  {"i:9", 282269, 8936},
  {"i:10", 282373, 8939},
  {"i:11", 282573, 8944},
  {"i:12", 282683, 8947},
  {"i:13", 282790, 8950},
  {"i:14", 282895, 8953},
  {"b:35.1", 283097, 8958},
  {"c:5", 285572, 9016},
  {"i:15", 285681, 9019},
  {"i:16", 285791, 9022},
  {"i:17", 285896, 9025},
  {"b:35.2", 286004, 9028},
  {"c:6", 293302, 9189},
  {"i:18", 293412, 9192},
  {"i:19", 293523, 9195},
  {"i:20", 293629, 9198},
  {"c:7", 293739, 9201},
  {"i:21", 293857, 9204},
  {"i:22", 293972, 9207},
  {"i:23", 294087, 9210},
  {"i:24", 294201, 9213},
  {"i:25", 294317, 9216},
  {"i:26", 294431, 9219},
  {"i:27", 294547, 9222},
  {"i:28", 294664, 9225},
  {"c:8", 294779, 9228},
  {"Sec.WorkingWithNumbers", 295081, 9234},
  {"b:36.0", 295367, 9240},
  {"c:9", 298205, 9305},
  {"i:29", 298315, 9308},
  {"i:30", 298427, 9311},
  {"i:31", 298629, 9316},
  {"i:32", 298737, 9319},
  {"i:33", 298843, 9322},
  {"b:36.1", 298953, 9325},
  {"c:10", 301007, 9373},
  {"i:34", 301119, 9376},
  {"i:35", 301230, 9379},
  {"b:36.2", 301338, 9382},
  {"c:11", 303118, 9423},
  {"i:36", 303229, 9426},
  {"i:37", 303340, 9429},
  {"i:38", 303447, 9432},
  {"i:39", 303554, 9435},
  {"b:36.3", 303663, 9438},
  {"c:12", 308046, 9539},
  {"i:40", 308158, 9542},
  {"i:41", 308266, 9545},
  {"i:42", 308372, 9548},
  {"i:43", 308479, 9551},
  {"i:44", 308587, 9554},
  {"b:36.4", 308695, 9557},
  {"c:13", 310625, 9602},
  {"i:45", 310736, 9605},
  {"b:36.5", 310849, 9608},
  {"c:14", 315802, 9721},
  {"b:36.36", 315917, 9724},
  {"c:15", 316010, 9727},
  {"c:16", 316130, 9730},
  {"i:46", 316339, 9735},
  {"b:37.0", 316445, 9738},
  {"c:17", 320262, 9825},
  {"i:47", 320374, 9828},
  {"i:48", 320488, 9831},
  {"i:49", 320595, 9834},
  {"i:50", 320702, 9837},
  {"i:51", 320810, 9840},
  {"i:53", 320945, 9844},
  {"i:54", 321052, 9847},
  {"b:37.1", 321166, 9850},
  {"c:18", 325636, 9950},
  {"i:55", 325748, 9953},
  {"i:56", 325862, 9956},
  {"i:57", 325998, 9960},
  {"i:58", 326110, 9963},
  {"i:59", 326222, 9966},
  {"i:60", 326331, 9969},
  {"c:19", 326443, 9972},
  {"i:61", 326563, 9975},
  {"i:62", 326679, 9978}
  }
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 462, 10, 0, "TitleBar",
  CellTags->{
  "IPM3.8.0", "IPM3.8.1", "IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", 
    "IPM3.8.2.4", "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", 
    "IPM3.8.3.5", "IPM3.8.3.6", "IPM3.8.3.7", "IPM3.8.4.0", "IPM3.8.4.1", 
    "IPM3.8.4.2", "IPM3.8.4.3", "IPM3.8.5.0", "IPM3.8.5.1", "IPM3.8.5.2", 
    "IPM3.8.5.3", "IPM3.8.5.4"}],

Cell[CellGroupData[{
Cell[2241, 65, 151, 7, 96, "Chapter",
  CounterAssignments->{{"Chapter", 7}},
  CellTags->{"IPM3.8.0", "c:1"}],
Cell[2395, 74, 779, 15, 148, "ChapterAbstract",
  CellTags->"IPM3.8.0"],

Cell[CellGroupData[{
Cell[3199, 93, 128, 2, 40, "Section",
  CounterAssignments->{{"Chapter", 8}, {"Section", 0}},
  CellTags->{"b:34", "IPM3.8.1", "c:2"}],
Cell[3330, 97, 860, 18, 147, "TextFirst",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[4193, 117, 254, 6, 52, "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[CellGroupData[{
Cell[4472, 127, 104, 3, 40, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[4579, 132, 98, 3, 46, "Output",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],

Cell[CellGroupData[{
Cell[4714, 140, 106, 3, 40, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[4823, 145, 111, 3, 29, "Output",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],
Cell[4949, 151, 811, 18, 128, "Text",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[5763, 171, 355, 8, 71, "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[CellGroupData[{
Cell[6143, 183, 112, 3, 30, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[6258, 188, 108, 3, 29, "Output",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],
Cell[6381, 194, 295, 10, 52, "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[CellGroupData[{
Cell[6701, 208, 108, 3, 30, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[6812, 213, 111, 3, 29, "Output",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],
Cell[6938, 219, 221, 5, 52, "Text",
  CellTags->{"b:34", "IPM3.8.1"}],

Cell[CellGroupData[{
Cell[7184, 228, 104, 3, 30, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[7291, 233, 317, 6, 86, "Output",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],
Cell[7623, 242, 557, 13, 74, "Text",
  CellTags->{"i:1", "b:34", "IPM3.8.1"}],

Cell[CellGroupData[{
Cell[8205, 259, 283, 6, 64, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[8491, 267, 283, 8, 29, "Output",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],
Cell[8789, 278, 408, 9, 71, "Text",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[9200, 289, 331, 7, 64, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[9534, 298, 199, 4, 52, "Text",
  CellTags->{"i:2", "b:34", "IPM3.8.1"}],

Cell[CellGroupData[{
Cell[9758, 306, 351, 7, 106, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[10112, 315, 285, 8, 48, "Output",
  CellTags->{"b:34", "IPM3.8.1"}]
}, Closed]],
Cell[10412, 326, 240, 6, 52, "Text",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[10655, 334, 338, 7, 64, "Input",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[10996, 343, 426, 7, 90, "Text",
  CellTags->{"b:34", "IPM3.8.1"}],
Cell[11425, 352, 80, 2, 30, "NonPrintInput"],
Cell[11508, 356, 25, 0, 8, "SectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[11570, 361, 159, 2, 29, "Section",
  CounterAssignments->{{"Chapter", 8}, {"Section", 1}},
  CellTags->{"IPM3.8.2.1", "IPM3.8.2.2", "IPM3.8.2.3", "IPM3.8.2.4", "c:3"}],

Cell[CellGroupData[{
Cell[11754, 367, 83, 1, 44, "Subsection",
  CellTags->{"b:35.0", "IPM3.8.2.1", "c:4"}],
Cell[11840, 370, 503, 10, 90, "TextFirst",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[12346, 382, 295, 6, 52, "Text",
  CellTags->{"i:3", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[12666, 392, 143, 3, 42, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[12812, 397, 138, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[12965, 403, 223, 8, 33, "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[13213, 415, 147, 3, 42, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[13363, 420, 1067, 34, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[14445, 457, 477, 14, 71, "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[14925, 473, 381, 8, 71, "Text",
  CellTags->{"i:4", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[15331, 485, 141, 3, 46, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[15475, 490, 100, 3, 42, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[15590, 496, 152, 5, 33, "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[15767, 505, 151, 3, 42, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[15921, 510, 102, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[16038, 516, 1023, 26, 147, "Text",
  PageBreakAbove->True,
  CellTags->{"i:5", "b:35.0", "IPM3.8.2.1"}],
Cell[17064, 544, 671, 24, 52, "Text",
  CellTags->{"i:6", "b:35.0", "IPM3.8.2.1"}],
Cell[17738, 570, 212, 6, 52, "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[17975, 580, 119, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[18097, 585, 116, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[CellGroupData[{
Cell[18250, 593, 102, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[18355, 598, 103, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[18473, 604, 100, 1, 33, "TextFirst",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[18598, 609, 122, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[18723, 614, 116, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[18854, 620, 138, 3, 33, "TextFirst",
  CellTags->{"i:7", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[19017, 627, 116, 3, 30, "Input",
  CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}],
Cell[19136, 632, 109, 3, 29, "Output",
  CellTags->{"i:8", "b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[19260, 638, 325, 6, 71, "Text",
  CellTags->{"i:9", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[19610, 648, 125, 3, 30, "Input",
  CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}],
Cell[19738, 653, 129, 3, 29, "Output",
  CellTags->{"i:10", "b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[19882, 659, 108, 1, 33, "TextFirst",
  CellTags->{"i:11", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[20015, 664, 117, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[20135, 669, 105, 3, 40, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[20255, 675, 193, 5, 33, "TextFirst",
  PageBreakAbove->True,
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[20451, 682, 122, 2, 22, "NumberedFigure",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[20576, 686, 777, 22, 109, "Text",
  CellTags->{"i:12", "b:35.0", "IPM3.8.2.1"}],
Cell[21356, 710, 269, 8, 33, "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[21650, 722, 125, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[21778, 727, 112, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[21905, 733, 325, 8, 52, "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[22255, 745, 134, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[22392, 750, 115, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[CellGroupData[{
Cell[22544, 758, 122, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[22669, 763, 105, 3, 42, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[22789, 769, 285, 8, 52, "Text",
  CellTags->{"i:13", "b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[23099, 781, 191, 5, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[23293, 788, 128, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[23436, 794, 561, 13, 90, "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[24022, 811, 143, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[24168, 816, 101, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],

Cell[CellGroupData[{
Cell[24306, 824, 128, 3, 30, "Input",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],
Cell[24437, 829, 101, 3, 29, "Output",
  CellTags->{"b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[24553, 835, 205, 6, 52, "Text",
  CellTags->{"b:35.0", "IPM3.8.2.1"}],

Cell[CellGroupData[{
Cell[24783, 845, 131, 3, 30, "Input",
  CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}],
Cell[24917, 850, 118, 3, 29, "Output",
  CellTags->{"i:14", "b:35.0", "IPM3.8.2.1"}]
}, Closed]],
Cell[25050, 856, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[25115, 861, 90, 1, 44, "Subsection",
  CellTags->{"b:35.1", "IPM3.8.2.2", "c:5"}],
Cell[25208, 864, 235, 7, 52, "TextFirst",
  CellTags->{"i:15", "b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{
Cell[25468, 875, 99, 2, 30, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[25570, 879, 109, 3, 29, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],

Cell[CellGroupData[{
Cell[25716, 887, 121, 3, 30, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[25840, 892, 150, 3, 29, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],
Cell[26005, 898, 241, 5, 52, "Text",
  CellTags->{"i:16", "b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{
Cell[26271, 907, 95, 2, 30, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[26369, 911, 216, 7, 43, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],
Cell[26600, 921, 380, 15, 33, "Text",
  CellTags->{"i:17", "b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{
Cell[27005, 940, 104, 3, 30, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[27112, 945, 99, 3, 29, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],
Cell[27226, 951, 220, 5, 52, "Text",
  PageBreakAbove->True,
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{
Cell[27471, 960, 130, 3, 30, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[27604, 965, 2979, 104, 48, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],
Cell[30598, 1072, 188, 4, 52, "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{
Cell[30811, 1080, 120, 3, 30, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[30934, 1085, 247, 7, 43, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],
Cell[31196, 1095, 492, 13, 71, "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{
Cell[31713, 1112, 119, 3, 21, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[31835, 1117, 279, 5, 44, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],
Cell[32129, 1125, 307, 8, 43, "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[32439, 1135, 124, 3, 14, "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{
Cell[32588, 1142, 117, 3, 21, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[32708, 1147, 246, 7, 30, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],
Cell[32969, 1157, 199, 4, 28, "Text",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],

Cell[CellGroupData[{
Cell[33193, 1165, 132, 3, 30, "Input",
  CellTags->{"b:35.1", "IPM3.8.2.2"}],
Cell[33328, 1170, 357, 6, 86, "Output",
  CellTags->{"b:35.1", "IPM3.8.2.2"}]
}, Closed]],
Cell[33700, 1179, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[33765, 1184, 81, 1, 44, "Subsection",
  CellTags->{"b:35.2", "IPM3.8.2.3", "c:6"}],
Cell[33849, 1187, 312, 7, 52, "TextFirst",
  CellTags->{"i:18", "b:35.2", "IPM3.8.2.3"}],
Cell[34164, 1196, 208, 6, 52, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{
Cell[34397, 1206, 104, 3, 30, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[34504, 1211, 117, 3, 29, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],
Cell[34636, 1217, 296, 6, 52, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{
Cell[34957, 1227, 121, 3, 30, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[35081, 1232, 99, 3, 29, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],
Cell[35195, 1238, 222, 5, 52, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[35420, 1245, 149, 3, 30, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[35572, 1250, 292, 8, 52, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[35867, 1260, 119, 2, 30, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[35989, 1264, 109, 2, 30, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[36101, 1268, 131, 3, 30, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[36235, 1273, 764, 15, 101, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[37002, 1290, 482, 9, 72, "Text",
  CellTags->{"i:19", "b:35.2", "IPM3.8.2.3"}],
Cell[37487, 1301, 126, 3, 14, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[37616, 1306, 117, 2, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[37736, 1310, 130, 3, 14, "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{
Cell[37891, 1317, 120, 3, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[38014, 1322, 121, 3, 21, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],
Cell[38150, 1328, 158, 4, 14, "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{
Cell[38333, 1336, 137, 3, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[38473, 1341, 319, 6, 32, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],
Cell[38807, 1350, 237, 5, 28, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[39047, 1357, 182, 4, 28, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[39232, 1363, 221, 4, 33, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[39456, 1369, 262, 5, 43, "TextFirst",
  CellTags->{"i:20", "b:35.2", "IPM3.8.2.3"}],
Cell[39721, 1376, 281, 5, 43, "Text",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{
Cell[40027, 1385, 148, 3, 32, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[40178, 1390, 532, 9, 56, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],

Cell[CellGroupData[{
Cell[40747, 1404, 145, 3, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[40895, 1409, 711, 12, 80, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],
Cell[41621, 1424, 157, 4, 14, "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{
Cell[41803, 1432, 143, 3, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[41949, 1437, 182, 5, 21, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],
Cell[42146, 1445, 111, 1, 14, "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[42260, 1448, 139, 3, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[42402, 1453, 142, 3, 14, "TextFirst",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],

Cell[CellGroupData[{
Cell[42569, 1460, 137, 3, 30, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.3"}],
Cell[42709, 1465, 548, 9, 67, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.3"}]
}, Closed]],
Cell[43272, 1477, 203, 4, 70, "NonPrintInput"],
Cell[43478, 1483, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[43543, 1488, 84, 1, 77, "ExerciseSubsection",
  CellTags->{"b:35.2", "IPM3.8.2.4", "c:7"}],
Cell[43630, 1491, 509, 15, 51, "ExerciseItem",
  CellTags->{"i:21", "b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[44164, 1510, 803, 25, 65, "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[44992, 1539, 119, 3, 30, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[45114, 1544, 98, 3, 29, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],
Cell[45227, 1550, 41, 1, 33, "Text",
  PageBreakAbove->True]
}, Closed]],
Cell[45283, 1554, 725, 23, 65, "ExerciseItem",
  CellTags->{"i:22", "b:35.2", "IPM3.8.2.4"}],
Cell[46011, 1579, 742, 18, 103, "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[46756, 1599, 93, 1, 27, "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[46852, 1602, 450, 17, 27, "ExerciseSubItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[47305, 1621, 365, 13, 27, "ExerciseSubItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[47673, 1636, 454, 17, 20, "ExerciseSubItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[48130, 1655, 355, 13, 20, "ExerciseSubItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[48488, 1670, 547, 21, 20, "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[49060, 1695, 390, 7, 63, "ExerciseItem",
  CellTags->{"i:23", "b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[49475, 1706, 115, 3, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[49593, 1711, 111, 3, 21, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],
Cell[49719, 1717, 114, 1, 15, "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[49858, 1722, 109, 3, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[49970, 1727, 111, 3, 21, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],
Cell[50096, 1733, 99, 1, 15, "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[50220, 1738, 87, 2, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[50310, 1742, 98, 3, 21, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],
Cell[50423, 1748, 171, 4, 30, "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[50597, 1754, 41, 1, 14, "Text",
  PageBreakAbove->True]
}, Closed]],
Cell[50653, 1758, 1061, 32, 92, "ExerciseItem",
  CellTags->{"i:24", "b:35.2", "IPM3.8.2.4"}],
Cell[51717, 1792, 230, 5, 34, "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[51950, 1799, 183, 5, 34, "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[52158, 1808, 358, 7, 49, "ExerciseItem",
  CellTags->{"i:25", "b:35.2", "IPM3.8.2.4"}],
Cell[52519, 1817, 193, 4, 36, "DisplayFormula",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[52715, 1823, 759, 28, 31, "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[53499, 1855, 104, 3, 21, "Input",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[53606, 1860, 97, 3, 21, "Output",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],
Cell[53718, 1866, 593, 18, 61, "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell[CellGroupData[{
Cell[54348, 1889, 1046, 38, 49, "ExerciseItem",
  CellTags->{"i:26", "b:35.2", "IPM3.8.2.4"}],
Cell[55397, 1929, 209, 4, 36, "DisplayFormula",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],

Cell[CellGroupData[{
Cell[55643, 1938, 1905, 55, 150, "ExerciseItem",
  CellTags->{"i:27", "b:35.2", "IPM3.8.2.4"}],
Cell[57551, 1995, 252, 5, 46, "DisplayFormula",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],
Cell[57806, 2002, 557, 17, 46, "ExercisesNoLabel",
  CellTags->{"b:35.2", "IPM3.8.2.4"}]
}, Closed]],
Cell[58378, 2022, 489, 16, 46, "ExerciseItem",
  CellTags->{"b:35.2", "IPM3.8.2.4"}],

Cell[CellGroupData[{
Cell[58892, 2042, 985, 18, 160, "ExerciseItem",
  CellTags->{"i:28", "b:35.2", "IPM3.8.2.4"}],
Cell[59880, 2062, 79, 2, 30, "NonPrintInput"],
Cell[59962, 2066, 25, 0, 0, "SectionSpacer"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[60048, 2073, 248, 4, 29, "Section",
  CounterAssignments->{{"Chapter", 8}, {"Section", 2}},
  CellTags->{
  "IPM3.8.3.1", "IPM3.8.3.2", "IPM3.8.3.3", "IPM3.8.3.4", "IPM3.8.3.5", 
    "IPM3.8.3.6", "IPM3.8.3.7", "c:8", "Sec.WorkingWithNumbers"}],

Cell[CellGroupData[{
Cell[60321, 2081, 89, 1, 44, "Subsection",
  CellTags->{"b:36.0", "IPM3.8.3.1", "c:9"}],
Cell[60413, 2084, 505, 11, 90, "TextFirst",
  CellTags->{"i:29", "b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[60943, 2099, 125, 3, 30, "Input",
  CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}],
Cell[61071, 2104, 122, 3, 29, "Output",
  CellTags->{"i:30", "b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[61208, 2110, 572, 10, 109, "Text",
  CellTags->{"i:31", "b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[61805, 2124, 122, 3, 30, "Input",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[61930, 2129, 135, 3, 29, "Output",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[62080, 2135, 330, 8, 71, "Text",
  CellTags->{"i:32", "b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[62435, 2147, 112, 3, 30, "Input",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[62550, 2152, 115, 3, 29, "Output",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[62680, 2158, 743, 18, 109, "Text",
  CellTags->{"i:33", "b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[63448, 2180, 114, 3, 21, "Input",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[63565, 2185, 115, 3, 21, "Output",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[63695, 2191, 713, 22, 57, "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[64433, 2217, 139, 3, 21, "Input",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[64575, 2222, 435, 8, 56, "Message",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[65013, 2232, 137, 3, 34, "Output",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[65165, 2238, 621, 19, 58, "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[65811, 2261, 128, 3, 34, "Input",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[65942, 2266, 114, 3, 21, "Output",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[66071, 2272, 387, 12, 28, "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[66461, 2286, 165, 4, 28, "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[66629, 2292, 484, 13, 57, "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[67138, 2309, 194, 4, 33, "Input",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[67335, 2315, 427, 12, 21, "Output",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[67777, 2330, 204, 4, 28, "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[68006, 2338, 188, 4, 33, "Input",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[68197, 2344, 406, 12, 21, "Output",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[68618, 2359, 240, 8, 29, "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],

Cell[CellGroupData[{
Cell[68883, 2371, 145, 3, 30, "Input",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[69031, 2376, 167, 4, 29, "Output",
  CellTags->{"b:36.0", "IPM3.8.3.1"}]
}, Closed]],
Cell[69213, 2383, 223, 5, 52, "Text",
  CellTags->{"b:36.0", "IPM3.8.3.1"}],
Cell[69439, 2390, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[69504, 2395, 105, 1, 30, "Subsection",
  CellTags->{"b:36.1", "IPM3.8.3.2", "c:10"}],
Cell[69612, 2398, 286, 7, 52, "TextFirst",
  CellTags->{"i:34", "b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{
Cell[69923, 2409, 109, 3, 30, "Input",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[70035, 2414, 115, 3, 29, "Output",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],
Cell[70165, 2420, 165, 5, 33, "Text",
  PageBreakAbove->True,
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{
Cell[70355, 2429, 98, 3, 30, "Input",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[70456, 2434, 115, 3, 29, "Output",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],

Cell[CellGroupData[{
Cell[70608, 2442, 108, 3, 30, "Input",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[70719, 2447, 120, 3, 29, "Output",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],
Cell[70854, 2453, 297, 8, 52, "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{
Cell[71176, 2465, 108, 3, 30, "Input",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[71287, 2470, 265, 8, 43, "Output",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],
Cell[71567, 2481, 348, 10, 52, "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[71918, 2493, 446, 9, 90, "Text",
  CellTags->{"i:35", "b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{
Cell[72389, 2506, 108, 3, 21, "Input",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[72500, 2511, 152, 3, 21, "Output",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],
Cell[72667, 2517, 197, 4, 28, "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{
Cell[72889, 2525, 107, 3, 21, "Input",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[72999, 2530, 301, 8, 30, "Output",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],
Cell[73315, 2541, 224, 7, 29, "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],

Cell[CellGroupData[{
Cell[73564, 2552, 111, 3, 21, "Input",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[73678, 2557, 113, 3, 21, "Output",
  CellTags->{"b:36.1", "IPM3.8.3.2"}]
}, Closed]],
Cell[73806, 2563, 922, 23, 116, "Text",
  CellTags->{"b:36.1", "IPM3.8.3.2"}],
Cell[74731, 2588, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[74796, 2593, 97, 1, 30, "Subsection",
  CellTags->{"b:36.2", "IPM3.8.3.3", "c:11"}],
Cell[74896, 2596, 311, 8, 29, "TextFirst",
  CellTags->{"i:36", "b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{
Cell[75232, 2608, 127, 3, 30, "Input",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],
Cell[75362, 2613, 123, 3, 21, "Output",
  CellTags->{"b:36.2", "IPM3.8.3.3"}]
}, Closed]],
Cell[75500, 2619, 277, 7, 29, "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{
Cell[75802, 2630, 115, 3, 21, "Input",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],
Cell[75920, 2635, 108, 3, 21, "Output",
  CellTags->{"b:36.2", "IPM3.8.3.3"}]
}, Closed]],
Cell[76043, 2641, 216, 4, 28, "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{
Cell[76284, 2649, 131, 3, 30, "Input",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],
Cell[76418, 2654, 136, 3, 21, "Output",
  CellTags->{"b:36.2", "IPM3.8.3.3"}]
}, Closed]],
Cell[76569, 2660, 283, 7, 29, "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{
Cell[76877, 2671, 90, 2, 29, "Input"],
Cell[76970, 2675, 88, 2, 31, "Output"]
}, Closed]],
Cell[77073, 2680, 216, 6, 29, "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],
Cell[77292, 2688, 650, 17, 57, "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],
Cell[77945, 2707, 788, 18, 87, "Text",
  CellTags->{"i:37", "b:36.2", "IPM3.8.3.3"}],
Cell[78736, 2727, 360, 6, 43, "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],
Cell[79099, 2735, 287, 7, 29, "Text",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],
Cell[79389, 2744, 737, 16, 87, "Text",
  CellTags->{"i:38", "b:36.2", "IPM3.8.3.3"}],

Cell[CellGroupData[{
Cell[80151, 2764, 112, 3, 21, "Input",
  CellTags->{"b:36.2", "IPM3.8.3.3"}],
Cell[80266, 2769, 414, 7, 124, "Output",
  CellTags->{"b:36.2", "IPM3.8.3.3"}]
}, Closed]],
Cell[80695, 2779, 722, 20, 90, "Text",
  CellTags->{"i:39", "b:36.2", "IPM3.8.3.3"}],
Cell[81420, 2801, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[81485, 2806, 104, 1, 30, "Subsection",
  CellTags->{"b:36.3", "IPM3.8.3.4", "c:12"}],
Cell[81592, 2809, 307, 6, 52, "TextFirst",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[81924, 2819, 131, 3, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[82058, 2824, 121, 3, 29, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{
Cell[82216, 2832, 166, 4, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[82385, 2838, 123, 3, 29, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[82523, 2844, 774, 15, 128, "Text",
  CellTags->{"i:40", "b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[83322, 2863, 113, 3, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[83438, 2868, 116, 3, 29, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[83569, 2874, 256, 5, 52, "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[83850, 2883, 104, 3, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[83957, 2888, 120, 3, 29, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{
Cell[84114, 2896, 108, 3, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[84225, 2901, 113, 3, 29, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[84353, 2907, 261, 6, 52, "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[84639, 2917, 137, 3, 21, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[84779, 2922, 113, 3, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[84907, 2928, 144, 3, 14, "Text",
  CellTags->{"i:41", "b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[85076, 2935, 134, 3, 21, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[85213, 2940, 150, 3, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[85378, 2946, 528, 12, 57, "Text",
  CellTags->{"i:42", "b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[85931, 2962, 106, 3, 21, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[86040, 2967, 151, 3, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{
Cell[86228, 2975, 159, 4, 21, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[86390, 2981, 191, 4, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{
Cell[86618, 2990, 113, 3, 21, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[86734, 2995, 121, 3, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[86870, 3001, 812, 16, 101, "Text",
  CellTags->{"i:43", "b:36.3", "IPM3.8.3.4"}],
Cell[87685, 3019, 788, 19, 87, "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[88476, 3040, 622, 13, 72, "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[89123, 3057, 129, 3, 21, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[89255, 3062, 136, 3, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[89406, 3068, 799, 17, 101, "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[90230, 3089, 116, 3, 21, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[90349, 3094, 114, 3, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{
Cell[90500, 3102, 123, 3, 21, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[90626, 3107, 136, 3, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[90777, 3113, 254, 6, 28, "Text",
  CellTags->{"i:44", "b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[91056, 3123, 122, 3, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[91181, 3128, 152, 3, 21, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[91348, 3134, 305, 7, 43, "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[91678, 3145, 119, 3, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[91800, 3150, 173, 4, 29, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[91988, 3157, 506, 10, 90, "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],

Cell[CellGroupData[{
Cell[92519, 3171, 118, 3, 42, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[92640, 3176, 284, 5, 67, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],

Cell[CellGroupData[{
Cell[92961, 3186, 120, 3, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[93084, 3191, 258, 8, 43, "Output",
  CellTags->{"b:36.3", "IPM3.8.3.4"}]
}, Closed]],
Cell[93357, 3202, 84, 1, 33, "Text",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[93444, 3205, 113, 3, 30, "Input",
  CellTags->{"b:36.3", "IPM3.8.3.4"}],
Cell[93560, 3210, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[93625, 3215, 83, 1, 30, "Subsection",
  CellTags->{"b:36.4", "IPM3.8.3.5", "c:13"}],
Cell[93711, 3218, 312, 6, 71, "TextFirst",
  CellTags->{"i:45", "b:36.4", "IPM3.8.3.5"}],
Cell[94026, 3226, 196, 6, 33, "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{
Cell[94247, 3236, 107, 3, 34, "Input",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],
Cell[94357, 3241, 120, 3, 29, "Output",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],
Cell[94492, 3247, 236, 5, 52, "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{
Cell[94753, 3256, 112, 3, 25, "Input",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],
Cell[94868, 3261, 120, 3, 21, "Output",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],
Cell[95003, 3267, 341, 7, 43, "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{
Cell[95369, 3278, 146, 3, 26, "Input",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],
Cell[95518, 3283, 357, 7, 46, "Output",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell[CellGroupData[{
Cell[95912, 3295, 112, 3, 21, "Input",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],
Cell[96027, 3300, 353, 6, 32, "Output",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],
Cell[96395, 3309, 466, 15, 43, "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],
Cell[96864, 3326, 378, 9, 43, "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{
Cell[97267, 3339, 112, 3, 26, "Input",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],
Cell[97382, 3344, 241, 5, 33, "Output",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],
Cell[97638, 3352, 95, 1, 33, "Text",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],

Cell[CellGroupData[{
Cell[97758, 3357, 114, 3, 34, "Input",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],
Cell[97875, 3362, 117, 3, 29, "Output",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],

Cell[CellGroupData[{
Cell[98029, 3370, 107, 3, 30, "Input",
  CellTags->{"b:36.4", "IPM3.8.3.5"}],
Cell[98139, 3375, 115, 3, 29, "Output",
  CellTags->{"b:36.4", "IPM3.8.3.5"}]
}, Closed]],
Cell[98269, 3381, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[98334, 3386, 105, 1, 30, "Subsection",
  CellTags->{"b:36.5", "IPM3.8.3.6", "c:14"}],
Cell[98442, 3389, 392, 10, 71, "TextFirst",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[98859, 3403, 110, 3, 42, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[98972, 3408, 105, 3, 42, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[99114, 3416, 107, 3, 42, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[99224, 3421, 98, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[99337, 3427, 305, 7, 52, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[99667, 3438, 120, 3, 31, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[99790, 3443, 113, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[99918, 3449, 504, 13, 90, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[100447, 3466, 142, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[100592, 3471, 98, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[100727, 3479, 145, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[100875, 3484, 123, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[101013, 3490, 212, 4, 52, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[101250, 3498, 128, 3, 33, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[101381, 3503, 115, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[101511, 3509, 303, 6, 71, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[101817, 3517, 109, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[101929, 3522, 117, 3, 31, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[102071, 3529, 141, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[102215, 3534, 139, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[102369, 3540, 518, 16, 71, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[102912, 3560, 128, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[103043, 3565, 139, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[103197, 3571, 400, 7, 90, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[103622, 3582, 138, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[103763, 3587, 101, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[103901, 3595, 140, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[104044, 3600, 116, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[104175, 3606, 276, 7, 52, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[104476, 3617, 117, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[104596, 3622, 116, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[104749, 3630, 110, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[104862, 3635, 116, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[104993, 3641, 137, 3, 33, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[105155, 3648, 113, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[105271, 3653, 100, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[105408, 3661, 107, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[105518, 3666, 116, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[105649, 3672, 478, 10, 90, "Text",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],

Cell[CellGroupData[{
Cell[106152, 3686, 128, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[106283, 3691, 278, 8, 43, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[106598, 3704, 107, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.6"}],
Cell[106708, 3709, 116, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.6"}]
}, Open  ]],
Cell[106839, 3715, 103, 3, 30, "NonPrintInput",
  CellTags->"b:36.36"],
Cell[106945, 3720, 28, 0, 13, "SubsectionSpacer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107010, 3725, 85, 1, 77, "ExerciseSubsection",
  CellTags->{"b:36.5", "IPM3.8.3.7", "c:15"}],

Cell[CellGroupData[{
Cell[107120, 3730, 235, 7, 46, "ExerciseItem",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[CellGroupData[{
Cell[107380, 3741, 107, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],
Cell[107490, 3746, 101, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.7"}]
}, Open  ]],

Cell[CellGroupData[{
Cell[107628, 3754, 107, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],
Cell[107738, 3759, 112, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.7"}]
}, Open  ]]
}, Open  ]],
Cell[107877, 3766, 671, 22, 46, "ExerciseItem",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[CellGroupData[{
Cell[108573, 3792, 197, 4, 46, "ExerciseItem",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],

Cell[CellGroupData[{
Cell[108795, 3800, 115, 3, 30, "Input",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],
Cell[108913, 3805, 119, 3, 29, "Output",
  CellTags->{"b:36.5", "IPM3.8.3.7"}]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[109081, 3814, 325, 9, 50, "ExerciseItem",
  CellTags->{"b:36.5", "IPM3.8.3.7"}],
Cell[109409, 3825, 79, 2, 30, "NonPrintInput"]
}, Closed]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[109549, 3834, 183, 2, 40, "Section",
  CounterAssignments->{{"Chapter", 8}, {"Section", 3}},
  CellTags->{
  "IPM3.8.4.0", "IPM3.8.4.1", "IPM3.8.4.2", "IPM3.8.4.3", "c:16"}],
Cell[109735, 3838, 640, 12, 128, "TextFirst",
  CellTags->{"i:46", "IPM3.8.4.0"}],
Cell[110378, 3852, 28, 0, 13, "SubsectionSpacer"],

Cell[CellGroupData[{
Cell[110431, 3856, 81, 1, 44, "Subsection",
  CellTags->{"b:37.0", "IPM3.8.4.1", "c:17"}],
Cell[110515, 3859, 685, 11, 128, "TextFirst",
  CellTags->{"i:47", "b:37.0", "IPM3.8.4.1"}],
Cell[111203, 3872, 349, 8, 71, "Text",
  CellTags->{"i:48", "b:37.0", "IPM3.8.4.1"}],
Cell[111555, 3882, 223, 6, 33, "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[111803, 3892, 142, 3, 30, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[111948, 3897, 358, 10, 29, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[112321, 3910, 281, 8, 49, "Text",
  CellTags->{"i:49", "b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[112627, 3922, 122, 3, 30, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[112752, 3927, 539, 15, 103, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[113306, 3945, 416, 10, 68, "Text",
  CellTags->{"i:50", "b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[113747, 3959, 112, 3, 30, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[113862, 3964, 213, 4, 48, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[114090, 3971, 197, 5, 49, "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[114312, 3980, 147, 3, 30, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[114462, 3985, 369, 10, 29, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[CellGroupData[{
Cell[114868, 4000, 123, 3, 27, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[114994, 4005, 559, 15, 103, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[115568, 4023, 287, 5, 71, "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[115880, 4032, 243, 6, 70, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[116126, 4040, 362, 10, 29, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[CellGroupData[{
Cell[116525, 4055, 121, 3, 27, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[116649, 4060, 984, 20, 183, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[117648, 4083, 207, 6, 30, "Text",
  PageBreakAbove->True,
  CellTags->{"i:51", "b:37.0", "IPM3.8.4.1"}],
Cell[117858, 4091, 117, 3, 30, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[117978, 4096, 192, 4, 33, "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[118173, 4102, 205, 5, 30, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[118381, 4109, 368, 8, 71, "Text",
  CellTags->{"i:53", "b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[118774, 4121, 247, 6, 52, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[119024, 4129, 392, 12, 29, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[119431, 4144, 108, 1, 30, "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[119542, 4147, 137, 3, 31, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[119682, 4152, 203, 4, 52, "Text",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[119910, 4160, 140, 3, 30, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[120053, 4165, 115, 3, 29, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[120183, 4171, 158, 4, 30, "TextFirst",
  PageBreakAbove->True,
  CellTags->{"b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[120366, 4179, 121, 3, 31, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[120490, 4184, 111, 3, 29, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[120616, 4190, 143, 3, 30, "TextFirst",
  CellTags->{"i:54", "b:37.0", "IPM3.8.4.1"}],

Cell[CellGroupData[{
Cell[120784, 4197, 138, 3, 30, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[120925, 4202, 132, 3, 29, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],

Cell[CellGroupData[{
Cell[121094, 4210, 122, 3, 27, "Input",
  CellTags->{"b:37.0", "IPM3.8.4.1"}],
Cell[121219, 4215, 133, 3, 29, "Output",
  CellTags->{"b:37.0", "IPM3.8.4.1"}]
}, Closed]],
Cell[121367, 4221, 28, 0, 13, "SubsectionSpacer"]
}, Open  ]],

Cell[CellGroupData[{
Cell[121432, 4226, 81, 1, 44, "Subsection",
  CellTags->{"b:37.1", "IPM3.8.4.2", "c:18"}],
Cell[121516, 4229, 928, 17, 166, "TextFirst",
  CellTags->{"i:55", "b:37.1", "IPM3.8.4.2"}],
Cell[122447, 4248, 459, 8, 90, "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[122909, 4258, 730, 13, 128, "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[123642, 4273, 191, 6, 33, "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[123836, 4281, 138, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[123977, 4286, 308, 10, 52, "Text",
  PageBreakAbove->True,
  CellTags->{"i:56", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[124310, 4300, 123, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[124436, 4305, 101, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[124552, 4311, 368, 9, 71, "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[124923, 4322, 135, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[125083, 4329, 124, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[125210, 4334, 102, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[125327, 4340, 158, 4, 33, "TextFirst",
  CellTags->{"i:57", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[125510, 4348, 123, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[125636, 4353, 116, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[125767, 4359, 169, 4, 33, "TextFirst",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[125961, 4367, 133, 3, 42, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[126097, 4372, 116, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[126228, 4378, 176, 4, 33, "TextFirst",
  CellTags->{"i:58", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[126429, 4386, 135, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[126567, 4391, 183, 4, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[126765, 4398, 152, 4, 33, "TextFirst",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[126942, 4406, 129, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[127074, 4411, 131, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[CellGroupData[{
Cell[127242, 4419, 131, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[127376, 4424, 120, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[127511, 4430, 793, 19, 128, "Text",
  CellTags->{"i:59", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[128329, 4453, 190, 4, 50, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[128522, 4459, 102, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[CellGroupData[{
Cell[128661, 4467, 190, 4, 50, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[128854, 4473, 101, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[128970, 4479, 466, 16, 52, "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[129461, 4499, 190, 4, 50, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[129654, 4505, 102, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],

Cell[CellGroupData[{
Cell[129793, 4513, 190, 4, 50, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[129986, 4519, 101, 3, 29, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[130102, 4525, 192, 5, 33, "TextFirst",
  CellTags->{"i:60", "b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[130319, 4534, 141, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[130463, 4539, 1077, 20, 257, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[131555, 4562, 647, 12, 128, "Text",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[132205, 4576, 198, 5, 50, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[132406, 4583, 149, 4, 33, "TextFirst",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],

Cell[CellGroupData[{
Cell[132580, 4591, 131, 3, 30, "Input",
  CellTags->{"b:37.1", "IPM3.8.4.2"}],
Cell[132714, 4596, 391, 7, 86, "Output",
  CellTags->{"b:37.1", "IPM3.8.4.2"}]
}, Closed]],
Cell[133120, 4606, 28, 0, 0, "SubsectionSpacer"]
}, Closed]],

Cell[CellGroupData[{
Cell[133185, 4611, 85, 1, 45, "ExerciseSubsection",
  CellTags->{"b:37.1", "IPM3.8.4.3", "c:19"}],
Cell[133273, 4614, 331, 10, 46, "ExerciseItem",
  CellTags->{"i:61", "b:37.1", "IPM3.8.4.3"}],
Cell[133607, 4626, 592, 20, 46, "ExerciseItem",
  CellTags->{"i:62", "b:37.1", "IPM3.8.4.3"}],

Cell[CellGroupData[{
Cell[134224, 4650, 483, 11, 84, "ExerciseItem",
  CellTags->{"b:37.1", "IPM3.8.4.3"}],
Cell[134710, 4663, 80, 2, 30, "NonPrintInput"],
Cell[134793, 4667, 25, 0, 8, "SectionSpacer"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[134879, 4674, 43, 0, 43, "NonPrintSection"],
Cell[134925, 4676, 144, 4, 30, "NonPrintInput",
  InitializationCell->True],
Cell[135072, 4682, 134, 3, 30, "NonPrintInput",
  InitializationCell->True],
Cell[135209, 4687, 119, 3, 30, "NonPrintInput",
  InitializationCell->True],
Cell[135331, 4692, 134, 4, 30, "NonPrintInput",
  InitializationCell->True]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

