(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      4929,        176]*)
(*NotebookOutlinePosition[      5615,        200]*)
(*  CellTagsIndexPosition[      5571,        196]*)
(*WindowFrame->Normal*)



Notebook[{
Cell["Count Cell Style Utility for IPM3", "Section"],

Cell[CellGroupData[{

Cell["\<\
Paul Wellin (wellin@wolfram.com)
Wolfram Education Group
Wolfram Research\
\>", "Subsubtitle"],

Cell["\<\
This utility can be used to count all the cells of a certain style in \
notebook or in a directory of notebooks.\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell["Identify directory where notebook(s) are located", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \($CourseDirectory = 
      ToFileName[{$BaseDirectory, "\<Applications\>", "\<IPM3\>", \
"\<Documentation\>", "\<English\>"}]\)], "Input"],

Cell[BoxData[
    \("C:\\Documents and Settings\\All Users\\Application \
Data\\Mathematica\\Applications\\IPM3\\Documentation\\English\\"\)], "Output"]
}, Closed]],

Cell["\<\
Open notebook, read it into the kernel, and then count the number of cells of \
a particular style.\
\>", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[BoxData[
    \(CountStyles[nb_String, style_String] := 
      Module[{nbExp, nbb}, \[IndentingNewLine]nbb = 
          NotebookOpen[
            ToFileName[{$CourseDirectory}, nb]]; \[IndentingNewLine]nbExp = 
          NotebookGet[nbb]; \[IndentingNewLine]FrontEndTokenExecute[
          nbb, "\<Close\>"]; 
        Length[Cases[nbExp, Cell[__, style, ___], 
            Infinity]]\[IndentingNewLine]]\)], "Input"],

Cell[TextData[{
  "Use ",
  StyleBox["CountStyles", "MR"],
  " on one notebook from ",
  StyleBox["$CourseDirectory", "MR"],
  " to count the number of occurrences of the ",
  StyleBox["ExerciseItem", "MR"],
  " cell style."
}], "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CountStyles["\<10FEProgramming.nb\>", "\<ExerciseItem\>"]\)], "Input"],

Cell[BoxData[
    \(11\)], "Output"]
}, Closed]],

Cell["Set the current working directory.", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SetDirectory[$CourseDirectory]\)], "Input"],

Cell[BoxData[
    \("C:\\Documents and Settings\\All Users\\Application \
Data\\Mathematica\\Applications\\IPM3\\Documentation\\English"\)], "Output"]
}, Closed]],

Cell["Pick out all of the files that I want to count.", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(filelist = Take[FileNames[], {3, 13}]\)], "Input"],

Cell[BoxData[
    \({"02Language.nb", "03Lists.nb", "04Functions.nb", "05Procedural.nb", 
      "06RuleBased.nb", "07Recursion.nb", "08Numerics.nb", "09Graphics.nb", 
      "10FEProgramming.nb", "11Applications.nb", "12Packages.nb"}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Map ",
  StyleBox["CountStyles", "MR"],
  " over the files from ",
  StyleBox["filelist", "MR"],
  "."
}], "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Map[CountStyles[#, "\<ExerciseItem\>"] &, filelist]\)], "Input"],

Cell[BoxData[
    \({10, 20, 42, 19, 26, 34, 29, 34, 11, 12, 5}\)], "Output"]
}, Closed]],

Cell["Add 'em up.", "Text",
  FontColor->RGBColor[0, 0, 1]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Total[%]\)], "Input"],

Cell[BoxData[
    \(242\)], "Output"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 681}},
WindowSize->{735, 612},
WindowMargins->{{Automatic, 31}, {Automatic, 6}},
ShowSelection->True,
Magnification->1.25
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{
Cell[1754, 51, 52, 0, 92, "Section"],

Cell[CellGroupData[{
Cell[1831, 55, 104, 4, 87, "Subsubtitle"],
Cell[1938, 61, 168, 4, 38, "Text"],
Cell[2109, 67, 96, 1, 38, "Text"],

Cell[CellGroupData[{
Cell[2230, 72, 157, 3, 77, "Input"],
Cell[2390, 77, 152, 2, 56, "Output"]
}, Closed]],
Cell[2557, 82, 155, 4, 33, "Text"],
Cell[2715, 88, 420, 8, 161, "Input"],
Cell[3138, 98, 268, 9, 59, "Text"],

Cell[CellGroupData[{
Cell[3431, 111, 90, 1, 35, "Input"],
Cell[3524, 114, 36, 1, 35, "Output"]
}, Closed]],
Cell[3575, 118, 82, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[3682, 123, 63, 1, 35, "Input"],
Cell[3748, 126, 150, 2, 56, "Output"]
}, Closed]],
Cell[3913, 131, 95, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[4033, 136, 70, 1, 35, "Input"],
Cell[4106, 139, 246, 3, 77, "Output"]
}, Closed]],
Cell[4367, 145, 165, 7, 33, "Text"],

Cell[CellGroupData[{
Cell[4557, 156, 84, 1, 35, "Input"],
Cell[4644, 159, 77, 1, 35, "Output"]
}, Closed]],
Cell[4736, 163, 59, 1, 33, "Text"],

Cell[CellGroupData[{
Cell[4820, 168, 41, 1, 35, "Input"],
Cell[4864, 171, 37, 1, 35, "Output"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

